{"sys/dkio.h", "DKIOCGGEOM", 0x401},
{"sys/dkio.h", "DKIOCSGEOM", 0x402},
{"sys/dkio.h", "DKIOCINFO", 0x403},
{"sys/dkio.h", "DKIOCSAPART", 0x404},
{"sys/dkio.h", "DKIOCGAPART", 0x405},
{"sys/dkio.h", "DKIOCEJECT", 0x406},
{"sys/dkio.h", "DKIOCLOCK", 0x407},
{"sys/dkio.h", "DKIOCUNLOCK", 0x408},
{"sys/dkio.h", "DKIOCGVTOC", 0x40b},
{"sys/dkio.h", "DKIOCSVTOC", 0x40c},
{"sys/dkio.h", "DKIOCSTATE", 0x40d},
{"sys/fdio.h", "FDIOGCHAR", 0x433},
{"sys/fdio.h", "FDIOSCHAR", 0x434},
{"sys/fdio.h", "FDEJECT", 0x435},
{"sys/fdio.h", "FDGETCHANGE", 0x436},
{"sys/fdio.h", "FDGETDRIVECHAR", 0x437},
{"sys/fdio.h", "FDSETDRIVECHAR", 0x438},
{"sys/fdio.h", "FDGETSEARCH", 0x439},
{"sys/fdio.h", "FDSETSEARCH", 0x43a},
{"sys/fdio.h", "FDIOCMD", 0x43b},
{"sys/fdio.h", "FDRAW", 0x446},
{"sys/fdio.h", "FDDEFGEOCHAR", 0x456},
{"sys/hdio.h", "HDKIOCSTYPE", 0x465},
{"sys/hdio.h", "HDKIOCGTYPE", 0x466},
{"sys/hdio.h", "HDKIOCSBAD", 0x467},
{"sys/hdio.h", "HDKIOCGBAD", 0x468},
{"sys/hdio.h", "HDKIOCSCMD", 0x469},
{"sys/hdio.h", "HDKIOCGDIAG", 0x46a},
{"sys/cdio.h", "CDROMPAUSE", 0x497},
{"sys/cdio.h", "CDROMRESUME", 0x498},
{"sys/cdio.h", "CDROMPLAYMSF", 0x499},
{"sys/cdio.h", "CDROMPLAYTRKIND", 0x49a},
{"sys/cdio.h", "CDROMREADTOCHDR", 0x49b},
{"sys/cdio.h", "CDROMREADTOCENTRY", 0x49c},
{"sys/cdio.h", "CDROMSTOP", 0x49d},
{"sys/cdio.h", "CDROMSTART", 0x49e},
{"sys/cdio.h", "CDROMEJECT", 0x49f},
{"sys/cdio.h", "CDROMVOLCTRL", 0x4a0},
{"sys/cdio.h", "CDROMSUBCHNL", 0x4a1},
{"sys/cdio.h", "CDROMREADMODE2", 0x4a2},
{"sys/cdio.h", "CDROMREADMODE1", 0x4a3},
{"sys/cdio.h", "CDROMREADOFFSET", 0x4a4},
{"sys/cdio.h", "CDROMGBLKMODE", 0x4a5},
{"sys/cdio.h", "CDROMSBLKMODE", 0x4a6},
{"sys/cdio.h", "CDROMCDDA", 0x4a7},
{"sys/cdio.h", "CDROMCDXA", 0x4a8},
{"sys/cdio.h", "CDROMSUBCODE", 0x4a9},
{"sys/cdio.h", "CDROMGDRVSPEED", 0x4aa},
{"sys/cdio.h", "CDROMSDRVSPEED", 0x4ab},
{"sys/scsi/impl/uscsi.h", "USCSICMD", 0x4c9},
{"sys/bufmod.h", "SBIOCSTIME", 0x4201},
{"sys/bufmod.h", "SBIOCGTIME", 0x4202},
{"sys/bufmod.h", "SBIOCCTIME", 0x4203},
{"sys/bufmod.h", "SBIOCSCHUNK", 0x4204},
{"sys/bufmod.h", "SBIOCGCHUNK", 0x4205},
{"sys/bufmod.h", "SBIOCSSNAP", 0x4206},
{"sys/bufmod.h", "SBIOCGSNAP", 0x4207},
{"sys/bufmod.h", "SBIOCSFLAGS", 0x4208},
{"sys/bufmod.h", "SBIOCGFLAGS", 0x4209},
{"sys/termios.h", "LDOPEN", 0x4400},
{"sys/termios.h", "LDCLOSE", 0x4401},
{"sys/dlpi.h", "DLIOCRAW", 0x4401},
{"sys/sad.h", "SAD_SAP", 0x4401},
{"sys/termios.h", "LDCHG", 0x4402},
{"sys/sad.h", "SAD_GAP", 0x4402},
{"sys/sad.h", "SAD_VML", 0x4403},
{"sys/termios.h", "LDGETT", 0x4408},
{"sys/termios.h", "LDSETT", 0x4409},
{"sys/dlpi.h", "DL_IOC_HDR_INFO", 0x440a},
{"sys/termios.h", "LDSMAP", 0x446e},
{"sys/termios.h", "LDGMAP", 0x446f},
{"sys/termios.h", "LDNMAP", 0x4470},
{"sys/termios.h", "LDEMAP", 0x4471},
{"sys/termios.h", "LDDMAP", 0x4472},
{"sys/fbio.h", "FBIOGTYPE", 0x4600},
{"sys/fbio.h", "FBIOGINFO", 0x4602},
{"sys/fbio.h", "FBIOPUTCMAP", 0x4603},
{"sys/fbio.h", "FBIOGETCMAP", 0x4604},
{"sys/fbio.h", "FBIOSATTR", 0x4605},
{"sys/fbio.h", "FBIOGATTR", 0x4606},
{"sys/fbio.h", "FBIOSVIDEO", 0x4607},
{"sys/fbio.h", "FBIOGVIDEO", 0x4608},
{"sys/fbio.h", "FBIOVERTICAL", 0x4609},
{"sys/fbio.h", "GRABPAGEALLOC", 0x460a},
{"sys/fbio.h", "GRABPAGEFREE", 0x460b},
{"sys/fbio.h", "GRABATTACH", 0x460c},
{"sys/fbio.h", "FBIOGPLNGRP", 0x460d},
{"sys/fbio.h", "FBIOGCMSIZE", 0x460e},
{"sys/fbio.h", "FBIOSCMSIZE", 0x460f},
{"sys/fbio.h", "FBIOSCMS", 0x4610},
{"sys/fbio.h", "FBIOAVAILPLNGRP", 0x4611},
{"sys/fbio.h", "FBIODBLGINFO", 0x4612},
{"sys/fbio.h", "FBIODBLSINFO", 0x4613},
{"sys/fbio.h", "FBIOSWINFD", 0x4614},
{"sys/fbio.h", "FBIOSAVWINFD", 0x4615},
{"sys/fbio.h", "FBIORESWINFD", 0x4616},
{"sys/fbio.h", "FBIOSRWINFD", 0x4617},
{"sys/visual_io.h", "VIS_SETCURSOR", 0x4618},
{"sys/fbio.h", "FBIOSCURSOR", 0x4618},
{"sys/fbio.h", "FBIOGCURSOR", 0x4619},
{"sys/visual_io.h", "VIS_GETCURSOR", 0x4619},
{"sys/fbio.h", "FBIOSCURPOS", 0x461a},
{"sys/visual_io.h", "VIS_MOVECURSOR", 0x461a},
{"sys/fbio.h", "FBIOGCURPOS", 0x461b},
{"sys/visual_io.h", "VIS_GETCURSORPOS", 0x461b},
{"sys/fbio.h", "FBIOGCURMAX", 0x461c},
{"sys/fbio.h", "GRABLOCKINFO", 0x461d},
{"sys/fbio.h", "FBIO_WID_ALLOC", 0x461e},
{"sys/fbio.h", "FBIO_WID_FREE", 0x461f},
{"sys/fbio.h", "FBIO_WID_PUT", 0x4620},
{"sys/fbio.h", "FBIO_WID_GET", 0x4621},
{"sys/fbio.h", "FBIO_DEVID", 0x4622},
{"sys/fbio.h", "FBIO_U_RST", 0x4623},
{"sys/fbio.h", "FBIO_FULLSCREEN_ELIMINATION_GROUPS", 0x4624},
{"sys/fbio.h", "FBIO_WID_DBL_SET", 0x4625},
{"sys/fbio.h", "FBIOVRTOFFSET", 0x4626},
{"sys/fbio.h", "FBIOGXINFO", 0x4627},
{"sys/fbio.h", "FBIOMONINFO", 0x4628},
{"sys/fbio.h", "FBIOPUTCMAPI", 0x4629},
{"sys/fbio.h", "FBIOGETCMAPI", 0x462a},
{"sys/fbio.h", "FBIO_ASSIGNWID", 0x462b},
{"sys/fbio.h", "FBIO_STEREO", 0x462c},
{"sys/gpio.h", "GP1IO_PUT_INFO", 0x4700},
{"sys/gpio.h", "GP1IO_GET_STATIC_BLOCK", 0x4701},
{"sys/gpio.h", "GP1IO_FREE_STATIC_BLOCK", 0x4702},
{"sys/gpio.h", "GP1IO_GET_GBUFFER_STATE", 0x4703},
{"sys/gpio.h", "GP1IO_CHK_GP", 0x4704},
{"sys/gpio.h", "GP1IO_GET_RESTART_COUNT", 0x4705},
{"sys/gpio.h", "GP1IO_REDIRECT_DEVFB", 0x4706},
{"sys/gpio.h", "GP1IO_GET_REQDEV", 0x4707},
{"sys/gpio.h", "GP1IO_GET_TRUMINORDEV", 0x4708},
{"sys/gpio.h", "GP1IO_CHK_FOR_GBUFFER", 0x4709},
{"sys/gpio.h", "GP1IO_SET_USING_GBUFFER", 0x470a},
{"sys/gpio.h", "GP1IO_INFO_STATIC_BLOCK", 0x470b},
{"sys/sockmod.h", "O_SI_GETUDATA", 0x4965},
{"sys/sockmod.h", "SI_SHUTDOWN", 0x4966},
{"sys/sockmod.h", "SI_LISTEN", 0x4967},
{"sys/sockmod.h", "SI_SETMYNAME", 0x4968},
{"sys/sockmod.h", "SI_SETPEERNAME", 0x4969},
{"sys/sockmod.h", "SI_GETINTRANSIT", 0x496a},
{"sys/sockmod.h", "SI_SOCKPARAMS", 0x496d},
{"sys/sockmod.h", "SI_GETUDATA", 0x496e},
{"sys/strlog.h", "I_TRCLOG", 0x4c01},
{"sys/strlog.h", "I_ERRLOG", 0x4c02},
{"sys/strlog.h", "I_CONSLOG", 0x4c03},
{"sys/cg14io.h", "MDI_RESET", 0x4d01},
{"sys/cg14io.h", "MDI_GET_CFGINFO", 0x4d02},
{"sys/cg14io.h", "MDI_SET_PIXELMODE", 0x4d03},
{"sys/cg14io.h", "MDI_SET_COUNTERS", 0x4d04},
{"sys/cg14io.h", "MDI_SET_PPR", 0x4d05},
{"sys/cg14io.h", "MDI_VRT_CNTL", 0x4d06},
{"sys/cg14io.h", "MDI_SET_CLUT", 0x4d07},
{"sys/cg14io.h", "MDI_GET_CLUT", 0x4d08},
{"sys/cg14io.h", "MDI_SET_XLUT", 0x4d09},
{"sys/cg14io.h", "MDI_GET_XLUT", 0x4d0a},
{"sys/cg14io.h", "MDI_GAMMA_CORRECT", 0x4d0b},
{"sys/cg14io.h", "MDI_SET_GAMMALUT", 0x4d0c},
{"sys/cg14io.h", "MDI_GET_GAMMALUT", 0x4d0d},
{"sys/cg14io.h", "MDI_SET_DEGAMMALUT", 0x4d0e},
{"sys/cg14io.h", "MDI_GET_DEGAMMALUT", 0x4d0f},
{"sys/cg14io.h", "MDI_GET_BUFFER_INFO", 0x4d10},
{"sys/cg14io.h", "MDI_SET_CURSOR", 0x4d11},
{"sys/cg14io.h", "MDI_GET_DIAGINFO", 0x4d12},
{"sys/cg14io.h", "MDI_SET_RESOLUTION", 0x4d13},
{"sys/cg14io.h", "SET_MONITOR_POWER", 0x4d14},
{"sys/openpromio.h", "OPROMGETBOOTARGS", 0x4f0c},
{"sys/pfmod.h", "PFIOCSETF", 0x5001},
{"sys/stropts.h", "I_NREAD", 0x5301},
{"sys/stropts.h", "I_PUSH", 0x5302},
{"sys/stropts.h", "I_POP", 0x5303},
{"sys/stropts.h", "I_LOOK", 0x5304},
{"sys/stropts.h", "I_FLUSH", 0x5305},
{"sys/stropts.h", "I_SRDOPT", 0x5306},
{"sys/stropts.h", "I_GRDOPT", 0x5307},
{"sys/stropts.h", "I_STR", 0x5308},
{"sys/stropts.h", "I_SETSIG", 0x5309},
{"sys/stropts.h", "I_GETSIG", 0x530a},
{"sys/stropts.h", "I_FIND", 0x530b},
{"sys/stropts.h", "I_LINK", 0x530c},
{"sys/stropts.h", "I_UNLINK", 0x530d},
{"sys/stropts.h", "I_RECVFD", 0x530e},
{"sys/stropts.h", "I_PEEK", 0x530f},
{"sys/stropts.h", "I_FDINSERT", 0x5310},
{"sys/stropts.h", "I_SENDFD", 0x5311},
{"sys/stropts.h", "I_SWROPT", 0x5313},
{"sys/stropts.h", "I_GWROPT", 0x5314},
{"sys/stropts.h", "I_LIST", 0x5315},
{"sys/stropts.h", "I_PLINK", 0x5316},
{"sys/stropts.h", "I_PUNLINK", 0x5317},
{"sys/stropts.h", "I_SETEV", 0x5318},
{"sys/stropts.h", "I_GETEV", 0x5319},
{"sys/stropts.h", "I_STREV", 0x531a},
{"sys/stropts.h", "I_UNSTREV", 0x531b},
{"sys/stropts.h", "I_FLUSHBAND", 0x531c},
{"sys/stropts.h", "I_CKBAND", 0x531d},
{"sys/stropts.h", "I_GETBAND", 0x531e},
{"sys/stropts.h", "I_ATMARK", 0x531f},
{"sys/stropts.h", "I_SETCLTIME", 0x5320},
{"sys/stropts.h", "I_GETCLTIME", 0x5321},
{"sys/stropts.h", "I_CANPUT", 0x5322},
{"sys/termios.h", "TCGETA", 0x5401},
{"sys/termios.h", "TCSETA", 0x5402},
{"sys/termios.h", "TCSETAW", 0x5403},
{"sys/termios.h", "TCSETAF", 0x5404},
{"sys/termios.h", "TCSBRK", 0x5405},
{"sys/termios.h", "TCXONC", 0x5406},
{"sys/termios.h", "TCFLSH", 0x5407},
{"sys/termios.h", "TIOCKBON", 0x5408},
{"sys/termios.h", "TIOCKBOF", 0x5409},
{"sys/termios.h", "KBENABLED", 0x540a},
{"sys/termios.h", "TCGETS", 0x540d},
{"sys/termios.h", "TCSETS", 0x540e},
{"sys/termios.h", "TCSANOW", 0x540e},
{"sys/termios.h", "TCSADRAIN", 0x540f},
{"sys/termios.h", "TCSETSW", 0x540f},
{"sys/termios.h", "TCSAFLUSH", 0x5410},
{"sys/termios.h", "TCSETSF", 0x5410},
{"sys/termio.h", "TCDSET", 0x5420},
{"sys/termios.h", "TCDSET", 0x5420},
{"sys/termios.h", "RTS_TOG", 0x5421},
{"sys/ttold.h", "TIOCSWINSZ", 0x5467},
{"sys/termios.h", "TIOCSWINSZ", 0x5467},
{"sys/ttold.h", "TIOCGWINSZ", 0x5468},
{"sys/termios.h", "TIOCGWINSZ", 0x5468},
{"sys/termios.h", "TIOCGSOFTCAR", 0x5469},
{"sys/termios.h", "TIOCSSOFTCAR", 0x546a},
{"sys/timod.h", "TI_GETINFO", 0x548c},
{"sys/timod.h", "TI_OPTMGMT", 0x548d},
{"sys/timod.h", "TI_BIND", 0x548e},
{"sys/timod.h", "TI_UNBIND", 0x548f},
{"sys/timod.h", "TI_GETMYNAME", 0x5490},
{"sys/timod.h", "TI_GETPEERNAME", 0x5491},
{"sys/timod.h", "TI_SETMYNAME", 0x5492},
{"sys/timod.h", "TI_SETPEERNAME", 0x5493},
{"sys/termiox.h", "TCGETX", 0x5801},
{"sys/termiox.h", "TCSETX", 0x5802},
{"sys/termiox.h", "TCSETXW", 0x5803},
{"sys/termiox.h", "TCSETXF", 0x5804},
{"sys/ioctl.h", "DIOCGETC", 0x6401},
{"sys/ioctl.h", "DIOCGETB", 0x6402},
{"sys/ioctl.h", "DIOCSETE", 0x6403},
{"sys/termios.h", "DIOCGETP", 0x6408},
{"sys/termios.h", "DIOCSETP", 0x6409},
{"sys/jioctl.h", "JBOOT", 0x6a01},
{"sys/jioctl.h", "JTERM", 0x6a02},
{"sys/jioctl.h", "JMPX", 0x6a03},
{"sys/jioctl.h", "JWINSIZE", 0x6a05},
{"sys/jioctl.h", "JZOMBOOT", 0x6a07},
{"sys/jioctl.h", "JAGENT", 0x6a09},
{"sys/jioctl.h", "JTRUN", 0x6a0a},
{"sys/jioctl.h", "JXTPROTO", 0x6a0b},
{"sys/kbio.h", "KIOCTRANS", 0x6b00},
{"sys/kbio.h", "KIOCSETKEY", 0x6b01},
{"sys/kbio.h", "KIOCGETKEY", 0x6b02},
{"sys/kbio.h", "KIOCGTRANS", 0x6b05},
{"sys/kbio.h", "KIOCTRANSABLE", 0x6b06},
{"sys/kbio.h", "KIOCGTRANSABLE", 0x6b07},
{"sys/kbio.h", "KIOCCMD", 0x6b08},
{"sys/kbio.h", "KIOCTYPE", 0x6b09},
{"sys/kbio.h", "KIOCSDIRECT", 0x6b0a},
{"sys/kbio.h", "KIOCGDIRECT", 0x6b0b},
{"sys/kbio.h", "KIOCSKEY", 0x6b0c},
{"sys/kbio.h", "KIOCGKEY", 0x6b0d},
{"sys/kbio.h", "KIOCSLED", 0x6b0e},
{"sys/kbio.h", "KIOCGLED", 0x6b0f},
{"sys/kbio.h", "KIOCSCOMPAT", 0x6b10},
{"sys/kbio.h", "KIOCGCOMPAT", 0x6b11},
{"sys/kbio.h", "KIOCLAYOUT", 0x6b14},
{"sys/ioctl.h", "LIOCGETP", 0x6c01},
{"sys/ioctl.h", "LIOCSETP", 0x6c02},
{"sys/ioctl.h", "LIOCGETS", 0x6c05},
{"sys/ioctl.h", "LIOCSETS", 0x6c06},
{"sys/mtio.h", "MTIOCTOP", 0x6d01},
{"sys/msio.h", "MSIOGETPARMS", 0x6d01},
{"sys/msio.h", "MSIOSETPARMS", 0x6d02},
{"sys/mtio.h", "MTIOCGET", 0x6d02},
{"sys/mtio.h", "MTIOCGETDRIVETYPE", 0x6d03},
{"sys/procfs.h", "PIOCSTATUS", 0x7101},
{"sys/procfs.h", "PIOCSTOP", 0x7102},
{"sys/procfs.h", "PIOCWSTOP", 0x7103},
{"sys/procfs.h", "PIOCRUN", 0x7104},
{"sys/procfs.h", "PIOCGTRACE", 0x7105},
{"sys/procfs.h", "PIOCSTRACE", 0x7106},
{"sys/procfs.h", "PIOCSSIG", 0x7107},
{"sys/procfs.h", "PIOCKILL", 0x7108},
{"sys/procfs.h", "PIOCUNKILL", 0x7109},
{"sys/procfs.h", "PIOCGHOLD", 0x710a},
{"sys/procfs.h", "PIOCSHOLD", 0x710b},
{"sys/procfs.h", "PIOCMAXSIG", 0x710c},
{"sys/procfs.h", "PIOCACTION", 0x710d},
{"sys/procfs.h", "PIOCGFAULT", 0x710e},
{"sys/procfs.h", "PIOCSFAULT", 0x710f},
{"sys/procfs.h", "PIOCCFAULT", 0x7110},
{"sys/procfs.h", "PIOCGENTRY", 0x7111},
{"sys/procfs.h", "PIOCSENTRY", 0x7112},
{"sys/procfs.h", "PIOCGEXIT", 0x7113},
{"sys/procfs.h", "PIOCSEXIT", 0x7114},
{"sys/procfs.h", "PIOCSFORK", 0x7115},
{"sys/procfs.h", "PIOCRFORK", 0x7116},
{"sys/procfs.h", "PIOCSRLC", 0x7117},
{"sys/procfs.h", "PIOCRRLC", 0x7118},
{"sys/procfs.h", "PIOCGREG", 0x7119},
{"sys/procfs.h", "PIOCSREG", 0x711a},
{"sys/procfs.h", "PIOCGFPREG", 0x711b},
{"sys/procfs.h", "PIOCSFPREG", 0x711c},
{"sys/procfs.h", "PIOCNICE", 0x711d},
{"sys/procfs.h", "PIOCPSINFO", 0x711e},
{"sys/procfs.h", "PIOCNMAP", 0x711f},
{"sys/procfs.h", "PIOCMAP", 0x7120},
{"sys/procfs.h", "PIOCOPENM", 0x7121},
{"sys/procfs.h", "PIOCCRED", 0x7122},
{"sys/procfs.h", "PIOCGROUPS", 0x7123},
{"sys/procfs.h", "PIOCGETPR", 0x7124},
{"sys/procfs.h", "PIOCGETU", 0x7125},
{"sys/procfs.h", "PIOCSET", 0x7126},
{"sys/procfs.h", "PIOCRESET", 0x7127},
{"sys/procfs.h", "PIOCNWATCH", 0x7128},
{"sys/procfs.h", "PIOCGWATCH", 0x7129},
{"sys/procfs.h", "PIOCSWATCH", 0x712a},
{"sys/procfs.h", "PIOCUSAGE", 0x712b},
{"sys/procfs.h", "PIOCOPENPD", 0x712c},
{"sys/procfs.h", "PIOCLWPIDS", 0x712d},
{"sys/procfs.h", "PIOCOPENLWP", 0x712e},
{"sys/procfs.h", "PIOCLSTATUS", 0x712f},
{"sys/procfs.h", "PIOCLUSAGE", 0x7130},
{"sys/procfs.h", "PIOCNAUXV", 0x7131},
{"sys/procfs.h", "PIOCAUXV", 0x7132},
{"sys/procfs.h", "PIOCGWIN", 0x7165},
{"sys/ttold.h", "TIOCGETD", 0x7400},
{"sys/termios.h", "TIOCGETD", 0x7400},
{"sys/termios.h", "TIOCSETD", 0x7401},
{"sys/ttold.h", "TIOCSETD", 0x7401},
{"sys/termios.h", "TIOCHPCL", 0x7402},
{"sys/ttold.h", "TIOCHPCL", 0x7402},
{"sys/ttold.h", "TIOCGETP", 0x7408},
{"sys/termios.h", "TIOCGETP", 0x7408},
{"sys/termios.h", "TIOCSETP", 0x7409},
{"sys/ttold.h", "TIOCSETP", 0x7409},
{"sys/ttold.h", "TIOCSETN", 0x740a},
{"sys/termios.h", "TIOCSETN", 0x740a},
{"sys/ttold.h", "TIOCEXCL", 0x740d},
{"sys/termios.h", "TIOCEXCL", 0x740d},
{"sys/ttold.h", "TIOCNXCL", 0x740e},
{"sys/termios.h", "TIOCNXCL", 0x740e},
{"sys/termios.h", "TIOCFLUSH", 0x7410},
{"sys/ttold.h", "TIOCFLUSH", 0x7410},
{"sys/termios.h", "TIOCSETC", 0x7411},
{"sys/ttold.h", "TIOCSETC", 0x7411},
{"sys/termios.h", "TIOCGETC", 0x7412},
{"sys/ttold.h", "TIOCGETC", 0x7412},
{"sys/termios.h", "TIOCGPGRP", 0x7414},
{"sys/termios.h", "TIOCSPGRP", 0x7415},
{"sys/termios.h", "TIOCGSID", 0x7416},
{"sys/termios.h", "TIOCSTI", 0x7417},
{"sys/termios.h", "TIOCSSID", 0x7418},
{"sys/termios.h", "TIOCMSET", 0x741a},
{"sys/termios.h", "TIOCMBIS", 0x741b},
{"sys/termios.h", "TIOCMBIC", 0x741c},
{"sys/termios.h", "TIOCMGET", 0x741d},
{"sys/termios.h", "TIOCREMOTE", 0x741e},
{"sys/ttold.h", "TIOCREMOTE", 0x741e},
{"sys/termios.h", "TIOCSIGNAL", 0x741f},
{"sys/termios.h", "TIOCSTART", 0x746e},
{"sys/ttold.h", "TIOCSTART", 0x746e},
{"sys/termios.h", "TIOCSTOP", 0x746f},
{"sys/ttold.h", "TIOCSTOP", 0x746f},
{"sys/ttold.h", "TIOCNOTTY", 0x7471},
{"sys/termios.h", "TIOCNOTTY", 0x7471},
{"sys/termios.h", "TIOCOUTQ", 0x7473},
{"sys/ttold.h", "TIOCOUTQ", 0x7473},
{"sys/termios.h", "TIOCGLTC", 0x7474},
{"sys/ttold.h", "TIOCGLTC", 0x7474},
{"sys/termios.h", "TIOCSLTC", 0x7475},
{"sys/ttold.h", "TIOCSLTC", 0x7475},
{"sys/termios.h", "TIOCCDTR", 0x7478},
{"sys/ttold.h", "TIOCCDTR", 0x7478},
{"sys/ttold.h", "TIOCSDTR", 0x7479},
{"sys/termios.h", "TIOCSDTR", 0x7479},
{"sys/termios.h", "TIOCCBRK", 0x747a},
{"sys/ttold.h", "TIOCCBRK", 0x747a},
{"sys/termios.h", "TIOCSBRK", 0x747b},
{"sys/ttold.h", "TIOCSBRK", 0x747b},
{"sys/termios.h", "TIOCLGET", 0x747c},
{"sys/ttold.h", "TIOCLGET", 0x747c},
{"sys/termios.h", "TIOCLSET", 0x747d},
{"sys/ttold.h", "TIOCLSET", 0x747d},
{"sys/ttold.h", "TIOCLBIC", 0x747e},
{"sys/termios.h", "TIOCLBIC", 0x747e},
{"sys/ttold.h", "TIOCLBIS", 0x747f},
{"sys/termios.h", "TIOCLBIS", 0x747f},
{"sys/vol.h", "VOLIOCMAP", 0x7601},
{"sys/vuid_event.h", "VUIDSFORMAT", 0x7601},
{"sys/vuid_event.h", "VUIDSFORMAT", 0x7601},
{"sys/vuid_event.h", "VUIDGFORMAT", 0x7602},
{"sys/vuid_event.h", "VUIDGFORMAT", 0x7602},
{"sys/vol.h", "VOLIOCUNMAP", 0x7602},
{"sys/vol.h", "VOLIOCEVENT", 0x7603},
{"sys/vuid_event.h", "VUIDSADDR", 0x7603},
{"sys/vuid_event.h", "VUIDSADDR", 0x7603},
{"sys/vuid_event.h", "VUIDGADDR", 0x7604},
{"sys/vuid_event.h", "VUIDGADDR", 0x7604},
{"sys/vol.h", "VOLIOCEJECT", 0x7604},
{"sys/vol.h", "VOLIOCCHECK", 0x7605},
{"sys/vol.h", "VOLIOCINUSE", 0x7606},
{"sys/vol.h", "VOLIOCDGATTR", 0x7607},
{"sys/vol.h", "VOLIOCDSATTR", 0x7608},
{"sys/vol.h", "VOLIOCDCHECK", 0x7609},
{"sys/vol.h", "VOLIOCCANCEL", 0x760a},
{"sys/vol.h", "VOLIOCINFO", 0x760b},
{"sys/vol.h", "VOLIOCSATTR", 0x760c},
{"sys/vol.h", "VOLIOCGATTR", 0x760d},
{"sys/vol.h", "VOLIOCDINUSE", 0x760e},
{"sys/vol.h", "VOLIOCDAEMON", 0x760f},
{"sys/vol.h", "VOLIOCFLAGS", 0x7610},
{"sys/vol.h", "VOLIOCEXTRA4", 0x7611},
{"sys/vol.h", "VOLIOCEXTRA5", 0x7612},
{"sys/vol.h", "VOLIOCEXTRA6", 0x7613},
{"sys/vol.h", "VOLIOCEXTRA7", 0x7614},
{"sys/ser_sync.h", "S_IOCGETMODE", 0x7a01},
{"sys/ser_sync.h", "S_IOCSETMODE", 0x7a02},
{"sys/ser_sync.h", "S_IOCGETSTATS", 0x7a03},
{"sys/ser_sync.h", "S_IOCCLRSTATS", 0x7a04},
{"sys/ser_sync.h", "S_IOCGETSPEED", 0x7a05},
{"sys/ser_sync.h", "S_IOCGETMRU", 0x7a06},
{"sys/ser_sync.h", "S_IOCSETMRU", 0x7a07},
{"sys/ser_sync.h", "S_IOCGETMTU", 0x7a08},
{"sys/ser_sync.h", "S_IOCSETMTU", 0x7a09},
{"sys/ser_sync.h", "S_IOCGETMCTL", 0x7a0a},
{"sys/tl.h", "TL_IOC_CREDOPT", 0x544c01},
