	{"linux/fs.h",	"FIBMAP",	0x1},
	{"linux/fs.h",	"FIGETBSZ",	0x2},
	{"linux/fd.h",	"FDGETPRM",	0x204},
	{"linux/fd.h",	"FDGETMAXERRS",	0x20e},
	{"linux/fd.h",	"FDGETDRVTYP",	0x20f},
	{"linux/fd.h",	"FDGETDRVPRM",	0x211},
	{"linux/fd.h",	"FDGETDRVSTAT",	0x212},
	{"linux/fd.h",	"FDPOLLDRVSTAT",	0x213},
	{"linux/fd.h",	"FDGETFDCSTAT",	0x215},
	{"linux/fd.h",	"FDWERRORGET",	0x217},
	{"linux/fd.h",	"FDCLRPRM",	0x241},
	{"linux/fd.h",	"FDSETPRM",	0x242},
	{"linux/fd.h",	"FDDEFPRM",	0x243},
	{"linux/fd.h",	"FDMSGON",	0x245},
	{"linux/fd.h",	"FDMSGOFF",	0x246},
	{"linux/fd.h",	"FDFMTBEG",	0x247},
	{"linux/fd.h",	"FDFMTTRK",	0x248},
	{"linux/fd.h",	"FDFMTEND",	0x249},
	{"linux/fd.h",	"FDSETEMSGTRESH",	0x24a},
	{"linux/fd.h",	"FDFLUSH",	0x24b},
	{"linux/fd.h",	"FDSETMAXERRS",	0x24c},
	{"linux/fd.h",	"FDRESET",	0x254},
	{"linux/fd.h",	"FDWERRORCLR",	0x256},
	{"linux/fd.h",	"FDRAWCMD",	0x258},
	{"linux/fd.h",	"FDTWADDLE",	0x259},
	{"linux/fd.h",	"FDEJECT",	0x25a},
	{"linux/fd.h",	"FDSETDRVPRM",	0x290},
	{"linux/umsdos_fs.h",	"UMSDOS_READDIR_DOS",	0x4d2},
	{"linux/umsdos_fs.h",	"UMSDOS_UNLINK_DOS",	0x4d3},
	{"linux/umsdos_fs.h",	"UMSDOS_RMDIR_DOS",	0x4d4},
	{"linux/umsdos_fs.h",	"UMSDOS_STAT_DOS",	0x4d5},
	{"linux/umsdos_fs.h",	"UMSDOS_CREAT_EMD",	0x4d6},
	{"linux/umsdos_fs.h",	"UMSDOS_UNLINK_EMD",	0x4d7},
	{"linux/umsdos_fs.h",	"UMSDOS_READDIR_EMD",	0x4d8},
	{"linux/umsdos_fs.h",	"UMSDOS_GETVERSION",	0x4d9},
	{"linux/umsdos_fs.h",	"UMSDOS_INIT_EMD",	0x4da},
	{"linux/umsdos_fs.h",	"UMSDOS_DOS_SETUP",	0x4db},
	{"linux/umsdos_fs.h",	"UMSDOS_RENAME_DOS",	0x4dc},
	{"linux/fs.h",	"BLKROSET",	0x125d},
	{"linux/fs.h",	"BLKROGET",	0x125e},
	{"linux/fs.h",	"BLKRRPART",	0x125f},
	{"linux/fs.h",	"BLKGETSIZE",	0x1260},
	{"linux/fs.h",	"BLKFLSBUF",	0x1261},
	{"linux/fs.h",	"BLKRASET",	0x1262},
	{"linux/fs.h",	"BLKRAGET",	0x1263},
	{"linux/fs.h",	"BLKFRASET",	0x1264},
	{"linux/fs.h",	"BLKFRAGET",	0x1265},
	{"linux/fs.h",	"BLKSECTSET",	0x1266},
	{"linux/fs.h",	"BLKSECTGET",	0x1267},
	{"linux/fs.h",	"BLKSSZGET",	0x1268},
	{"linux/blkpg.h",	"BLKPG",	0x1269},
	{"linux/fs.h",	"BLKPG",	0x1269},
	{"linux/elevator.h",	"BLKELVGET",	0x126a},
	{"linux/fs.h",	"BLKELVGET",	0x126a},
	{"linux/elevator.h",	"BLKELVSET",	0x126b},
	{"linux/fs.h",	"BLKELVSET",	0x126b},
	{"linux/agpgart.h",	"AGPIOC_INFO",	0x4100},
	{"linux/agpgart.h",	"AGPIOC_ACQUIRE",	0x4101},
	{"linux/apm_bios.h",	"APM_IOC_STANDBY",	0x4101},
	{"linux/agpgart.h",	"AGPIOC_RELEASE",	0x4102},
	{"linux/apm_bios.h",	"APM_IOC_SUSPEND",	0x4102},
	{"linux/agpgart.h",	"AGPIOC_SETUP",	0x4103},
	{"linux/agpgart.h",	"AGPIOC_RESERVE",	0x4104},
	{"linux/agpgart.h",	"AGPIOC_PROTECT",	0x4105},
	{"linux/agpgart.h",	"AGPIOC_ALLOCATE",	0x4106},
	{"linux/agpgart.h",	"AGPIOC_DEALLOCATE",	0x4107},
	{"linux/agpgart.h",	"AGPIOC_BIND",	0x4108},
	{"linux/agpgart.h",	"AGPIOC_UNBIND",	0x4109},
	{"linux/pmu.h",	"PMU_IOC_SLEEP",	0x4200},
	{"linux/cciss_ioctl.h",	"CCISS_GETPCIINFO",	0x4201},
	{"linux/pmu.h",	"PMU_IOC_GET_BACKLIGHT",	0x4201},
	{"linux/cciss_ioctl.h",	"CCISS_GETINTINFO",	0x4202},
	{"linux/pmu.h",	"PMU_IOC_SET_BACKLIGHT",	0x4202},
	{"linux/cciss_ioctl.h",	"CCISS_SETINTINFO",	0x4203},
	{"linux/pmu.h",	"PMU_IOC_GET_MODEL",	0x4203},
	{"linux/cciss_ioctl.h",	"CCISS_GETNODENAME",	0x4204},
	{"linux/pmu.h",	"PMU_IOC_HAS_ADB",	0x4204},
	{"linux/cciss_ioctl.h",	"CCISS_SETNODENAME",	0x4205},
	{"linux/cciss_ioctl.h",	"CCISS_GETHEARTBEAT",	0x4206},
	{"linux/cciss_ioctl.h",	"CCISS_GETBUSTYPES",	0x4207},
	{"linux/cciss_ioctl.h",	"CCISS_GETFIRMVER",	0x4208},
	{"linux/cciss_ioctl.h",	"CCISS_GETDRIVVER",	0x4209},
	{"linux/cciss_ioctl.h",	"CCISS_REVALIDVOLS",	0x420a},
	{"linux/cciss_ioctl.h",	"CCISS_PASSTHRU",	0x420b},
	{"linux/capi.h",	"CAPI_REGISTER",	0x4301},
	{"linux/capi.h",	"CAPI_GET_MANUFACTURER",	0x4306},
	{"linux/capi.h",	"CAPI_GET_VERSION",	0x4307},
	{"linux/capi.h",	"CAPI_GET_SERIAL",	0x4308},
	{"linux/capi.h",	"CAPI_GET_PROFILE",	0x4309},
	{"linux/capi.h",	"CAPI_MANUFACTURER_CMD",	0x4320},
	{"linux/capi.h",	"CAPI_GET_ERRCODE",	0x4321},
	{"linux/capi.h",	"CAPI_INSTALLED",	0x4322},
	{"linux/capi.h",	"CAPI_GET_FLAGS",	0x4323},
	{"linux/capi.h",	"CAPI_SET_FLAGS",	0x4324},
	{"linux/capi.h",	"CAPI_CLR_FLAGS",	0x4325},
	{"linux/capi.h",	"CAPI_NCCI_OPENCOUNT",	0x4326},
	{"linux/capi.h",	"CAPI_NCCI_GETUNIT",	0x4327},
	{"linux/dasd.h",	"BIODASDFORMAT",	0x4400},
	{"linux/dasd.h",	"BIODASDDISABLE",	0x4401},
	{"linux/dasd.h",	"BIODASDENABLE",	0x4402},
	{"linux/dasd.h",	"BIODASDGTVLBL",	0x4403},
	{"linux/dasd.h",	"BIODASDSTVLBL",	0x4404},
	{"linux/dasd.h",	"BIODASDRWTB",	0x4405},
	{"linux/dasd.h",	"BIODASDRSID",	0x4406},
	{"linux/input.h",	"EVIOCGVERSION",	0x4501},
	{"linux/input.h",	"EVIOCGID",	0x4502},
	{"linux/input.h",	"EVIOCGREP",	0x4503},
	{"linux/input.h",	"EVIOCSREP",	0x4503},
	{"linux/input.h",	"EVIOCGKEYCODE",	0x4504},
	{"linux/input.h",	"EVIOCSKEYCODE",	0x4504},
	{"linux/input.h",	"EVIOCGKEY",	0x4505},
	{"linux/fb.h",	"FBIOGET_VBLANK",	0x4612},
	{"linux/isdn.h",	"IIOCNETAIF",	0x4901},
	{"linux/isdn.h",	"IIOCNETDIF",	0x4902},
	{"linux/isdn.h",	"IIOCNETSCF",	0x4903},
	{"linux/isdn.h",	"IIOCNETGCF",	0x4904},
	{"linux/isdn.h",	"IIOCNETANM",	0x4905},
	{"linux/isdn.h",	"IIOCNETDNM",	0x4906},
	{"linux/isdn.h",	"IIOCNETGNM",	0x4907},
	{"linux/isdn.h",	"IIOCGETSET",	0x4908},
	{"linux/isdn.h",	"IIOCSETSET",	0x4909},
	{"linux/isdn.h",	"IIOCSETVER",	0x490a},
	{"linux/isdn.h",	"IIOCNETHUP",	0x490b},
	{"linux/isdn.h",	"IIOCSETGST",	0x490c},
	{"linux/isdn.h",	"IIOCSETBRJ",	0x490d},
	{"linux/isdn.h",	"IIOCSIGPRF",	0x490e},
	{"linux/isdn.h",	"IIOCGETPRF",	0x490f},
	{"linux/isdn.h",	"IIOCSETPRF",	0x4910},
	{"linux/isdn.h",	"IIOCGETMAP",	0x4911},
	{"linux/isdn.h",	"IIOCSETMAP",	0x4912},
	{"linux/isdn.h",	"IIOCNETASL",	0x4913},
	{"linux/isdn.h",	"IIOCNETDIL",	0x4914},
	{"linux/isdn.h",	"IIOCGETCPS",	0x4915},
	{"linux/isdn.h",	"IIOCGETDVR",	0x4916},
	{"linux/isdn.h",	"IIOCNETLCR",	0x4917},
	{"linux/isdn.h",	"IIOCNETDWRSET",	0x4918},
	{"linux/isdn.h",	"IIOCNETALN",	0x4920},
	{"linux/isdn.h",	"IIOCNETDLN",	0x4921},
	{"linux/isdn.h",	"IIOCNETGPN",	0x4922},
	{"linux/isdn.h",	"IIOCDBGVAR",	0x497f},
	{"linux/isdn.h",	"IIOCDRVCTL",	0x4980},
	{"linux/random.h",	"RNDGETENTCNT",	0x5200},
	{"linux/random.h",	"RNDADDTOENTCNT",	0x5201},
	{"linux/random.h",	"RNDGETPOOL",	0x5202},
	{"linux/random.h",	"RNDADDENTROPY",	0x5203},
	{"linux/random.h",	"RNDZAPENTCNT",	0x5204},
	{"linux/random.h",	"RNDCLEARPOOL",	0x5206},
	{"asm-parisc/ioctls.h",	"TCGETA",	0x5401},
	{"asm-parisc/ioctls.h",	"TCSETA",	0x5402},
	{"asm-parisc/ioctls.h",	"TCSETAW",	0x5403},
	{"asm-parisc/ioctls.h",	"TCSETAF",	0x5404},
	{"asm-parisc/ioctls.h",	"TCSBRK",	0x5405},
	{"asm-parisc/ioctls.h",	"TCXONC",	0x5406},
	{"asm-parisc/ioctls.h",	"TCFLSH",	0x5407},
	{"asm-parisc/ioctls.h",	"TCGETS",	0x5410},
	{"asm-parisc/ioctls.h",	"TCSETS",	0x5411},
	{"asm-parisc/ioctls.h",	"TCSETSW",	0x5412},
	{"asm-parisc/ioctls.h",	"TCSETSF",	0x5413},
	{"asm-parisc/ioctls.h",	"TIOCGSID",	0x5414},
	{"asm-parisc/ioctls.h",	"TIOCSPGRP",	0x541d},
	{"asm-parisc/ioctls.h",	"TIOCGPGRP",	0x541e},
	{"asm-parisc/ioctls.h",	"TIOCGPTN",	0x5430},
	{"asm-parisc/ioctls.h",	"TIOCSPTLCK",	0x5431},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CONTROL",	0x5500},
	{"linux/usbdevice_fs.h",	"USBDEVFS_BULK",	0x5502},
	{"linux/usbdevice_fs.h",	"USBDEVFS_RESETEP",	0x5503},
	{"linux/usbdevice_fs.h",	"USBDEVFS_SETINTERFACE",	0x5504},
	{"linux/usbdevice_fs.h",	"USBDEVFS_SETCONFIGURATION",	0x5505},
	{"linux/usbdevice_fs.h",	"USBDEVFS_GETDRIVER",	0x5508},
	{"linux/usbdevice_fs.h",	"USBDEVFS_SUBMITURB",	0x550a},
	{"linux/usbdevice_fs.h",	"USBDEVFS_DISCARDURB",	0x550b},
	{"linux/usbdevice_fs.h",	"USBDEVFS_REAPURB",	0x550c},
	{"linux/usbdevice_fs.h",	"USBDEVFS_REAPURBNDELAY",	0x550d},
	{"linux/usbdevice_fs.h",	"USBDEVFS_DISCSIGNAL",	0x550e},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CLAIMINTERFACE",	0x550f},
	{"linux/usbdevice_fs.h",	"USBDEVFS_RELEASEINTERFACE",	0x5510},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CONNECTINFO",	0x5511},
	{"linux/usbdevice_fs.h",	"USBDEVFS_IOCTL",	0x5512},
	{"linux/usbdevice_fs.h",	"USBDEVFS_HUB_PORTINFO",	0x5513},
	{"linux/usbdevice_fs.h",	"USBDEVFS_RESET",	0x5514},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CLEAR_HALT",	0x5515},
	{"linux/watchdog.h",	"WDIOC_GETSUPPORT",	0x5700},
	{"linux/watchdog.h",	"WDIOC_GETSTATUS",	0x5701},
	{"linux/watchdog.h",	"WDIOC_GETBOOTSTATUS",	0x5702},
	{"linux/watchdog.h",	"WDIOC_GETTEMP",	0x5703},
	{"linux/watchdog.h",	"WDIOC_SETOPTIONS",	0x5704},
	{"linux/watchdog.h",	"WDIOC_KEEPALIVE",	0x5705},
	{"linux/sonet.h",	"SONET_GETSTAT",	0x6110},
	{"linux/sonet.h",	"SONET_GETSTATZ",	0x6111},
	{"linux/sonet.h",	"SONET_SETDIAG",	0x6112},
	{"linux/sonet.h",	"SONET_CLRDIAG",	0x6113},
	{"linux/sonet.h",	"SONET_GETDIAG",	0x6114},
	{"linux/sonet.h",	"SONET_SETFRAMING",	0x6115},
	{"linux/sonet.h",	"SONET_GETFRAMING",	0x6116},
	{"linux/sonet.h",	"SONET_GETFRSENSE",	0x6117},
	{"linux/atm_idt77105.h",	"IDT77105_GETSTAT",	0x6132},
	{"linux/atm_idt77105.h",	"IDT77105_GETSTATZ",	0x6133},
	{"linux/atmdev.h",	"ATM_GETSTAT",	0x6150},
	{"linux/atmdev.h",	"ATM_GETSTATZ",	0x6151},
	{"linux/atmdev.h",	"ATM_GETLOOP",	0x6152},
	{"linux/atmdev.h",	"ATM_SETLOOP",	0x6153},
	{"linux/atmdev.h",	"ATM_QUERYLOOP",	0x6154},
	{"linux/atm_eni.h",	"ENI_MEMDUMP",	0x6160},
	{"linux/atm_nicstar.h",	"NS_GETPSTAT",	0x6161},
	{"linux/atm_zatm.h",	"ZATM_GETPOOL",	0x6161},
	{"linux/atm_nicstar.h",	"NS_SETBUFLEV",	0x6162},
	{"linux/atm_zatm.h",	"ZATM_GETPOOLZ",	0x6162},
	{"linux/atm_nicstar.h",	"NS_ADJBUFLEV",	0x6163},
	{"linux/atm_zatm.h",	"ZATM_SETPOOL",	0x6163},
	{"linux/atm_zatm.h",	"ZATM_GETTHIST",	0x6164},
	{"linux/atm_eni.h",	"ENI_SETMULT",	0x6167},
	{"linux/atm_tcp.h",	"SIOCSIFATMTCP",	0x6180},
	{"linux/atmdev.h",	"ATM_GETLINKRATE",	0x6181},
	{"linux/atmdev.h",	"ATM_GETNAMES",	0x6183},
	{"linux/atmdev.h",	"ATM_GETTYPE",	0x6184},
	{"linux/atmdev.h",	"ATM_GETESI",	0x6185},
	{"linux/atmdev.h",	"ATM_GETADDR",	0x6186},
	{"linux/atmdev.h",	"ATM_RSTADDR",	0x6187},
	{"linux/atmdev.h",	"ATM_ADDADDR",	0x6188},
	{"linux/atmdev.h",	"ATM_DELADDR",	0x6189},
	{"linux/atmdev.h",	"ATM_GETCIRANGE",	0x618a},
	{"linux/atmdev.h",	"ATM_SETCIRANGE",	0x618b},
	{"linux/atmdev.h",	"ATM_SETESI",	0x618c},
	{"linux/atmdev.h",	"ATM_SETESIF",	0x618d},
	{"linux/atm_tcp.h",	"ATMTCP_CREATE",	0x618e},
	{"linux/atm_tcp.h",	"ATMTCP_REMOVE",	0x618f},
	{"linux/atmlec.h",	"ATMLEC_CTRL",	0x61d0},
	{"linux/atmlec.h",	"ATMLEC_DATA",	0x61d1},
	{"linux/atmlec.h",	"ATMLEC_MCAST",	0x61d2},
	{"linux/atmmpc.h",	"ATMMPC_CTRL",	0x61d8},
	{"linux/atmmpc.h",	"ATMMPC_DATA",	0x61d9},
	{"linux/atmclip.h",	"SIOCMKCLIP",	0x61e0},
	{"linux/atmarp.h",	"ATMARPD_CTRL",	0x61e1},
	{"linux/atmarp.h",	"ATMARP_MKIP",	0x61e2},
	{"linux/atmarp.h",	"ATMARP_SETENTRY",	0x61e3},
	{"linux/atmarp.h",	"ATMARP_ENCAP",	0x61e5},
	{"linux/atmsvc.h",	"ATMSIGD_CTRL",	0x61f0},
	{"linux/atmdev.h",	"ATM_SETSC",	0x61f1},
	{"linux/coda.h",	"CIOC_KERNEL_VERSION",	0x630a},
	{"linux/comstats.h",	"COM_GETPORTSTATS",	0x631e},
	{"linux/comstats.h",	"COM_CLRPORTSTATS",	0x631f},
	{"linux/comstats.h",	"COM_GETBRDSTATS",	0x6320},
	{"linux/comstats.h",	"COM_READPORT",	0x6328},
	{"linux/comstats.h",	"COM_READBOARD",	0x6329},
	{"linux/comstats.h",	"COM_READPANEL",	0x632a},
	{"linux/devfs_fs.h",	"DEVFSDIOC_GET_PROTO_REV",	0x6400},
	{"linux/video_decoder.h",	"DECODER_GET_CAPABILITIES",	0x6401},
	{"linux/devfs_fs.h",	"DEVFSDIOC_SET_EVENT_MASK",	0x6402},
	{"linux/video_decoder.h",	"DECODER_GET_STATUS",	0x6402},
	{"linux/devfs_fs.h",	"DEVFSDIOC_RELEASE_EVENT_QUEUE",	0x6403},
	{"linux/video_decoder.h",	"DECODER_SET_NORM",	0x6403},
	{"linux/devfs_fs.h",	"DEVFSDIOC_SET_DEBUG_MASK",	0x6404},
	{"linux/video_decoder.h",	"DECODER_SET_INPUT",	0x6404},
	{"linux/video_decoder.h",	"DECODER_SET_OUTPUT",	0x6405},
	{"linux/video_decoder.h",	"DECODER_ENABLE_OUTPUT",	0x6406},
	{"linux/video_decoder.h",	"DECODER_SET_PICTURE",	0x6407},
	{"linux/video_decoder.h",	"DECODER_DUMP",	0x64c0},
	{"linux/video_encoder.h",	"ENCODER_GET_CAPABILITIES",	0x6501},
	{"linux/video_encoder.h",	"ENCODER_SET_NORM",	0x6502},
	{"linux/video_encoder.h",	"ENCODER_SET_INPUT",	0x6503},
	{"linux/video_encoder.h",	"ENCODER_SET_OUTPUT",	0x6504},
	{"linux/video_encoder.h",	"ENCODER_ENABLE_OUTPUT",	0x6505},
	{"linux/ext2_fs.h",	"EXT2_IOC_GETFLAGS",	0x6601},
	{"linux/ext2_fs.h",	"EXT2_IOC_SETFLAGS",	0x6602},
	{"linux/i2o-dev.h",	"I2OGETIOPS",	0x6900},
	{"linux/i2o-dev.h",	"I2OHRTGET",	0x6901},
	{"linux/i2o-dev.h",	"I2OLCTGET",	0x6902},
	{"linux/i2o-dev.h",	"I2OPARMSET",	0x6903},
	{"linux/i2o-dev.h",	"I2OPARMGET",	0x6904},
	{"linux/i2o-dev.h",	"I2OSWDL",	0x6905},
	{"linux/i2o-dev.h",	"I2OSWUL",	0x6906},
	{"linux/i2o-dev.h",	"I2OSWDEL",	0x6907},
	{"linux/i2o-dev.h",	"I2OVALIDATE",	0x6908},
	{"linux/i2o-dev.h",	"I2OHTML",	0x6909},
	{"linux/i2o-dev.h",	"I2OEVTREG",	0x690a},
	{"linux/i2o-dev.h",	"I2OEVTGET",	0x690b},
	{"linux/joystick.h",	"JSIOCGVERSION",	0x6a01},
	{"linux/joystick.h",	"JSIOCGAXES",	0x6a11},
	{"linux/joystick.h",	"JSIOCGBUTTONS",	0x6a12},
	{"linux/joystick.h",	"JSIOCSCORR",	0x6a21},
	{"linux/joystick.h",	"JSIOCGCORR",	0x6a22},
	{"linux/udf_fs_i.h",	"UDF_GETEASIZE",	0x6c40},
	{"linux/udf_fs_i.h",	"UDF_GETEABLOCK",	0x6c41},
	{"linux/udf_fs_i.h",	"UDF_GETVOLIDENT",	0x6c42},
	{"linux/synclink.h",	"MGSL_IOCSPARAMS",	0x6d00},
	{"linux/mtio.h",	"MTIOCTOP",	0x6d01},
	{"linux/synclink.h",	"MGSL_IOCGPARAMS",	0x6d01},
	{"linux/mtio.h",	"MTIOCGET",	0x6d02},
	{"linux/synclink.h",	"MGSL_IOCSTXIDLE",	0x6d02},
	{"linux/mtio.h",	"MTIOCPOS",	0x6d03},
	{"linux/synclink.h",	"MGSL_IOCGTXIDLE",	0x6d03},
	{"linux/mtio.h",	"MTIOCGETCONFIG",	0x6d04},
	{"linux/synclink.h",	"MGSL_IOCTXENABLE",	0x6d04},
	{"linux/mtio.h",	"MTIOCSETCONFIG",	0x6d05},
	{"linux/synclink.h",	"MGSL_IOCRXENABLE",	0x6d05},
	{"linux/mtio.h",	"MTIOCRDFTSEG",	0x6d06},
	{"linux/synclink.h",	"MGSL_IOCTXABORT",	0x6d06},
	{"linux/mtio.h",	"MTIOCWRFTSEG",	0x6d07},
	{"linux/synclink.h",	"MGSL_IOCGSTATS",	0x6d07},
	{"linux/mtio.h",	"MTIOCVOLINFO",	0x6d08},
	{"linux/synclink.h",	"MGSL_IOCWAITEVENT",	0x6d08},
	{"linux/mtio.h",	"MTIOCGETSIZE",	0x6d09},
	{"linux/synclink.h",	"MGSL_IOCLOOPTXDONE",	0x6d09},
	{"linux/mtio.h",	"MTIOCFTFORMAT",	0x6d0a},
	{"linux/mtio.h",	"MTIOCFTCMD",	0x6d0b},
	{"linux/synclink.h",	"MGSL_IOCCLRMODCOUNT",	0x6d0f},
	{"linux/zftape.h",	"MTIOC_ZFTAPE_GETBLKSZ",	0x6d68},
	{"linux/ncp_fs.h",	"NCP_IOC_NCPREQUEST",	0x6e01},
	{"linux/ncp_fs.h",	"NCP_IOC_GETMOUNTUID",	0x6e02},
	{"linux/ncp_fs.h",	"NCP_IOC_GETMOUNTUID2",	0x6e02},
	{"linux/ncp_fs.h",	"NCP_IOC_CONN_LOGGED_IN",	0x6e03},
	{"linux/ncp_fs.h",	"NCP_IOC_GET_FS_INFO",	0x6e04},
	{"linux/ncp_fs.h",	"NCP_IOC_GET_FS_INFO_V2",	0x6e04},
	{"linux/ncp_fs.h",	"NCP_IOC_SIGN_INIT",	0x6e05},
	{"linux/ncp_fs.h",	"NCP_IOC_SIGN_WANTED",	0x6e06},
	{"linux/ncp_fs.h",	"NCP_IOC_SET_SIGN_WANTED",	0x6e06},
	{"linux/ncp_fs.h",	"NCP_IOC_LOCKUNLOCK",	0x6e07},
	{"linux/ncp_fs.h",	"NCP_IOC_GETROOT",	0x6e08},
	{"linux/ncp_fs.h",	"NCP_IOC_SETROOT",	0x6e08},
	{"linux/ncp_fs.h",	"NCP_IOC_GETOBJECTNAME",	0x6e09},
	{"linux/ncp_fs.h",	"NCP_IOC_SETOBJECTNAME",	0x6e09},
	{"linux/ncp_fs.h",	"NCP_IOC_GETPRIVATEDATA",	0x6e0a},
	{"linux/ncp_fs.h",	"NCP_IOC_SETPRIVATEDATA",	0x6e0a},
	{"linux/ncp_fs.h",	"NCP_IOC_GETCHARSETS",	0x6e0b},
	{"linux/ncp_fs.h",	"NCP_IOC_SETCHARSETS",	0x6e0b},
	{"linux/ncp_fs.h",	"NCP_IOC_GETDENTRYTTL",	0x6e0c},
	{"linux/ncp_fs.h",	"NCP_IOC_SETDENTRYTTL",	0x6e0c},
	{"linux/matroxfb.h",	"MATROXFB_SET_OUTPUT_CONNECTION",	0x6ef8},
	{"linux/matroxfb.h",	"MATROXFB_GET_OUTPUT_CONNECTION",	0x6ef8},
	{"linux/matroxfb.h",	"MATROXFB_GET_AVAILABLE_OUTPUTS",	0x6ef9},
	{"linux/matroxfb.h",	"MATROXFB_SET_OUTPUT_MODE",	0x6efa},
	{"linux/matroxfb.h",	"MATROXFB_GET_OUTPUT_MODE",	0x6efa},
	{"linux/matroxfb.h",	"MATROXFB_GET_ALL_OUTPUTS",	0x6efb},
	{"linux/rtc.h",	"RTC_AIE_ON",	0x7001},
	{"linux/rtc.h",	"RTC_AIE_OFF",	0x7002},
	{"linux/rtc.h",	"RTC_UIE_ON",	0x7003},
	{"linux/rtc.h",	"RTC_UIE_OFF",	0x7004},
	{"linux/rtc.h",	"RTC_PIE_ON",	0x7005},
	{"linux/rtc.h",	"RTC_PIE_OFF",	0x7006},
	{"linux/rtc.h",	"RTC_ALM_SET",	0x7007},
	{"linux/rtc.h",	"RTC_ALM_READ",	0x7008},
	{"linux/rtc.h",	"RTC_RD_TIME",	0x7009},
	{"linux/rtc.h",	"RTC_SET_TIME",	0x700a},
	{"linux/rtc.h",	"RTC_IRQP_READ",	0x700b},
	{"linux/rtc.h",	"RTC_IRQP_SET",	0x700c},
	{"linux/rtc.h",	"RTC_EPOCH_READ",	0x700d},
	{"linux/rtc.h",	"RTC_EPOCH_SET",	0x700e},
	{"linux/rtc.h",	"RTC_WIE_ON",	0x700f},
	{"linux/rtc.h",	"RTC_WKALM_SET",	0x700f},
	{"linux/rtc.h",	"RTC_WIE_OFF",	0x7010},
	{"linux/rtc.h",	"RTC_WKALM_RD",	0x7010},
	{"linux/nvram.h",	"NVRAM_INIT",	0x7040},
	{"linux/nvram.h",	"NVRAM_SETCKS",	0x7041},
	{"linux/ppdev.h",	"PPSETMODE",	0x7080},
	{"linux/ppdev.h",	"PPRSTATUS",	0x7081},
	{"linux/ppdev.h",	"PPRCONTROL",	0x7083},
	{"linux/ppdev.h",	"PPWCONTROL",	0x7084},
	{"linux/ppdev.h",	"PPRDATA",	0x7085},
	{"linux/ppdev.h",	"PPWDATA",	0x7086},
	{"linux/ppdev.h",	"PPCLAIM",	0x708b},
	{"linux/ppdev.h",	"PPRELEASE",	0x708c},
	{"linux/ppdev.h",	"PPYIELD",	0x708d},
	{"linux/ppdev.h",	"PPFCONTROL",	0x708e},
	{"linux/ppdev.h",	"PPEXCL",	0x708f},
	{"linux/ppdev.h",	"PPDATADIR",	0x7090},
	{"linux/ppdev.h",	"PPNEGOT",	0x7091},
	{"linux/ppdev.h",	"PPWCTLONIRQ",	0x7092},
	{"linux/ppdev.h",	"PPCLRIRQ",	0x7093},
	{"linux/ppdev.h",	"PPSETPHASE",	0x7094},
	{"linux/ppdev.h",	"PPGETTIME",	0x7095},
	{"linux/ppdev.h",	"PPSETTIME",	0x7096},
	{"linux/serio.h",	"SPIOCSTYPE",	0x7101},
	{"linux/telephony.h",	"PHONE_CAPABILITIES",	0x7180},
	{"linux/telephony.h",	"PHONE_CAPABILITIES_LIST",	0x7181},
	{"linux/telephony.h",	"PHONE_CAPABILITIES_CHECK",	0x7182},
	{"linux/telephony.h",	"PHONE_RING",	0x7183},
	{"linux/telephony.h",	"PHONE_HOOKSTATE",	0x7184},
	{"linux/telephony.h",	"PHONE_MAXRINGS",	0x7185},
	{"linux/telephony.h",	"PHONE_RING_CADENCE",	0x7186},
	{"linux/telephony.h",	"OLD_PHONE_RING_START",	0x7187},
	{"linux/telephony.h",	"PHONE_RING_START",	0x7187},
	{"linux/telephony.h",	"PHONE_RING_STOP",	0x7188},
	{"linux/telephony.h",	"PHONE_REC_CODEC",	0x7189},
	{"linux/telephony.h",	"PHONE_REC_START",	0x718a},
	{"linux/telephony.h",	"PHONE_REC_STOP",	0x718b},
	{"linux/telephony.h",	"PHONE_REC_DEPTH",	0x718c},
	{"linux/telephony.h",	"PHONE_FRAME",	0x718d},
	{"linux/telephony.h",	"PHONE_REC_VOLUME",	0x718e},
	{"linux/telephony.h",	"PHONE_REC_LEVEL",	0x718f},
	{"linux/telephony.h",	"PHONE_PLAY_CODEC",	0x7190},
	{"linux/telephony.h",	"PHONE_PLAY_START",	0x7191},
	{"linux/telephony.h",	"PHONE_PLAY_STOP",	0x7192},
	{"linux/telephony.h",	"PHONE_PLAY_DEPTH",	0x7193},
	{"linux/telephony.h",	"PHONE_PLAY_VOLUME",	0x7194},
	{"linux/telephony.h",	"PHONE_PLAY_LEVEL",	0x7195},
	{"linux/telephony.h",	"PHONE_DTMF_READY",	0x7196},
	{"linux/telephony.h",	"PHONE_GET_DTMF",	0x7197},
	{"linux/telephony.h",	"PHONE_GET_DTMF_ASCII",	0x7198},
	{"linux/telephony.h",	"PHONE_DTMF_OOB",	0x7199},
	{"linux/telephony.h",	"PHONE_EXCEPTION",	0x719a},
	{"linux/telephony.h",	"PHONE_PLAY_TONE",	0x719b},
	{"linux/telephony.h",	"PHONE_SET_TONE_ON_TIME",	0x719c},
	{"linux/telephony.h",	"PHONE_SET_TONE_OFF_TIME",	0x719d},
	{"linux/telephony.h",	"PHONE_GET_TONE_ON_TIME",	0x719e},
	{"linux/telephony.h",	"PHONE_GET_TONE_OFF_TIME",	0x719f},
	{"linux/telephony.h",	"PHONE_GET_TONE_STATE",	0x71a0},
	{"linux/telephony.h",	"PHONE_BUSY",	0x71a1},
	{"linux/telephony.h",	"PHONE_RINGBACK",	0x71a2},
	{"linux/telephony.h",	"PHONE_DIALTONE",	0x71a3},
	{"linux/telephony.h",	"PHONE_CPT_STOP",	0x71a4},
	{"linux/telephony.h",	"PHONE_PSTN_SET_STATE",	0x71a4},
	{"linux/telephony.h",	"PHONE_PSTN_GET_STATE",	0x71a5},
	{"linux/telephony.h",	"PHONE_WINK_DURATION",	0x71a6},
	{"linux/telephony.h",	"PHONE_QUERY_CODEC",	0x71a7},
	{"linux/telephony.h",	"PHONE_PSTN_LINETEST",	0x71a8},
	{"linux/telephony.h",	"PHONE_VAD",	0x71a9},
	{"linux/ixjuser.h",	"IXJCTL_DSP_RESET",	0x71c0},
	{"linux/ixjuser.h",	"IXJCTL_CARDTYPE",	0x71c1},
	{"linux/ixjuser.h",	"IXJCTL_SERIAL",	0x71c2},
	{"linux/ixjuser.h",	"IXJCTL_DSP_TYPE",	0x71c3},
	{"linux/ixjuser.h",	"IXJCTL_DSP_VERSION",	0x71c4},
	{"linux/ixjuser.h",	"IXJCTL_DSP_IDLE",	0x71c5},
	{"linux/ixjuser.h",	"IXJCTL_TESTRAM",	0x71c6},
	{"linux/ixjuser.h",	"IXJCTL_SET_FILTER",	0x71c7},
	{"linux/ixjuser.h",	"IXJCTL_GET_FILTER_HIST",	0x71c8},
	{"linux/ixjuser.h",	"IXJCTL_INIT_TONE",	0x71c9},
	{"linux/ixjuser.h",	"IXJCTL_TONE_CADENCE",	0x71ca},
	{"linux/ixjuser.h",	"IXJCTL_AEC_START",	0x71cb},
	{"linux/ixjuser.h",	"IXJCTL_AEC_STOP",	0x71cc},
	{"linux/ixjuser.h",	"IXJCTL_AEC_GET_LEVEL",	0x71cd},
	{"linux/ixjuser.h",	"IXJCTL_SET_LED",	0x71ce},
	{"linux/ixjuser.h",	"IXJCTL_MIXER",	0x71cf},
	{"linux/ixjuser.h",	"IXJCTL_DAA_COEFF_SET",	0x71d0},
	{"linux/ixjuser.h",	"IXJCTL_PORT",	0x71d1},
	{"linux/ixjuser.h",	"IXJCTL_DAA_AGAIN",	0x71d2},
	{"linux/ixjuser.h",	"IXJCTL_PSTN_LINETEST",	0x71d3},
	{"linux/ixjuser.h",	"IXJCTL_CID",	0x71d4},
	{"linux/ixjuser.h",	"IXJCTL_POTS_PSTN",	0x71d5},
	{"linux/ixjuser.h",	"IXJCTL_FILTER_CADENCE",	0x71d6},
	{"linux/ixjuser.h",	"IXJCTL_PLAY_CID",	0x71d7},
	{"linux/ixjuser.h",	"IXJCTL_VMWI",	0x71d8},
	{"linux/ixjuser.h",	"IXJCTL_CIDCW",	0x71d9},
	{"linux/ixjuser.h",	"IXJCTL_VERSION",	0x71da},
	{"linux/ixjuser.h",	"IXJCTL_HZ",	0x71e0},
	{"linux/ixjuser.h",	"IXJCTL_RATE",	0x71e1},
	{"linux/ixjuser.h",	"IXJCTL_FRAMES_READ",	0x71e2},
	{"linux/ixjuser.h",	"IXJCTL_FRAMES_WRITTEN",	0x71e3},
	{"linux/ixjuser.h",	"IXJCTL_READ_WAIT",	0x71e4},
	{"linux/ixjuser.h",	"IXJCTL_WRITE_WAIT",	0x71e5},
	{"linux/ixjuser.h",	"IXJCTL_DRYBUFFER_READ",	0x71e6},
	{"linux/ixjuser.h",	"IXJCTL_DRYBUFFER_CLEAR",	0x71e7},
	{"linux/ixjuser.h",	"IXJCTL_INTERCOM_START",	0x71fd},
	{"linux/ixjuser.h",	"IXJCTL_INTERCOM_STOP",	0x71fe},
	{"linux/msdos_fs.h",	"VFAT_IOCTL_READDIR_BOTH",	0x7201},
	{"linux/msdos_fs.h",	"VFAT_IOCTL_READDIR_SHORT",	0x7202},
	{"linux/cdk.h",	"STL_BINTR",	0x7314},
	{"linux/cdk.h",	"STL_BSTART",	0x7315},
	{"linux/cdk.h",	"STL_BSTOP",	0x7316},
	{"linux/cdk.h",	"STL_BRESET",	0x7317},
	{"linux/cdk.h",	"STL_GETPFLAG",	0x7350},
	{"linux/cdk.h",	"STL_SETPFLAG",	0x7351},
	{"linux/if_ppp.h",	"PPPIOCGCHAN",	0x7437},
	{"linux/if_ppp.h",	"PPPIOCATTCHAN",	0x7438},
	{"linux/if_ppp.h",	"PPPIOCDISCONN",	0x7439},
	{"linux/if_ppp.h",	"PPPIOCCONNECT",	0x743a},
	{"linux/if_ppp.h",	"PPPIOCSMRRU",	0x743b},
	{"linux/if_ppp.h",	"PPPIOCDETACH",	0x743c},
	{"linux/if_ppp.h",	"PPPIOCATTACH",	0x743d},
	{"linux/if_ppp.h",	"PPPIOCNEWUNIT",	0x743e},
	{"linux/if_ppp.h",	"PPPIOCGIDLE",	0x743f},
	{"linux/if_ppp.h",	"PPPIOCSDEBUG",	0x7440},
	{"linux/if_ppp.h",	"PPPIOCGDEBUG",	0x7441},
	{"linux/if_ppp.h",	"PPPIOCSNPMODE",	0x744b},
	{"linux/if_ppp.h",	"PPPIOCGNPMODE",	0x744c},
	{"linux/if_ppp.h",	"PPPIOCSCOMPRESS",	0x744d},
	{"linux/if_ppp.h",	"PPPIOCXFERUNIT",	0x744e},
	{"linux/if_ppp.h",	"PPPIOCSXASYNCMAP",	0x744f},
	{"linux/if_ppp.h",	"PPPIOCGXASYNCMAP",	0x7450},
	{"linux/if_ppp.h",	"PPPIOCSMAXCID",	0x7451},
	{"linux/if_ppp.h",	"PPPIOCSMRU",	0x7452},
	{"linux/if_ppp.h",	"PPPIOCGMRU",	0x7453},
	{"linux/if_ppp.h",	"PPPIOCSRASYNCMAP",	0x7454},
	{"linux/if_ppp.h",	"PPPIOCGRASYNCMAP",	0x7455},
	{"linux/if_ppp.h",	"PPPIOCGUNIT",	0x7456},
	{"linux/if_ppp.h",	"PPPIOCSASYNCMAP",	0x7457},
	{"linux/if_ppp.h",	"PPPIOCGASYNCMAP",	0x7458},
	{"linux/if_ppp.h",	"PPPIOCSFLAGS",	0x7459},
	{"linux/if_ppp.h",	"PPPIOCGFLAGS",	0x745a},
	{"linux/jffs.h",	"JFFS_PRINT_HASH",	0x745a},
	{"linux/jffs.h",	"JFFS_PRINT_TREE",	0x745b},
	{"linux/jffs.h",	"JFFS_GET_STATUS",	0x745c},
	{"linux/isdn_ppp.h",	"PPPIOCGCALLINFO",	0x7480},
	{"linux/isdn_ppp.h",	"PPPIOCBUNDLE",	0x7481},
	{"linux/isdn_ppp.h",	"PPPIOCGMPFLAGS",	0x7482},
	{"linux/isdn_ppp.h",	"PPPIOCSMPFLAGS",	0x7483},
	{"linux/isdn_ppp.h",	"PPPIOCSMPMTU",	0x7484},
	{"linux/isdn_ppp.h",	"PPPIOCSMPMRU",	0x7485},
	{"linux/isdn_ppp.h",	"PPPIOCGCOMPRESSORS",	0x7486},
	{"linux/isdn_ppp.h",	"PPPIOCSCOMPRESSOR",	0x7487},
	{"linux/isdn_ppp.h",	"PPPIOCGIFNAME",	0x7488},
	{"linux/toshiba.h",	"TOSH_SMM",	0x7490},
	{"linux/smb_fs.h",	"SMB_IOC_GETMOUNTUID",	0x7501},
	{"linux/smb_fs.h",	"SMB_IOC_NEWCONN",	0x7502},
	{"linux/smb_fs.h",	"SMB_IOC_GETMOUNTUID32",	0x7503},
	{"linux/ext2_fs.h",	"EXT2_IOC_GETVERSION",	0x7601},
	{"linux/videodev.h",	"VIDIOCGCAP",	0x7601},
	{"linux/ext2_fs.h",	"EXT2_IOC_SETVERSION",	0x7602},
	{"linux/videodev.h",	"VIDIOCGCHAN",	0x7602},
	{"linux/videodev.h",	"VIDIOCSCHAN",	0x7603},
	{"linux/videodev.h",	"VIDIOCGTUNER",	0x7604},
	{"linux/videodev.h",	"VIDIOCSTUNER",	0x7605},
	{"linux/videodev.h",	"VIDIOCGPICT",	0x7606},
	{"linux/videodev.h",	"VIDIOCSPICT",	0x7607},
	{"linux/videodev.h",	"VIDIOCCAPTURE",	0x7608},
	{"linux/videodev.h",	"VIDIOCGWIN",	0x7609},
	{"linux/videodev.h",	"VIDIOCSWIN",	0x760a},
	{"linux/videodev.h",	"VIDIOCGFBUF",	0x760b},
	{"linux/videodev.h",	"VIDIOCSFBUF",	0x760c},
	{"linux/videodev.h",	"VIDIOCKEY",	0x760d},
	{"linux/videodev.h",	"VIDIOCGFREQ",	0x760e},
	{"linux/videodev.h",	"VIDIOCSFREQ",	0x760f},
	{"linux/videodev.h",	"VIDIOCGAUDIO",	0x7610},
	{"linux/videodev.h",	"VIDIOCSAUDIO",	0x7611},
	{"linux/videodev.h",	"VIDIOCSYNC",	0x7612},
	{"linux/videodev.h",	"VIDIOCMCAPTURE",	0x7613},
	{"linux/videodev.h",	"VIDIOCGMBUF",	0x7614},
	{"linux/videodev.h",	"VIDIOCGUNIT",	0x7615},
	{"linux/videodev.h",	"VIDIOCGCAPTURE",	0x7616},
	{"linux/videodev.h",	"VIDIOCSCAPTURE",	0x7617},
	{"linux/videodev.h",	"VIDIOCSPLAYMODE",	0x7618},
	{"linux/videodev.h",	"VIDIOCSWRITEMODE",	0x7619},
	{"linux/videodev.h",	"VIDIOCGPLAYINFO",	0x761a},
	{"linux/videodev.h",	"VIDIOCSMICROCODE",	0x761b},
	{"linux/videodev.h",	"VIDIOCGVBIFMT",	0x761c},
	{"linux/videodev.h",	"VIDIOCSVBIFMT",	0x761d},
	{"linux/dn.h",	"SIOCSNETADDR",	0x89e0},
	{"linux/dn.h",	"OSIOCSNETADDR",	0x89e0},
	{"linux/dn.h",	"SIOCGNETADDR",	0x89e1},
	{"linux/dn.h",	"OSIOCGNETADDR",	0x89e1},
	{"linux/auto_fs.h",	"AUTOFS_IOC_READY",	0x9360},
	{"linux/auto_fs.h",	"AUTOFS_IOC_FAIL",	0x9361},
	{"linux/auto_fs.h",	"AUTOFS_IOC_CATATONIC",	0x9362},
	{"linux/auto_fs.h",	"AUTOFS_IOC_PROTOVER",	0x9363},
	{"linux/auto_fs.h",	"AUTOFS_IOC_SETTIMEOUT",	0x9364},
	{"linux/auto_fs.h",	"AUTOFS_IOC_EXPIRE",	0x9365},
	{"linux/auto_fs4.h",	"AUTOFS_IOC_EXPIRE_MULTI",	0x9366},
	{"linux/nbd.h",	"NBD_SET_SOCK",	0xab00},
	{"linux/nbd.h",	"NBD_SET_BLKSIZE",	0xab01},
	{"linux/nbd.h",	"NBD_SET_SIZE",	0xab02},
	{"linux/nbd.h",	"NBD_DO_IT",	0xab03},
	{"linux/nbd.h",	"NBD_CLEAR_SOCK",	0xab04},
	{"linux/nbd.h",	"NBD_CLEAR_QUE",	0xab05},
	{"linux/nbd.h",	"NBD_PRINT_DEBUG",	0xab06},
	{"linux/nbd.h",	"NBD_SET_SIZE_BLOCKS",	0xab07},
	{"linux/nbd.h",	"NBD_DISCONNECT",	0xab08},
	{"linux/raw.h",	"RAW_SETBIND",	0xac00},
	{"linux/raw.h",	"RAW_GETBIND",	0xac01},
	{"linux/if_pppox.h",	"PPPOEIOCSFWD",	0xb100},
	{"linux/if_pppox.h",	"PPPOEIOCDFWD",	0xb101},
	{"linux/lvm.h",	"VG_CREATE",	0xfe00},
	{"linux/lvm.h",	"VG_REMOVE",	0xfe01},
	{"linux/lvm.h",	"VG_EXTEND",	0xfe03},
	{"linux/lvm.h",	"VG_REDUCE",	0xfe04},
	{"linux/lvm.h",	"VG_STATUS",	0xfe05},
	{"linux/lvm.h",	"VG_STATUS_GET_COUNT",	0xfe06},
	{"linux/lvm.h",	"VG_STATUS_GET_NAMELIST",	0xfe07},
	{"linux/lvm.h",	"VG_SET_EXTENDABLE",	0xfe08},
	{"linux/lvm.h",	"VG_RENAME",	0xfe09},
	{"linux/lvm.h",	"LV_CREATE",	0xfe20},
	{"linux/lvm.h",	"LV_REMOVE",	0xfe21},
	{"linux/lvm.h",	"LV_ACTIVATE",	0xfe22},
	{"linux/lvm.h",	"LV_DEACTIVATE",	0xfe23},
	{"linux/lvm.h",	"LV_EXTEND",	0xfe24},
	{"linux/lvm.h",	"LV_REDUCE",	0xfe25},
	{"linux/lvm.h",	"LV_STATUS_BYNAME",	0xfe26},
	{"linux/lvm.h",	"LV_STATUS_BYINDEX",	0xfe27},
	{"linux/lvm.h",	"LV_SET_ACCESS",	0xfe28},
	{"linux/lvm.h",	"LV_SET_ALLOCATION",	0xfe29},
	{"linux/lvm.h",	"LV_SET_STATUS",	0xfe2a},
	{"linux/lvm.h",	"LE_REMAP",	0xfe2b},
	{"linux/lvm.h",	"LV_SNAPSHOT_USE_RATE",	0xfe2c},
	{"linux/lvm.h",	"LV_STATUS_BYDEV",	0xfe2e},
	{"linux/lvm.h",	"LV_RENAME",	0xfe2f},
	{"linux/lvm.h",	"LV_BMAP",	0xfe30},
	{"linux/lvm.h",	"PV_STATUS",	0xfe40},
	{"linux/lvm.h",	"PV_CHANGE",	0xfe41},
	{"linux/lvm.h",	"PV_FLUSH",	0xfe42},
	{"linux/lvm.h",	"PE_LOCK_UNLOCK",	0xfe50},
	{"linux/lvm.h",	"LVM_GET_IOP_VERSION",	0xfe98},
	{"linux/lvm.h",	"LVM_RESET",	0xfe99},
	{"linux/lvm.h",	"LVM_LOCK_LVM",	0xff00},


