/*
 * Automatically generated by ./../syscalls.pl on Thu Mar  8 18:14:07 2001
 */

#define sys_syscall printargs
int sys_exit();
int sys_fork();
int sys_read();
int sys_write();
int sys_open();
int sys_close();
int sys_wait4();
int sys_creat();
int sys_link();
int sys_unlink();
int sys_chdir();
int sys_fchdir();
int sys_mknod();
int sys_chmod();
int sys_chown();
#define sys_break printargs
#define sys_getfsstat printargs
int sys_lseek();
int sys_getpid();
#define sys_mount printargs
#define sys_unmount printargs
#define sys_setuid printargs
int sys_getuid();
#define sys_geteuid printargs
int sys_ptrace();
int sys_recvmsg();
int sys_sendmsg();
int sys_recvfrom();
int sys_accept();
int sys_getpeername();
int sys_getsockname();
int sys_access();
int sys_chflags();
int sys_fchflags();
#define sys_sync printargs
int sys_kill();
int sys_stat();
#define sys_getppid printargs
int sys_lstat();
int sys_dup();
int sys_pipe();
#define sys_getegid printargs
#define sys_profil printargs
#define sys_ktrace printargs
int sys_sigaction();
int sys_getgid();
int sys_sigprocmask();
#define sys_getlogin printargs
#define sys_setlogin printargs
#define sys_acct printargs
int sys_sigpending();
int sys_sigaltstack();
int sys_ioctl();
#define sys_reboot printargs
#define sys_revoke printargs
int sys_symlink();
int sys_readlink();
int sys_execve();
int sys_umask();
int sys_chroot();
int sys_fstat();
#define sys_getkerninfo printargs
int sys_getpagesize();
int sys_msync();
int sys_vfork();
int sys_sbrk();
#define sys_sstk printargs
int sys_mmap();
#define sys_vadvise printargs
int sys_munmap();
int sys_mprotect();
#define sys_madvise printargs
int sys_mincore();
int sys_getgroups();
int sys_setgroups();
int sys_getpgrp();
int sys_setpgid();
int sys_setitimer();
int sys_wait();
#define sys_swapon printargs
int sys_getitimer();
int sys_gethostname();
int sys_sethostname();
int sys_getdtablesize();
int sys_dup2();
int sys_fcntl();
int sys_select();
int sys_fsync();
int sys_setpriority();
int sys_socket();
int sys_connect();
int sys_accept();
int sys_getpriority();
int sys_send();
int sys_recv();
#define sys_sigreturn printargs
int sys_bind();
int sys_setsockopt();
int sys_listen();
int sys_sigvec();
int sys_sigblock();
int sys_sigsetmask();
int sys_sigsuspend();
int sys_sigstack();
int sys_recvmsg();
int sys_sendmsg();
int sys_gettimeofday();
int sys_getrusage();
int sys_getsockopt();
int sys_readv();
int sys_writev();
int sys_settimeofday();
int sys_fchown();
int sys_fchmod();
int sys_recvfrom();
int sys_setreuid();
int sys_setregid();
int sys_rename();
int sys_truncate();
int sys_ftruncate();
int sys_flock();
int sys_mkfifo();
int sys_sendto();
int sys_shutdown();
int sys_socketpair();
int sys_mkdir();
int sys_rmdir();
int sys_utimes();
int sys_adjtime();
int sys_getpeername();
int sys_gethostid();
#define sys_sethostid printargs
int sys_getrlimit();
int sys_setrlimit();
int sys_killpg();
int sys_setsid();
int sys_quotactl();
#define sys_quota printargs
int sys_getsockname();
#define sys_nfssvc printargs
int sys_getdirentries();
int sys_statfs();
int sys_fstatfs();
#define sys_getfh printargs
int sys_getdomainname();
int sys_setdomainname();
int sys_uname();
#define sys_sysarch printargs
#define sys_rtprio printargs
#define sys_semsys printargs
#define sys_msgsys printargs
#define sys_shmsys printargs
int sys_pread();
int sys_pwrite();
#define sys_ntp_adjtime printargs
#define sys_setgid printargs
#define sys_setegid printargs
#define sys_seteuid printargs
int sys_stat();
int sys_fstat();
int sys_lstat();
int sys_pathconf();
int sys_fpathconf();
int sys_getrlimit();
int sys_setrlimit();
int sys_getdirentries();
int sys_mmap();
#define sys___syscall printargs
int sys_lseek();
int sys_truncate();
int sys_ftruncate();
int sys___sysctl();
#define sys_mlock printargs
#define sys_munlock printargs
#define sys_undelete printargs
#define sys_futimes printargs
int sys_getpgid();
int sys_poll();
#define sys___semctl printargs
int sys_semget();
int sys_semop();
int sys_msgctl();
int sys_msgget();
int sys_msgsnd();
int sys_msgrcv();
int sys_shmat();
int sys_shmctl();
int sys_shmdt();
int sys_shmget();
#define sys_clock_gettime printargs
#define sys_clock_settime printargs
#define sys_clock_getres printargs
#define sys_nanosleep printargs
#define sys_minherit printargs
#define sys_rfork printargs
#define sys_openbsd_poll printargs
#define sys_issetugid printargs
#define sys_lchown printargs
int sys_getdents();
#define sys_lchmod printargs
#define sys_netbsd_lchown printargs
#define sys_lutimes printargs
#define sys_netbsd_msync printargs
#define sys_nstat printargs
#define sys_nfstat printargs
#define sys_nlstat printargs
#define sys_fhstatfs printargs
#define sys_fhopen printargs
#define sys_fhstat printargs
#define sys_modnext printargs
#define sys_modstat printargs
#define sys_modfnext printargs
#define sys_modfind printargs
#define sys_kldload printargs
#define sys_kldunload printargs
#define sys_kldfind printargs
#define sys_kldnext printargs
#define sys_kldstat printargs
#define sys_kldfirstmod printargs
int sys_getsid();
int sys_setresuid();
int sys_setresgid();
#define sys_aio_return printargs
#define sys_aio_suspend printargs
#define sys_aio_cancel printargs
#define sys_aio_error printargs
#define sys_aio_read printargs
#define sys_aio_write printargs
#define sys_lio_listio printargs
#define sys_yield printargs
#define sys_thr_sleep printargs
#define sys_thr_wakeup printargs
#define sys_mlockall printargs
#define sys_munlockall printargs
int sys___getcwd();
#define sys_sched_setparam printargs
#define sys_sched_getparam printargs
#define sys_sched_setscheduler printargs
#define sys_sched_getscheduler printargs
#define sys_sched_yield printargs
#define sys_sched_get_priority_max printargs
#define sys_sched_get_priority_min printargs
#define sys_sched_rr_get_interval printargs
#define sys_utrace printargs
int sys_sendfile();
#define sys_kldsym printargs
#define sys_jail printargs
int sys_sigprocmask();
int sys_sigsuspend();
int sys_sigaction();
int sys_sigpending();
#define sys_sigreturn printargs
#define sys___acl_get_file printargs
#define sys___acl_set_file printargs
#define sys___acl_get_fd printargs
#define sys___acl_set_fd printargs
#define sys___acl_delete_file printargs
#define sys___acl_delete_fd printargs
#define sys___acl_aclcheck_file printargs
#define sys___acl_aclcheck_fd printargs
#define sys_extattrctl printargs
#define sys_extattr_set_file printargs
#define sys_extattr_get_file printargs
#define sys_extattr_delete_file printargs
#define sys_aio_waitcomplete printargs
#define sys_getresuid printargs
#define sys_getresgid printargs
#define sys_kqueue printargs
#define sys_kevent printargs
