{"sys/timepps.h", "PPS_IOC_CREATE", 0x20003101},
{"sys/timepps.h", "PPS_IOC_DESTROY", 0x20003102},
{"machine/pcaudioio.h", "AUDIO_DRAIN", 0x20004103},
{"machine/pcaudioio.h", "AUDIO_FLUSH", 0x20004104},
{"sys/dataacq.h", "AD_SUPPORTED_GAINS", 0x20004105},
{"sys/dataacq.h", "AD_GAINS_SET", 0x20004106},
{"sys/dataacq.h", "AD_GAINS_GET", 0x20004107},
{"net/bpf.h", "BIOCFLUSH", 0x20004268},
{"net/bpf.h", "BIOCPROMISC", 0x20004269},
{"sys/soundcard.h", "SNDCTL_COPR_RESET", 0x20004300},
{"machine/soundcard.h", "SNDCTL_COPR_RESET", 0x20004300},
{"machine/pcvt_ioctl.h", "KBDRESET", 0x20004b01},
{"sys/kbio.h", "KDSKBMODE", 0x20004b07},
{"machine/pcvt_ioctl.h", "KDSKBMODE", 0x20004b07},
{"sys/kbio.h", "KDMKTONE", 0x20004b08},
{"machine/pcvt_ioctl.h", "KDMKTONE", 0x20004b08},
{"machine/pcvt_ioctl.h", "KDSETMODE", 0x20004b0a},
{"sys/consio.h", "KDSETMODE", 0x20004b0a},
{"sys/consio.h", "KDSBORDER", 0x20004b0d},
{"machine/pcvt_ioctl.h", "KBDDEFAULT", 0x20004b14},
{"sys/kbio.h", "KDSKBSTATE", 0x20004b14},
{"machine/pcvt_ioctl.h", "KDENABIO", 0x20004b3c},
{"sys/kbio.h", "KDENABIO", 0x20004b3c},
{"sys/kbio.h", "KDDISABIO", 0x20004b3d},
{"machine/pcvt_ioctl.h", "KDDISABIO", 0x20004b3d},
{"sys/kbio.h", "KIOCSOUND", 0x20004b3f},
{"sys/kbio.h", "KDSETLED", 0x20004b42},
{"machine/pcvt_ioctl.h", "KDSETLED", 0x20004b42},
{"machine/pcvt_ioctl.h", "KDSETRAD", 0x20004b43},
{"sys/kbio.h", "KDSETRAD", 0x20004b43},
{"machine/pcaudioio.h", "AUDIO_COMPAT_FLUSH", 0x20005000},
{"sys/soundcard.h", "SNDCTL_DSP_RESET", 0x20005000},
{"machine/soundcard.h", "SNDCTL_DSP_RESET", 0x20005000},
{"sys/soundcard.h", "SNDCTL_DSP_SYNC", 0x20005001},
{"machine/soundcard.h", "SNDCTL_DSP_SYNC", 0x20005001},
{"machine/pcaudioio.h", "AUDIO_COMPAT_DRAIN", 0x20005001},
{"machine/apm_bios.h", "APMIO_SUSPEND", 0x20005001},
{"machine/apm_bios.h", "APMIO_ENABLE", 0x20005005},
{"machine/apm_bios.h", "APMIO_DISABLE", 0x20005006},
{"machine/apm_bios.h", "APMIO_HALTCPU", 0x20005007},
{"sys/soundcard.h", "SNDCTL_DSP_POST", 0x20005008},
{"machine/soundcard.h", "SNDCTL_DSP_POST", 0x20005008},
{"machine/apm_bios.h", "APMIO_NOTHALTCPU", 0x20005008},
{"machine/apm_bios.h", "APMIO_STANDBY", 0x2000500c},
{"machine/soundcard.h", "SNDCTL_DSP_NONBLOCK", 0x2000500e},
{"sys/soundcard.h", "SNDCTL_DSP_NONBLOCK", 0x2000500e},
{"machine/soundcard.h", "SNDCTL_DSP_SETSYNCRO", 0x20005015},
{"sys/soundcard.h", "SNDCTL_DSP_SETSYNCRO", 0x20005015},
{"machine/apm_bios.h", "APMIO_REJECTLASTREQ", 0x20005065},
{"machine/soundcard.h", "SNDCTL_SEQ_RESET", 0x20005100},
{"sys/soundcard.h", "SNDCTL_SEQ_RESET", 0x20005100},
{"sys/soundcard.h", "SNDCTL_SEQ_SYNC", 0x20005101},
{"machine/soundcard.h", "SNDCTL_SEQ_SYNC", 0x20005101},
{"machine/soundcard.h", "SNDCTL_SEQ_PANIC", 0x20005111},
{"sys/soundcard.h", "SNDCTL_SEQ_PANIC", 0x20005111},
{"sys/consio.h", "SW_B40x25", 0x20005300},
{"sys/consio.h", "SW_C40x25", 0x20005301},
{"machine/speaker.h", "SPKRTUNE", 0x20005302},
{"sys/consio.h", "SW_B80x25", 0x20005302},
{"sys/consio.h", "SW_C80x25", 0x20005303},
{"sys/consio.h", "SW_BG320", 0x20005304},
{"sys/consio.h", "SW_CG320", 0x20005305},
{"sys/consio.h", "SW_BG640", 0x20005306},
{"sys/consio.h", "SW_EGAMONO80x25", 0x20005307},
{"machine/gsc.h", "GSC_SRESSW", 0x2000530b},
{"machine/asc_ioctl.h", "ASC_SRESSW", 0x2000530b},
{"sys/consio.h", "SW_CG320_D", 0x2000530d},
{"sys/consio.h", "SW_CG640_E", 0x2000530e},
{"sys/consio.h", "SW_EGAMONOAPA", 0x2000530f},
{"sys/consio.h", "SW_CG640x350", 0x20005310},
{"sys/consio.h", "SW_ENH_MONOAPA2", 0x20005311},
{"sys/consio.h", "SW_ENH_CG640", 0x20005312},
{"sys/consio.h", "SW_ENH_B40x25", 0x20005313},
{"sys/consio.h", "SW_ENH_C40x25", 0x20005314},
{"sys/consio.h", "SW_ENH_B80x25", 0x20005315},
{"sys/consio.h", "SW_ENH_C80x25", 0x20005316},
{"sys/consio.h", "SW_VGA_C40x25", 0x20005317},
{"sys/consio.h", "SW_VGA_C80x25", 0x20005318},
{"sys/consio.h", "SW_VGA_M80x25", 0x20005319},
{"sys/consio.h", "SW_VGA11", 0x2000531a},
{"sys/consio.h", "SW_BG640x480", 0x2000531a},
{"sys/consio.h", "SW_CG640x480", 0x2000531b},
{"sys/consio.h", "SW_VGA12", 0x2000531b},
{"sys/consio.h", "SW_VGA13", 0x2000531c},
{"sys/consio.h", "SW_VGA_CG320", 0x2000531c},
{"sys/consio.h", "SW_VGA_C80x50", 0x2000531e},
{"sys/consio.h", "SW_VGA_M80x50", 0x2000531f},
{"sys/consio.h", "SW_VGA_C80x30", 0x20005320},
{"sys/consio.h", "SW_VGA_M80x30", 0x20005321},
{"sys/consio.h", "SW_VGA_C80x60", 0x20005322},
{"sys/consio.h", "SW_VGA_M80x60", 0x20005323},
{"sys/consio.h", "SW_VGA_CG640", 0x20005324},
{"sys/consio.h", "SW_VGA_MODEX", 0x20005325},
{"sys/consio.h", "SW_VGA_C90x25", 0x20005328},
{"sys/consio.h", "SW_VGA_M90x25", 0x20005329},
{"sys/consio.h", "SW_VGA_C90x30", 0x2000532a},
{"sys/consio.h", "SW_VGA_M90x30", 0x2000532b},
{"sys/consio.h", "SW_VGA_C90x43", 0x2000532c},
{"sys/consio.h", "SW_VGA_M90x43", 0x2000532d},
{"sys/consio.h", "SW_VGA_C90x50", 0x2000532e},
{"sys/consio.h", "SW_VGA_M90x50", 0x2000532f},
{"sys/consio.h", "SW_VGA_C90x60", 0x20005330},
{"sys/consio.h", "SW_VGA_M90x60", 0x20005331},
{"sys/consio.h", "SW_PC98_80x25", 0x20005362},
{"sys/consio.h", "SW_PC98_80x30", 0x20005363},
{"sys/consio.h", "SW_ENH_B80x43", 0x20005370},
{"sys/consio.h", "SW_ENH_C80x43", 0x20005371},
{"sys/consio.h", "SW_TEXT_80x25", 0x200053c8},
{"sys/consio.h", "SW_TEXT_80x30", 0x200053c9},
{"sys/consio.h", "SW_TEXT_80x43", 0x200053ca},
{"sys/consio.h", "SW_TEXT_80x50", 0x200053cb},
{"sys/consio.h", "SW_TEXT_80x60", 0x200053cc},
{"sys/consio.h", "SW_TEXT_132x25", 0x200053cd},
{"sys/consio.h", "SW_TEXT_132x30", 0x200053ce},
{"sys/consio.h", "SW_TEXT_132x43", 0x200053cf},
{"sys/consio.h", "SW_TEXT_132x50", 0x200053d0},
{"sys/consio.h", "SW_TEXT_132x60", 0x200053d1},
{"sys/consio.h", "SW_MCAMODE", 0x200053ff},
{"machine/soundcard.h", "SNDCTL_TMR_START", 0x20005402},
{"sys/soundcard.h", "SNDCTL_TMR_START", 0x20005402},
{"sys/soundcard.h", "SNDCTL_TMR_STOP", 0x20005403},
{"machine/soundcard.h", "SNDCTL_TMR_STOP", 0x20005403},
{"machine/soundcard.h", "SNDCTL_TMR_CONTINUE", 0x20005404},
{"sys/soundcard.h", "SNDCTL_TMR_CONTINUE", 0x20005404},
{"dev/usb/usb.h", "USB_DISCOVER", 0x20005503},
{"sys/consio.h", "SW_VESA_CG640x400", 0x20005600},
{"sys/consio.h", "SW_VESA_CG640x480", 0x20005601},
{"sys/consio.h", "SW_VESA_800x600", 0x20005602},
{"sys/consio.h", "SW_VESA_CG800x600", 0x20005603},
{"sys/consio.h", "SW_VESA_1024x768", 0x20005604},
{"sys/consio.h", "SW_VESA_CG1024x768", 0x20005605},
{"sys/consio.h", "SW_VESA_1280x1024", 0x20005606},
{"sys/consio.h", "SW_VESA_CG1280x1024", 0x20005607},
{"sys/consio.h", "SW_VESA_C80x60", 0x20005608},
{"sys/consio.h", "SW_VESA_C132x25", 0x20005609},
{"sys/consio.h", "SW_VESA_C132x43", 0x2000560a},
{"sys/consio.h", "SW_VESA_C132x50", 0x2000560b},
{"sys/consio.h", "SW_VESA_C132x60", 0x2000560c},
{"sys/consio.h", "SW_VESA_32K_320", 0x2000560d},
{"sys/consio.h", "SW_VESA_64K_320", 0x2000560e},
{"sys/consio.h", "SW_VESA_FULL_320", 0x2000560f},
{"sys/consio.h", "SW_VESA_32K_640", 0x20005610},
{"sys/consio.h", "SW_VESA_64K_640", 0x20005611},
{"sys/consio.h", "SW_VESA_FULL_640", 0x20005612},
{"sys/consio.h", "SW_VESA_32K_800", 0x20005613},
{"sys/consio.h", "SW_VESA_64K_800", 0x20005614},
{"sys/consio.h", "SW_VESA_FULL_800", 0x20005615},
{"sys/consio.h", "SW_VESA_32K_1024", 0x20005616},
{"sys/consio.h", "SW_VESA_64K_1024", 0x20005617},
{"sys/consio.h", "SW_VESA_FULL_1024", 0x20005618},
{"sys/consio.h", "SW_VESA_32K_1280", 0x20005619},
{"sys/consio.h", "SW_VESA_64K_1280", 0x2000561a},
{"sys/consio.h", "SW_VESA_FULL_1280", 0x2000561b},
{"sys/wormio.h", "WORMIOCFINISHTRACK", 0x20005717},
{"sys/consio.h", "CONS_IO", 0x20006303},
{"sys/cdio.h", "CDIOCSETMONO", 0x2000630c},
{"sys/cdio.h", "CDIOCSETSTERIO", 0x2000630d},
{"sys/cdio.h", "CDIOCSETSTEREO", 0x2000630d},
{"sys/cdio.h", "CDIOCSETMUTE", 0x2000630e},
{"sys/cdio.h", "CDIOCSETLEFT", 0x2000630f},
{"sys/cdio.h", "CDIOCSETRIGHT", 0x20006310},
{"sys/cdio.h", "CDIOCSETDEBUG", 0x20006311},
{"sys/cdio.h", "CDIOCCLRDEBUG", 0x20006312},
{"sys/cdio.h", "CDIOCPAUSE", 0x20006313},
{"sys/cdio.h", "CDIOCRESUME", 0x20006314},
{"sys/cdio.h", "CDIOCRESET", 0x20006315},
{"sys/cdio.h", "CDIOCSTART", 0x20006316},
{"sys/cdio.h", "CDIOCSTOP", 0x20006317},
{"sys/cdio.h", "CDIOCEJECT", 0x20006318},
{"sys/cdio.h", "CDIOCALLOW", 0x2000631a},
{"sys/cdio.h", "CDIOCPREVENT", 0x2000631b},
{"sys/cdio.h", "CDIOCCLOSE", 0x2000631c},
{"sys/wormio.h", "CDRIOCBLANK", 0x20006364},
{"sys/cdrio.h", "CDRIOCBLANK", 0x20006364},
{"sys/cdrio.h", "CDRIOCOPENDISK", 0x20006366},
{"sys/cdrio.h", "CDRIOCCLOSEDISK", 0x20006367},
{"sys/consio.h", "CONS_SETWINORG", 0x20006368},
{"sys/cdrio.h", "CDRIOCCLOSETRACK", 0x20006369},
{"sys/consio.h", "CONS_SETKBD", 0x2000636e},
{"sys/consio.h", "CONS_RELKBD", 0x2000636f},
{"sys/filio.h", "FIOCLEX", 0x20006601},
{"sys/filio.h", "FIONCLEX", 0x20006602},
{"machine/iic.h", "I2CSTOP", 0x20006902},
{"sys/mtio.h", "MTIOCIEOT", 0x20006d03},
{"sys/mtio.h", "MTIOCEEOT", 0x20006d04},
{"machine/spigot.h", "SPIGOT_IOPL_ON", 0x20007306},
{"machine/spigot.h", "SPIGOT_IOPL_OFF", 0x20007307},
{"machine/cdk.h", "STL_BINTR", 0x20007314},
{"machine/cdk.h", "STL_BSTART", 0x20007315},
{"machine/cdk.h", "STL_BSTOP", 0x20007316},
{"machine/cdk.h", "STL_BRESET", 0x20007317},
{"sys/ioctl_compat.h", "TIOCHPCL", 0x20007402},
{"sys/ttycom.h", "TIOCEXCL", 0x2000740d},
{"sys/ttycom.h", "TIOCNXCL", 0x2000740e},
{"net/if_ppp.h", "PPPIOCXFERUNIT", 0x2000744e},
{"sys/ttycom.h", "TIOCDRAIN", 0x2000745e},
{"sys/ttycom.h", "TIOCSIG", 0x2000745f},
{"net/if_tun.h", "TUNSIFPID", 0x2000745f},
{"sys/ttycom.h", "TIOCSCTTY", 0x20007461},
{"sys/ioctl_compat.h", "OTIOCCONS", 0x20007462},
{"sys/ttycom.h", "TIOCSTAT", 0x20007465},
{"sys/ttycom.h", "TIOCSTART", 0x2000746e},
{"sys/ttycom.h", "TIOCSTOP", 0x2000746f},
{"sys/ttycom.h", "TIOCNOTTY", 0x20007471},
{"sys/ttycom.h", "TIOCCDTR", 0x20007478},
{"machine/pcvt_ioctl.h", "CONSOLE_X_MODE_ON", 0x20007479},
{"sys/ttycom.h", "TIOCSDTR", 0x20007479},
{"machine/pcvt_ioctl.h", "CONSOLE_X_MODE_OFF", 0x2000747a},
{"sys/ttycom.h", "TIOCCBRK", 0x2000747a},
{"sys/ttycom.h", "TIOCSBRK", 0x2000747b},
{"sys/consio.h", "VT_RELDISP", 0x20007604},
{"machine/pcvt_ioctl.h", "VT_RELDISP", 0x20007604},
{"sys/consio.h", "VT_ACTIVATE", 0x20007605},
{"machine/pcvt_ioctl.h", "VT_ACTIVATE", 0x20007605},
{"sys/consio.h", "VT_WAITACTIVE", 0x20007606},
{"machine/pcvt_ioctl.h", "VT_WAITACTIVE", 0x20007606},
{"machine/ioctl_ctx.h", "CTX_LIVE", 0x20007801},
{"machine/ioctl_ctx.h", "CTX_GRAB", 0x20007802},
{"machine/ioctl_ctx.h", "CTX_H_ORGANIZE", 0x20007803},
{"machine/ioctl_ctx.h", "CTX_V_ORGANIZE", 0x20007804},
{"cam/scsi/scsi_ses.h", "SESIOC_GETNOBJ", 0x20530001},
{"cam/scsi/scsi_ses.h", "SESIOC_GETOBJMAP", 0x20530002},
{"cam/scsi/scsi_ses.h", "SESIOC_GETENCSTAT", 0x20530003},
{"cam/scsi/scsi_ses.h", "SESIOC_SETENCSTAT", 0x20530004},
{"cam/scsi/scsi_ses.h", "SESIOC_GETOBJSTAT", 0x20530005},
{"cam/scsi/scsi_ses.h", "SESIOC_SETOBJSTAT", 0x20530006},
{"cam/scsi/scsi_ses.h", "SESIOC_GETTEXT", 0x20530007},
{"cam/scsi/scsi_ses.h", "SESIOC_INIT", 0x20530008},
{"machine/ioctl_meteor.h", "METEORGHUE", 0x40017806},
{"machine/ioctl_meteor.h", "METEORGCHCV", 0x40017809},
{"machine/ioctl_meteor.h", "METEORGBRIG", 0x4001780e},
{"machine/ioctl_meteor.h", "METEORGCSAT", 0x4001780f},
{"machine/ioctl_meteor.h", "METEORGCONT", 0x40017810},
{"machine/ioctl_meteor.h", "METEORGHWS", 0x40017812},
{"machine/ioctl_meteor.h", "METEORGVWS", 0x40017813},
{"machine/ioctl_meteor.h", "METEORGTS", 0x40017814},
{"machine/ioctl_bt848.h", "RADIO_GETMODE", 0x4001783a},
{"machine/random.h", "MEM_RETURNIRQ", 0x40027203},
{"machine/ioctl_meteor.h", "METEORSTATUS", 0x40027805},
{"machine/ioctl_meteor.h", "METEORGFPS", 0x4002780b},
{"machine/ioctl_meteor.h", "METEORGBT254", 0x40027811},
{"machine/ioctl_bt848.h", "REMOTE_GETKEY", 0x40037847},
{"sys/timepps.h", "PPS_IOC_GETCAP", 0x40043105},
{"machine/i4b_tel_ioctl.h", "I4B_TEL_GETAUDIOFMT", 0x40044100},
{"sys/dataacq.h", "AD_MICRO_PERIOD_GET", 0x40044102},
{"sys/dataacq.h", "AD_NGAINS_GET", 0x40044103},
{"sys/dataacq.h", "AD_NCHANS_GET", 0x40044104},
{"machine/soundcard.h", "AIONWRITE", 0x4004410a},
{"sys/soundcard.h", "AIONWRITE", 0x4004410a},
{"net/bpf.h", "BIOCGBLEN", 0x40044266},
{"net/bpf.h", "BIOCGDLT", 0x4004426a},
{"net/bpf.h", "BIOCVERSION", 0x40044271},
{"net/bpf.h", "BIOCGRSIG", 0x40044272},
{"net/bpf.h", "BIOCGHDRCMPLT", 0x40044274},
{"net/bpf.h", "BIOCGSEESENT", 0x40044276},
{"cam/scsi/scsi_targetio.h", "TARGIOCFETCHEXCEPTION", 0x40044301},
{"sys/fbio.h", "FBIOGVIDEO", 0x40044608},
{"sys/fbio.h", "FBIOGCURMAX", 0x4004461c},
{"machine/ioctl_fd.h", "FD_GOPTS", 0x40044640},
{"sys/fbio.h", "FBIO_ADAPTER", 0x40044664},
{"sys/fbio.h", "FBIO_ADPTYPE", 0x40044665},
{"sys/fbio.h", "FBIO_GETMODE", 0x40044669},
{"sys/fbio.h", "FBIO_GETWINORG", 0x4004466b},
{"sys/fbio.h", "FBIO_GETLINEWIDTH", 0x4004466f},
{"machine/joystick.h", "JOY_GETTIMEOUT", 0x40044a02},
{"sys/joystick.h", "JOY_GETTIMEOUT", 0x40044a02},
{"machine/joystick.h", "JOY_GET_X_OFFSET", 0x40044a05},
{"sys/joystick.h", "JOY_GET_X_OFFSET", 0x40044a05},
{"machine/joystick.h", "JOY_GET_Y_OFFSET", 0x40044a06},
{"sys/joystick.h", "JOY_GET_Y_OFFSET", 0x40044a06},
{"machine/pcvt_ioctl.h", "KBDGTPMAT", 0x40044b02},
{"machine/pcvt_ioctl.h", "KBDGREPSW", 0x40044b04},
{"machine/pcvt_ioctl.h", "KBDGLEDS", 0x40044b06},
{"sys/kbio.h", "KDGKBMODE", 0x40044b06},
{"machine/pcvt_ioctl.h", "KBDGLOCK", 0x40044b08},
{"sys/consio.h", "KDGETMODE", 0x40044b09},
{"sys/kbio.h", "KDGKBSTATE", 0x40044b13},
{"sys/kbio.h", "KDGKBTYPE", 0x40044b40},
{"sys/kbio.h", "KDGETLED", 0x40044b41},
{"machine/pcvt_ioctl.h", "KDGETLED", 0x40044b41},
{"machine/mouse.h", "MOUSE_GETLEVEL", 0x40044d04},
{"machine/soundcard.h", "SOUND_PCM_READ_RATE", 0x40045002},
{"sys/soundcard.h", "SOUND_PCM_READ_RATE", 0x40045002},
{"machine/soundcard.h", "SNDCTL_DSP_GETBLKSIZE", 0x40045004},
{"sys/soundcard.h", "SNDCTL_DSP_GETBLKSIZE", 0x40045004},
{"sys/soundcard.h", "SOUND_PCM_READ_BITS", 0x40045005},
{"machine/soundcard.h", "SOUND_PCM_READ_BITS", 0x40045005},
{"sys/soundcard.h", "SOUND_PCM_READ_CHANNELS", 0x40045006},
{"machine/soundcard.h", "SOUND_PCM_READ_CHANNELS", 0x40045006},
{"machine/soundcard.h", "SOUND_PCM_READ_FILTER", 0x40045007},
{"sys/soundcard.h", "SOUND_PCM_READ_FILTER", 0x40045007},
{"machine/soundcard.h", "SNDCTL_DSP_GETFMTS", 0x4004500b},
{"sys/soundcard.h", "SNDCTL_DSP_GETFMTS", 0x4004500b},
{"machine/soundcard.h", "SNDCTL_DSP_GETCAPS", 0x4004500f},
{"sys/soundcard.h", "SNDCTL_DSP_GETCAPS", 0x4004500f},
{"sys/soundcard.h", "SNDCTL_DSP_GETTRIGGER", 0x40045010},
{"machine/soundcard.h", "SNDCTL_DSP_GETTRIGGER", 0x40045010},
{"sys/soundcard.h", "SNDCTL_DSP_GETODELAY", 0x40045017},
{"machine/soundcard.h", "SNDCTL_DSP_GETODELAY", 0x40045017},
{"machine/soundcard.h", "SNDCTL_SEQ_GETOUTCOUNT", 0x40045104},
{"sys/soundcard.h", "SNDCTL_SEQ_GETOUTCOUNT", 0x40045104},
{"machine/soundcard.h", "SNDCTL_SEQ_GETINCOUNT", 0x40045105},
{"sys/soundcard.h", "SNDCTL_SEQ_GETINCOUNT", 0x40045105},
{"sys/soundcard.h", "SNDCTL_SEQ_NRSYNTHS", 0x4004510a},
{"machine/soundcard.h", "SNDCTL_SEQ_NRSYNTHS", 0x4004510a},
{"sys/soundcard.h", "SNDCTL_SEQ_NRMIDIS", 0x4004510b},
{"machine/soundcard.h", "SNDCTL_SEQ_NRMIDIS", 0x4004510b},
{"machine/gsc.h", "GSC_GRES", 0x40045301},
{"machine/asc_ioctl.h", "ASC_GRES", 0x40045301},
{"machine/asc_ioctl.h", "ASC_GWIDTH", 0x40045303},
{"machine/gsc.h", "GSC_GWIDTH", 0x40045303},
{"machine/asc_ioctl.h", "ASC_GHEIGHT", 0x40045305},
{"machine/gsc.h", "GSC_GHEIGHT", 0x40045305},
{"machine/asc_ioctl.h", "ASC_GBLEN", 0x40045307},
{"machine/gsc.h", "GSC_GBLEN", 0x40045307},
{"machine/gsc.h", "GSC_GBTIME", 0x40045309},
{"machine/asc_ioctl.h", "ASC_GBTIME", 0x40045309},
{"machine/i4b_trace.h", "I4B_TRC_GET", 0x40045400},
{"sys/ptio.h", "PTIOCGETTIMEOUT", 0x40045401},
{"sys/snoop.h", "SNPGTTY", 0x40045459},
{"dev/usb/usb.h", "USB_GET_CONFIG", 0x40045564},
{"dev/usb/usb.h", "USB_GET_CM_OVER_DATA", 0x40045582},
{"sys/wormio.h", "WORMIOERROR", 0x40045718},
{"sys/wormio.h", "WORMIOCREADSESSIONINFO", 0x4004571f},
{"sys/consio.h", "GIO_ATTR", 0x40046100},
{"sys/consio.h", "GIO_COLOR", 0x40046300},
{"sys/consio.h", "CONS_CURRENT", 0x40046301},
{"sys/consio.h", "CONS_GET", 0x40046302},
{"sys/cdio.h", "CDIOREADTOCHEADER", 0x40046304},
{"sys/chio.h", "CHIOGPICKER", 0x40046304},
{"sys/cdio.h", "CDIOCGETVOL", 0x4004630a},
{"sys/consio.h", "CONS_IDLE", 0x4004630b},
{"sys/consio.h", "CONS_GETVERS", 0x4004634a},
{"sys/consio.h", "CONS_CURRENTADP", 0x40046364},
{"sys/cdrio.h", "CDRIOCNEXTWRITEABLEADDR", 0x40046365},
{"sys/wormio.h", "CDRIOCNEXTWRITEABLEADDR", 0x40046365},
{"sys/cdrio.h", "CDRIOCGETBLOCKSIZE", 0x4004636b},
{"sys/filio.h", "FIOGETLBA", 0x40046679},
{"sys/filio.h", "FIODTYPE", 0x4004667a},
{"sys/filio.h", "FIOGETOWN", 0x4004667b},
{"sys/filio.h", "FIONREAD", 0x4004667f},
{"sys/mtio.h", "MTIOCRDSPOS", 0x40046d05},
{"sys/mtio.h", "MTIOCRDHPOS", 0x40046d06},
{"sys/mtio.h", "MTIOCGETEOTMODEL", 0x40046d08},
{"nwfs/nwfs.h", "NWFSIOC_GETCONN", 0x40046e01},
{"nwfs/nwfs.h", "NWFSIOC_GETNS", 0x40046e03},
{"sys/pioctl.h", "PIOCGFL", 0x40047007},
{"netinet/ip_fil.h", "SIOCGETFF", 0x4004723f},
{"netinet/ip_fil.h", "SIOCIPFFB", 0x40047242},
{"netinet/ip_fil.h", "SIOCSWAPA", 0x40047245},
{"sys/sockio.h", "SIOCGHIWAT", 0x40047301},
{"sys/sockio.h", "SIOCGLOWAT", 0x40047303},
{"sys/sockio.h", "SIOCATMARK", 0x40047307},
{"sys/sockio.h", "SIOCGPGRP", 0x40047309},
{"machine/cdk.h", "STL_GETPFLAG", 0x40047350},
{"sys/ioctl_compat.h", "OTIOCGETD", 0x40047400},
{"sys/ttycom.h", "TIOCMODG", 0x40047403},
{"sys/ttycom.h", "TIOCGETD", 0x4004741a},
{"net/if_ppp.h", "PPPIOCGMTU", 0x40047449},
{"net/slip.h", "SLIOCGOUTFILL", 0x40047451},
{"net/slip.h", "SLIOCGKEEPAL", 0x40047452},
{"net/if_ppp.h", "PPPIOCGMRU", 0x40047453},
{"net/if_ppp.h", "PPPIOCGRASYNCMAP", 0x40047455},
{"sys/ttycom.h", "TIOCGDRAINWAIT", 0x40047456},
{"net/if_ppp.h", "PPPIOCGUNIT", 0x40047456},
{"net/slip.h", "SLIOCGUNIT", 0x40047458},
{"net/if_ppp.h", "PPPIOCGASYNCMAP", 0x40047458},
{"net/if_tun.h", "TUNGDEBUG", 0x40047459},
{"net/if_ppp.h", "PPPIOCGFLAGS", 0x4004745a},
{"sys/ttycom.h", "TIOCMGDTRWAIT", 0x4004745a},
{"net/if_tun.h", "TUNGIFHEAD", 0x40047461},
{"sys/ttycom.h", "TIOCMGET", 0x4004746a},
{"sys/ttycom.h", "TIOCOUTQ", 0x40047473},
{"sys/ttycom.h", "TIOCGPGRP", 0x40047477},
{"sys/ioctl_compat.h", "TIOCLGET", 0x4004747c},
{"sys/consio.h", "VT_OPENQRY", 0x40047601},
{"machine/pcvt_ioctl.h", "VT_OPENQRY", 0x40047601},
{"machine/pcvt_ioctl.h", "VT_GETACTIVE", 0x40047607},
{"sys/consio.h", "VT_GETACTIVE", 0x40047607},
{"sys/consio.h", "VT_GETINDEX", 0x40047608},
{"machine/ioctl_meteor.h", "METEORGFMT", 0x40047807},
{"machine/ioctl_meteor.h", "METEORGINPUT", 0x40047808},
{"machine/ioctl_meteor.h", "METEORGSIGNAL", 0x4004780c},
{"machine/ioctl_bt848.h", "TVTUNER_GETCHNL", 0x40047820},
{"machine/ioctl_bt848.h", "TVTUNER_GETTYPE", 0x40047821},
{"machine/ioctl_bt848.h", "TVTUNER_GETSTATUS", 0x40047822},
{"machine/ioctl_bt848.h", "TVTUNER_GETFREQ", 0x40047824},
{"machine/ioctl_bt848.h", "BT848_GHUE", 0x40047825},
{"machine/ioctl_bt848.h", "BT848_GBRIG", 0x40047826},
{"machine/ioctl_bt848.h", "BT848_GCSAT", 0x40047827},
{"machine/ioctl_bt848.h", "BT848_GCONT", 0x40047828},
{"machine/ioctl_bt848.h", "BT848_GVSAT", 0x40047829},
{"machine/ioctl_bt848.h", "BT848_GUSAT", 0x4004782a},
{"machine/ioctl_bt848.h", "BT848_SCBARS", 0x4004782b},
{"machine/ioctl_bt848.h", "BT848_CCBARS", 0x4004782c},
{"machine/ioctl_bt848.h", "BT848_GAUDIO", 0x4004782f},
{"machine/ioctl_bt848.h", "BT848_GSTATUS", 0x40047831},
{"machine/ioctl_bt848.h", "TVTUNER_GETAFC", 0x40047836},
{"machine/ioctl_bt848.h", "BT848_GLNOTCH", 0x40047838},
{"machine/ioctl_bt848.h", "RADIO_GETFREQ", 0x4004783b},
{"machine/ioctl_bt848.h", "METEORGACTPIXFMT", 0x40047840},
{"machine/ioctl_bt848.h", "BT848GFMT", 0x40047843},
{"machine/ioctl_bt848.h", "BT848GCBUF", 0x40047844},
{"machine/ioctl_bt848.h", "BT848_GPIO_GET_EN", 0x40047849},
{"machine/ioctl_bt848.h", "BT848_GPIO_GET_DATA", 0x4004784b},
{"sys/ioctl_compat.h", "TIOCGETP", 0x40067408},
{"sys/ioctl_compat.h", "TIOCGETC", 0x40067412},
{"sys/ioctl_compat.h", "TIOCGLTC", 0x40067474},
{"sys/soundcard.h", "AIOGSIZE", 0x4008410b},
{"machine/soundcard.h", "AIOGSIZE", 0x4008410b},
{"net/bpf.h", "BIOCGRTIMEOUT", 0x4008426e},
{"net/bpf.h", "BIOCGSTATS", 0x4008426f},
{"sys/fbio.h", "FBIO_GETDISPSTART", 0x4008466d},
{"sys/kbio.h", "KDGETREPEAT", 0x40084b67},
{"sys/soundcard.h", "SNDCTL_DSP_MAPINBUF", 0x40085013},
{"machine/soundcard.h", "SNDCTL_DSP_MAPINBUF", 0x40085013},
{"machine/soundcard.h", "SNDCTL_DSP_MAPOUTBUF", 0x40085014},
{"sys/soundcard.h", "SNDCTL_DSP_MAPOUTBUF", 0x40085014},
{"sys/chio.h", "CHIOGPARAMS", 0x40086306},
{"machine/spigot.h", "SPIGOT_GET_INFO", 0x40087304},
{"net/if_ppp.h", "PPPIOCGIDLE", 0x4008744a},
{"sys/ttycom.h", "TIOCDCDTIMESTAMP", 0x40087458},
{"sys/ttycom.h", "TIOCTIMESTAMP", 0x40087459},
{"net/if_tun.h", "TUNGIFINFO", 0x4008745c},
{"sys/ttycom.h", "TIOCGWINSZ", 0x40087468},
{"machine/pcvt_ioctl.h", "VT_GETMODE", 0x40087603},
{"sys/consio.h", "VT_GETMODE", 0x40087603},
{"machine/i4b_ioctl.h", "I4B_VR_REQ", 0x400c3409},
{"machine/perfmon.h", "PMIOTSTAMP", 0x400c3506},
{"machine/i4b_tel_ioctl.h", "I4B_TEL_VR_REQ", 0x400c4103},
{"sys/soundcard.h", "SNDCTL_DSP_GETIPTR", 0x400c5011},
{"machine/soundcard.h", "SNDCTL_DSP_GETIPTR", 0x400c5011},
{"machine/soundcard.h", "SNDCTL_DSP_GETOPTR", 0x400c5012},
{"sys/soundcard.h", "SNDCTL_DSP_GETOPTR", 0x400c5012},
{"machine/i4b_rbch_ioctl.h", "I4B_RBCH_VR_REQ", 0x400c5202},
{"sys/cdio.h", "CDIOCCAPABILITY", 0x400c631e},
{"machine/ioctl_meteor.h", "METEORGETGEO", 0x400c7804},
{"machine/i4b_debug.h", "I4B_CTL_GET_DEBUG", 0x40104300},
{"machine/soundcard.h", "SNDCTL_DSP_GETOSPACE", 0x4010500c},
{"sys/soundcard.h", "SNDCTL_DSP_GETOSPACE", 0x4010500c},
{"machine/soundcard.h", "SNDCTL_DSP_GETISPACE", 0x4010500d},
{"sys/soundcard.h", "SNDCTL_DSP_GETISPACE", 0x4010500d},
{"dev/usb/usb.h", "USB_DEVICESTATS", 0x40105505},
{"machine/soundcard.h", "AIOGFMT", 0x4010660c},
{"sys/soundcard.h", "AIOGFMT", 0x4010660c},
{"machine/ioctl_meteor.h", "METEORGVIDEO", 0x4010780d},
{"machine/ioctl_bt848.h", "BT848_GCAPAREA", 0x40107845},
{"dev/usb/usb.h", "USB_GET_DEVICE_DESC", 0x40125569},
{"machine/pcvt_ioctl.h", "KBDMOUSEGET", 0x40144b19},
{"machine/mouse.h", "MOUSE_GETHWINFO", 0x40144d01},
{"sys/pioctl.h", "PIOCWAIT", 0x40147004},
{"sys/pioctl.h", "PIOCSTATUS", 0x40147006},
{"machine/ioctl_meteor.h", "METEORGCOUNT", 0x4014780a},
{"sys/fbio.h", "FBIOGTYPE", 0x40184600},
{"machine/mouse.h", "MOUSE_GETSTATUS", 0x40184d00},
{"pccard/cardinfo.h", "PIOCGSTATE", 0x40185001},
{"machine/apm_bios.h", "APMIO_GETINFO_OLD", 0x40185002},
{"machine/mouse.h", "MOUSE_GETMODE", 0x401c4d02},
{"sys/timepps.h", "PPS_IOC_GETPARAMS", 0x40203104},
{"net/bpf.h", "BIOCGETIF", 0x4020426b},
{"netinet/ip_nat.h", "SIOCGFRST", 0x40207254},
{"net/if_ppp.h", "PPPIOCGXASYNCMAP", 0x40207450},
{"sys/kbio.h", "KDGKBINFO", 0x40244b65},
{"machine/apm_bios.h", "APMIO_NEXTEVENT", 0x40284164},
{"netgraph/ng_message.h", "NGIOCGINFO", 0x40284e28},
{"machine/ioctl_fd.h", "FD_GTYPE", 0x402c463e},
{"sys/ttycom.h", "TIOCGETA", 0x402c7413},
{"netinet/ip_nat.h", "SIOCGIPST", 0x40387255},
{"machine/mouse.h", "MOUSE_GETVARS", 0x40404d06},
{"machine/apm_bios.h", "APMIO_GETINFO", 0x4040500b},
{"netinet/ip_nat.h", "SIOCGNATS", 0x40407252},
{"sys/mtio.h", "MTIOCGET", 0x404c6d02},
{"sys/fbio.h", "FBIOGATTR", 0x40584606},
{"machine/pcaudioio.h", "AUDIO_GETINFO", 0x40844101},
{"cam/scsi/scsi_targetio.h", "TARGIOCFETCHATIO", 0x409c4303},
{"sys/fbio.h", "FBIO_ADPINFO", 0x40a44666},
{"sys/consio.h", "GIO_SCRNMAP", 0x41006b02},
{"sys/mtio.h", "MTIOCERRSTAT", 0x41006d07},
{"machine/ioctl_ctx.h", "CTX_GET_LUT", 0x41007806},
{"netinet/ip_fil.h", "SIOCGETFS", 0x410c7240},
{"sys/disklabel.h", "DIOCGDINFO", 0x41146465},
{"nwfs/nwfs.h", "NWFSIOC_GETEINFO", 0x414d6e02},
{"dev/usb/usb.h", "USB_GET_DEVICEINFO", 0x41585570},
{"dev/usb/usb.h", "USB_GET_REPORT_DESC", 0x44045515},
{"sys/kbio.h", "GIO_DEADKEYMAP", 0x462a6b08},
{"machine/ioctl_bt848.h", "BT848GCLIP", 0x46407842},
{"sys/diskslice.h", "DIOCGSLICEINFO", 0x471c646f},
{"sys/consio.h", "GIO_FONT8x8", 0x48006341},
{"machine/pcvt_ioctl.h", "GIO_KEYMAP", 0x4a026b06},
{"sys/kbio.h", "GIO_KEYMAP", 0x4a026b06},
{"sys/consio.h", "GIO_FONT8x14", 0x4e006343},
{"machine/soundcard.h", "SNDCTL_COPR_RCVMSG", 0x4fa44309},
{"sys/soundcard.h", "SNDCTL_COPR_RCVMSG", 0x4fa44309},
{"sys/consio.h", "GIO_FONT8x16", 0x50006345},
{"sys/pioctl.h", "PIOCBIS", 0x80007001},
{"sys/pioctl.h", "PIOCBIC", 0x80007002},
{"sys/pioctl.h", "PIOCSFL", 0x80007003},
{"sys/pioctl.h", "PIOCCONT", 0x80007005},
{"sys/ttycom.h", "TIOCSTI", 0x80017472},
{"machine/ioctl_meteor.h", "METEORSHUE", 0x80017806},
{"machine/ioctl_meteor.h", "METEORSCHCV", 0x80017809},
{"machine/ioctl_meteor.h", "METEORSBRIG", 0x8001780e},
{"machine/ioctl_meteor.h", "METEORSCSAT", 0x8001780f},
{"machine/ioctl_meteor.h", "METEORSCONT", 0x80017810},
{"machine/ioctl_meteor.h", "METEORSHWS", 0x80017812},
{"machine/ioctl_meteor.h", "METEORSVWS", 0x80017813},
{"machine/ioctl_meteor.h", "METEORSTS", 0x80017814},
{"pccard/cardinfo.h", "PIOCSREG", 0x80025065},
{"sys/cdio.h", "CDIOCPITCH", 0x8002631d},
{"machine/random.h", "MEM_SETIRQ", 0x80027201},
{"machine/random.h", "MEM_CLEARIRQ", 0x80027202},
{"machine/ioctl_meteor.h", "METEORSFPS", 0x8002780b},
{"machine/ioctl_meteor.h", "METEORSBT254", 0x80027811},
{"machine/i4b_ioctl.h", "I4B_ALERT_REQ", 0x80043408},
{"machine/perfmon.h", "PMIOSTART", 0x80043502},
{"machine/perfmon.h", "PMIOSTOP", 0x80043503},
{"machine/perfmon.h", "PMIORESET", 0x80043505},
{"machine/i4b_tel_ioctl.h", "I4B_TEL_SETAUDIOFMT", 0x80044101},
{"sys/dataacq.h", "AD_MICRO_PERIOD_SET", 0x80044101},
{"machine/i4b_tel_ioctl.h", "I4B_TEL_EMPTYINPUTQUEUE", 0x80044102},
{"net/bpf.h", "BIOCIMMEDIATE", 0x80044270},
{"net/bpf.h", "BIOCSRSIG", 0x80044273},
{"net/bpf.h", "BIOCSHDRCMPLT", 0x80044275},
{"net/bpf.h", "BIOCSSEESENT", 0x80044277},
{"cam/scsi/scsi_targetio.h", "TARGIOCCLEAREXCEPTION", 0x80044302},
{"machine/i4b_debug.h", "I4B_CTL_CLR_LAPDSTAT", 0x80044305},
{"sys/fbio.h", "FBIOSVIDEO", 0x80044607},
{"sys/fbio.h", "FBIOSCURPOS", 0x8004461a},
{"sys/fbio.h", "FBIOGCURPOS", 0x8004461b},
{"machine/ioctl_fd.h", "FD_SOPTS", 0x80044641},
{"machine/ioctl_fd.h", "FD_DEBUG", 0x80044642},
{"sys/fbio.h", "FBIO_SETMODE", 0x8004466a},
{"sys/fbio.h", "FBIO_SETWINORG", 0x8004466c},
{"sys/fbio.h", "FBIO_SETLINEWIDTH", 0x80044670},
{"machine/joystick.h", "JOY_SETTIMEOUT", 0x80044a01},
{"sys/joystick.h", "JOY_SETTIMEOUT", 0x80044a01},
{"machine/joystick.h", "JOY_SET_X_OFFSET", 0x80044a03},
{"sys/joystick.h", "JOY_SET_X_OFFSET", 0x80044a03},
{"machine/joystick.h", "JOY_SET_Y_OFFSET", 0x80044a04},
{"sys/joystick.h", "JOY_SET_Y_OFFSET", 0x80044a04},
{"machine/pcvt_ioctl.h", "KBDSTPMAT", 0x80044b03},
{"machine/pcvt_ioctl.h", "KBDSREPSW", 0x80044b05},
{"machine/pcvt_ioctl.h", "KBDSLEDS", 0x80044b07},
{"machine/pcvt_ioctl.h", "KBDSLOCK", 0x80044b09},
{"machine/pcvt_ioctl.h", "KBDRMKEY", 0x80044b13},
{"machine/mouse.h", "MOUSE_SETLEVEL", 0x80044d05},
{"sys/soundcard.h", "SNDCTL_DSP_SETBLKSIZE", 0x80045004},
{"machine/soundcard.h", "SNDCTL_DSP_SETBLKSIZE", 0x80045004},
{"pccard/cardinfo.h", "PIOCRWFLAG", 0x80045007},
{"machine/apm_bios.h", "APMIO_DISPLAY", 0x80045009},
{"pccard/cardinfo.h", "PIOCSVIR", 0x8004500a},
{"pccard/cardinfo.h", "PIOCSBEEP", 0x8004500b},
{"machine/soundcard.h", "SNDCTL_DSP_SETTRIGGER", 0x80045010},
{"sys/soundcard.h", "SNDCTL_DSP_SETTRIGGER", 0x80045010},
{"sys/soundcard.h", "SNDCTL_SEQ_PERCMODE", 0x80045106},
{"machine/soundcard.h", "SNDCTL_SEQ_PERCMODE", 0x80045106},
{"sys/soundcard.h", "SNDCTL_SEQ_TESTMIDI", 0x80045108},
{"machine/soundcard.h", "SNDCTL_SEQ_TESTMIDI", 0x80045108},
{"sys/soundcard.h", "SNDCTL_SEQ_RESETSAMPLES", 0x80045109},
{"machine/soundcard.h", "SNDCTL_SEQ_RESETSAMPLES", 0x80045109},
{"machine/soundcard.h", "SNDCTL_SEQ_THRESHOLD", 0x8004510d},
{"sys/soundcard.h", "SNDCTL_SEQ_THRESHOLD", 0x8004510d},
{"sys/soundcard.h", "SNDCTL_FM_4OP_ENABLE", 0x8004510f},
{"machine/soundcard.h", "SNDCTL_FM_4OP_ENABLE", 0x8004510f},
{"machine/gsc.h", "GSC_SRES", 0x80045302},
{"machine/asc_ioctl.h", "ASC_SRES", 0x80045302},
{"machine/asc_ioctl.h", "ASC_SWIDTH", 0x80045304},
{"machine/gsc.h", "GSC_SWIDTH", 0x80045304},
{"machine/asc_ioctl.h", "ASC_SHEIGHT", 0x80045306},
{"machine/gsc.h", "GSC_SHEIGHT", 0x80045306},
{"machine/asc_ioctl.h", "ASC_SBLEN", 0x80045308},
{"machine/gsc.h", "GSC_SBLEN", 0x80045308},
{"machine/asc_ioctl.h", "ASC_SBTIME", 0x8004530a},
{"machine/gsc.h", "GSC_SBTIME", 0x8004530a},
{"machine/i4b_trace.h", "I4B_TRC_SET", 0x80045401},
{"sys/ptio.h", "PTIOCSETTIMEOUT", 0x80045402},
{"machine/i4b_trace.h", "I4B_TRC_RESETA", 0x80045403},
{"machine/soundcard.h", "SNDCTL_TMR_METRONOME", 0x80045407},
{"sys/soundcard.h", "SNDCTL_TMR_METRONOME", 0x80045407},
{"machine/soundcard.h", "SNDCTL_TMR_SELECT", 0x80045408},
{"sys/soundcard.h", "SNDCTL_TMR_SELECT", 0x80045408},
{"sys/snoop.h", "SNPSTTY", 0x8004545a},
{"dev/usb/usb.h", "USB_SETDEBUG", 0x80045502},
{"dev/usb/usb.h", "USB_SET_IMMED", 0x80045516},
{"dev/usb/usb.h", "USB_SET_CONFIG", 0x80045565},
{"dev/usb/usb.h", "USB_SET_SHORT_XFER", 0x80045571},
{"dev/usb/usb.h", "USB_SET_TIMEOUT", 0x80045572},
{"dev/usb/usb.h", "USB_SET_CM_OVER_DATA", 0x80045583},
{"machine/pcvt_ioctl.h", "VGASCREENSAVER", 0x80045670},
{"machine/pcvt_ioctl.h", "VGASETCOLMS", 0x80045673},
{"sys/cdio.h", "CDIOCPLAYTRACKS", 0x80046301},
{"sys/consio.h", "CONS_BLANKTIME", 0x80046304},
{"sys/chio.h", "CHIOSPICKER", 0x80046305},
{"sys/consio.h", "CONS_CURSORTYPE", 0x80046307},
{"sys/chio.h", "CHIOIELEM", 0x80046307},
{"sys/consio.h", "CONS_BELLTYPE", 0x80046308},
{"sys/consio.h", "CONS_HISTORY", 0x80046309},
{"sys/cdio.h", "CDIOCSETPATCH", 0x80046309},
{"sys/cdio.h", "CDIOCSETVOL", 0x8004630b},
{"sys/consio.h", "CONS_SAVERMODE", 0x8004630c},
{"sys/consio.h", "CONS_SAVERSTART", 0x8004630d},
{"sys/cdrio.h", "CDRIOCWRITESPEED", 0x8004636a},
{"sys/cdrio.h", "CDRIOCSETBLOCKSIZE", 0x8004636c},
{"sys/disklabel.h", "DIOCWLABEL", 0x8004646d},
{"sys/diskslice.h", "DIOCSYNCSLICEINFO", 0x80046470},
{"sys/filio.h", "FIOSETOWN", 0x8004667c},
{"sys/filio.h", "FIOASYNC", 0x8004667d},
{"sys/filio.h", "FIONBIO", 0x8004667e},
{"sys/mtio.h", "MTIOCSLOCATE", 0x80046d05},
{"sys/mtio.h", "MTIOCHLOCATE", 0x80046d06},
{"sys/mtio.h", "MTIOCSETEOTMODEL", 0x80046d08},
{"machine/lpt.h", "LPT_IRQ", 0x80047001},
{"netinet/ip_fil.h", "SIOCSETFF", 0x8004723e},
{"netinet/ip_fil.h", "SIOCFRENB", 0x80047248},
{"netinet/ip_fil.h", "SIOCFRSYN", 0x80047249},
{"sys/sockio.h", "SIOCSHIWAT", 0x80047300},
{"sys/sockio.h", "SIOCSLOWAT", 0x80047302},
{"machine/spigot.h", "SPIGOT_SETINT", 0x80047305},
{"sys/sockio.h", "SIOCSPGRP", 0x80047308},
{"machine/cdk.h", "STL_SETPFLAG", 0x80047351},
{"sys/ioctl_compat.h", "OTIOCSETD", 0x80047401},
{"sys/ttycom.h", "TIOCMODS", 0x80047404},
{"sys/ttycom.h", "TIOCFLUSH", 0x80047410},
{"sys/ttycom.h", "TIOCSETD", 0x8004741b},
{"net/if_ppp.h", "PPPIOCSMTU", 0x80047448},
{"net/slip.h", "SLIOCSUNIT", 0x80047450},
{"net/if_ppp.h", "PPPIOCSMAXCID", 0x80047451},
{"net/if_ppp.h", "PPPIOCSMRU", 0x80047452},
{"net/slip.h", "SLIOCSOUTFILL", 0x80047453},
{"net/slip.h", "SLIOCSKEEPAL", 0x80047454},
{"net/if_ppp.h", "PPPIOCSRASYNCMAP", 0x80047454},
{"sys/ttycom.h", "TIOCSDRAINWAIT", 0x80047457},
{"net/if_ppp.h", "PPPIOCSASYNCMAP", 0x80047457},
{"net/if_ppp.h", "PPPIOCSFLAGS", 0x80047459},
{"net/if_tun.h", "TUNSDEBUG", 0x8004745a},
{"sys/ttycom.h", "TIOCMSDTRWAIT", 0x8004745b},
{"net/if_tun.h", "TUNSLMODE", 0x8004745d},
{"net/if_tun.h", "TUNSIFMODE", 0x8004745e},
{"net/if_tun.h", "TUNSIFHEAD", 0x80047460},
{"sys/ttycom.h", "TIOCEXT", 0x80047460},
{"sys/ttycom.h", "TIOCCONS", 0x80047462},
{"sys/ttycom.h", "TIOCUCNTL", 0x80047466},
{"sys/ttycom.h", "TIOCREMOTE", 0x80047469},
{"sys/ttycom.h", "TIOCMBIC", 0x8004746b},
{"sys/ttycom.h", "TIOCMBIS", 0x8004746c},
{"sys/ttycom.h", "TIOCMSET", 0x8004746d},
{"sys/ttycom.h", "TIOCPKT", 0x80047470},
{"sys/ttycom.h", "TIOCSPGRP", 0x80047476},
{"sys/ioctl_compat.h", "TIOCLSET", 0x8004747d},
{"sys/ioctl_compat.h", "TIOCLBIC", 0x8004747e},
{"sys/ioctl_compat.h", "TIOCLBIS", 0x8004747f},
{"machine/ioctl_meteor.h", "METEORCAPTUR", 0x80047801},
{"machine/ioctl_meteor.h", "METEORSFMT", 0x80047807},
{"machine/ioctl_meteor.h", "METEORSINPUT", 0x80047808},
{"machine/ioctl_meteor.h", "METEORSSIGNAL", 0x8004780c},
{"machine/ioctl_bt848.h", "TVTUNER_SETCHNL", 0x80047820},
{"machine/ioctl_bt848.h", "TVTUNER_SETTYPE", 0x80047821},
{"machine/ioctl_bt848.h", "TVTUNER_SETFREQ", 0x80047823},
{"machine/ioctl_bt848.h", "BT848_SHUE", 0x80047825},
{"machine/ioctl_bt848.h", "BT848_SBRIG", 0x80047826},
{"machine/ioctl_bt848.h", "BT848_SCSAT", 0x80047827},
{"machine/ioctl_bt848.h", "BT848_SCONT", 0x80047828},
{"machine/ioctl_bt848.h", "BT848_SVSAT", 0x80047829},
{"machine/ioctl_bt848.h", "BT848_SUSAT", 0x8004782a},
{"machine/ioctl_bt848.h", "BT848_SAUDIO", 0x8004782e},
{"machine/ioctl_bt848.h", "BT848_SBTSC", 0x80047830},
{"machine/ioctl_bt848.h", "TVTUNER_SETAFC", 0x80047835},
{"machine/ioctl_bt848.h", "BT848_SLNOTCH", 0x80047837},
{"machine/ioctl_bt848.h", "RADIO_SETMODE", 0x8004783a},
{"machine/ioctl_bt848.h", "RADIO_SETFREQ", 0x8004783b},
{"machine/ioctl_bt848.h", "METEORSACTPIXFMT", 0x80047840},
{"machine/ioctl_bt848.h", "BT848SFMT", 0x80047843},
{"machine/ioctl_bt848.h", "BT848SCBUF", 0x80047844},
{"machine/ioctl_bt848.h", "BT848_GPIO_SET_EN", 0x80047848},
{"machine/ioctl_bt848.h", "BT848_GPIO_SET_DATA", 0x8004784a},
{"sys/chio.h", "CHIOPOSITION", 0x80066303},
{"sys/cdio.h", "CDIOCPLAYMSF", 0x80066319},
{"sys/ioctl_compat.h", "TIOCSETP", 0x80067409},
{"sys/ioctl_compat.h", "TIOCSETN", 0x8006740a},
{"sys/ioctl_compat.h", "TIOCSETC", 0x80067411},
{"sys/ioctl_compat.h", "TIOCSLTC", 0x80067475},
{"machine/ioctl_meteor.h", "METEORCAPFRM", 0x80067802},
{"machine/i4b_ioctl.h", "I4B_DISCONNECT_REQ", 0x80083403},
{"machine/i4b_ioctl.h", "I4B_PROT_IND", 0x8008340a},
{"machine/perfmon.h", "PMIOSETUP", 0x80083501},
{"net/bpf.h", "BIOCSETF", 0x80084267},
{"net/bpf.h", "BIOCSRTIMEOUT", 0x8008426d},
{"sys/fbio.h", "FBIO_SETDISPSTART", 0x8008466e},
{"sys/kbio.h", "KDSETREPEAT", 0x80084b66},
{"pccard/cardinfo.h", "PIOCSPOW", 0x80085009},
{"sys/soundcard.h", "SNDCTL_SEQ_OUTOFBAND", 0x80085112},
{"machine/soundcard.h", "SNDCTL_SEQ_OUTOFBAND", 0x80085112},
{"machine/speaker.h", "SPKRTONE", 0x80085301},
{"sys/wormio.h", "WORMIOCPREPDISK", 0x80085714},
{"sys/wormio.h", "WORMIOCFIXATION", 0x80085716},
{"sys/cdio.h", "CDIOCPLAYBLOCKS", 0x80086302},
{"sys/disklabel.h", "DIOCGPART", 0x80086468},
{"sys/mtio.h", "MTIOCTOP", 0x80086d01},
{"net/if_ppp.h", "PPPIOCSACTIVE", 0x80087446},
{"net/if_ppp.h", "PPPIOCSPASS", 0x80087447},
{"net/if_ppp.h", "PPPIOCSNPMODE", 0x8008744b},
{"net/if_tun.h", "TUNSIFINFO", 0x8008745b},
{"sys/ttycom.h", "TIOCSWINSZ", 0x80087467},
{"machine/pcvt_ioctl.h", "CONSOLE_X_BELL", 0x8008747b},
{"sys/consio.h", "VT_SETMODE", 0x80087602},
{"machine/pcvt_ioctl.h", "VT_SETMODE", 0x80087602},
{"sys/chio.h", "CHIOMOVE", 0x800a6301},
{"sys/timepps.h", "PPS_IOC_KCBIND", 0x800c3107},
{"machine/i4b_ioctl.h", "I4B_UPDOWN_IND", 0x800c3407},
{"machine/i4b_ioctl.h", "I4B_CTRL_DOWNLOAD", 0x800c3464},
{"sys/consio.h", "KDRASTER", 0x800c4b64},
{"machine/pcvt_ioctl.h", "VGACURSOR", 0x800c5664},
{"sys/chio.h", "CHIOGSTATUS", 0x800c6308},
{"sys/cdrio.h", "CDRIOCOPENTRACK", 0x800c6368},
{"sys/kbio.h", "PIO_KEYMAPENT", 0x800c6b0b},
{"sys/memrange.h", "MEMRANGE_SET", 0x800c6d33},
{"net/if_ppp.h", "PPPIOCSCOMPRESS", 0x800c744d},
{"machine/ioctl_meteor.h", "METEORSETGEO", 0x800c7803},
{"sys/chio.h", "CHIOEXCHANGE", 0x800e6302},
{"machine/i4b_ioctl.h", "I4B_DIALOUT_RESP", 0x80103405},
{"machine/i4b_debug.h", "I4B_CTL_SET_DEBUG", 0x80104301},
{"cam/scsi/scsi_targetio.h", "TARGCTLIOFREEUNIT", 0x80104308},
{"netgraph/ng_message.h", "NGIOCSETNAME", 0x80104e29},
{"pccard/cardinfo.h", "PIOCSIO", 0x80105005},
{"machine/i4b_trace.h", "I4B_TRC_SETA", 0x80105402},
{"machine/pcvt_ioctl.h", "VGAWRITEPEL", 0x8010566f},
{"machine/iic.h", "I2CSTART", 0x80106901},
{"machine/iic.h", "I2CRSTCARD", 0x80106903},
{"machine/iic.h", "I2CWRITE", 0x80106904},
{"machine/iic.h", "I2CREAD", 0x80106905},
{"machine/ioctl_meteor.h", "METEORSVIDEO", 0x8010780d},
{"machine/ioctl_bt848.h", "BT848_SCAPAREA", 0x80107845},
{"machine/i4b_ioctl.h", "I4B_TIMEOUT_UPD", 0x80143406},
{"machine/soundcard.h", "SNDCTL_COPR_WDATA", 0x80144304},
{"sys/soundcard.h", "SNDCTL_COPR_WDATA", 0x80144304},
{"sys/soundcard.h", "SNDCTL_COPR_WCODE", 0x80144305},
{"machine/soundcard.h", "SNDCTL_COPR_WCODE", 0x80144305},
{"sys/fbio.h", "FBIOPUTCMAP", 0x80144603},
{"sys/fbio.h", "FBIOGETCMAP", 0x80144604},
{"machine/pcvt_ioctl.h", "KBDMOUSESET", 0x80144b1a},
{"pccard/cardinfo.h", "PIOCSMEM", 0x80145003},
{"machine/pcvt_ioctl.h", "VGASETFONTATTR", 0x80145666},
{"machine/smb.h", "SMB_QUICK_WRITE", 0x80146901},
{"machine/smb.h", "SMB_QUICK_READ", 0x80146902},
{"machine/smb.h", "SMB_SENDB", 0x80146903},
{"machine/smb.h", "SMB_RECVB", 0x80146904},
{"machine/smb.h", "SMB_WRITEB", 0x80146905},
{"machine/smb.h", "SMB_WRITEW", 0x80146906},
{"machine/smb.h", "SMB_READB", 0x80146907},
{"machine/smb.h", "SMB_READW", 0x80146908},
{"machine/smb.h", "SMB_PCALL", 0x80146909},
{"machine/smb.h", "SMB_BWRITE", 0x8014690a},
{"machine/smb.h", "SMB_BREAD", 0x8014690b},
{"machine/ioctl_meteor.h", "METEORSCOUNT", 0x8014780a},
{"machine/i4b_ioctl.h", "I4B_ACTIVE_DIAGNOSTIC", 0x80183466},
{"netatm/atm_ioctl.h", "AIOCCFG", 0x80184180},
{"sys/ccdvar.h", "CCDIOCCLR", 0x80184611},
{"sys/fbio.h", "FBIO_GETPALETTE", 0x80184671},
{"sys/fbio.h", "FBIO_SETPALETTE", 0x80184672},
{"sys/consio.h", "CONS_SSAVER", 0x80186305},
{"machine/mouse.h", "MOUSE_SETMODE", 0x801c4d03},
{"sys/timepps.h", "PPS_IOC_SETPARAMS", 0x80203103},
{"machine/i4b_ioctl.h", "I4B_CONNECT_RESP", 0x80203402},
{"net/bpf.h", "BIOCSETIF", 0x8020426c},
{"machine/i4b_debug.h", "I4B_CTL_CLR_HSCXSTAT", 0x80204303},
{"sys/sockio.h", "SIOCSIFADDR", 0x8020690c},
{"sys/sockio.h", "SIOCSIFDSTADDR", 0x8020690e},
{"sys/sockio.h", "SIOCSIFFLAGS", 0x80206910},
{"sys/sockio.h", "SIOCSIFBRDADDR", 0x80206913},
{"sys/sockio.h", "SIOCSIFNETMASK", 0x80206916},
{"sys/sockio.h", "SIOCSIFMETRIC", 0x80206918},
{"sys/sockio.h", "SIOCDIFADDR", 0x80206919},
{"sys/sockio.h", "SIOCADDMULTI", 0x80206931},
{"sys/sockio.h", "SIOCDELMULTI", 0x80206932},
{"sys/sockio.h", "SIOCSIFMTU", 0x80206934},
{"sys/sockio.h", "SIOCSIFPHYS", 0x80206936},
{"sys/sockio.h", "SIOCSIFGENERIC", 0x80206939},
{"machine/if_wl_wavelan.h", "SIOCDWLCACHE", 0x80206940},
{"machine/if_wl_wavelan.h", "SIOCSWLTHR", 0x80206941},
{"netatalk/phase2.h", "SIOCPHASE1", 0x80206964},
{"netatalk/phase2.h", "SIOCPHASE2", 0x80206965},
{"net/if_ppp.h", "PPPIOCSXASYNCMAP", 0x8020744f},
{"netatm/atm_ioctl.h", "AIOCDEL", 0x80244182},
{"sys/wormio.h", "WORMIOCWRITESESSION", 0x80245720},
{"sys/soundcard.h", "SNDCTL_FM_LOAD_INSTR", 0x80285107},
{"machine/soundcard.h", "SNDCTL_FM_LOAD_INSTR", 0x80285107},
{"sys/wormio.h", "WORMIOCPREPTRACK", 0x80285715},
{"machine/i4b_rbch_ioctl.h", "I4B_RBCH_DIALOUT", 0x80295201},
{"sys/chio.h", "CHIOSETVOLTAG", 0x802a6309},
{"sys/fbio.h", "FBIOSCURSOR", 0x802c4618},
{"machine/ioctl_fd.h", "FD_STYPE", 0x802c463f},
{"machine/pcvt_ioctl.h", "VGALOADCHAR", 0x802c5665},
{"sys/ttycom.h", "TIOCSETA", 0x802c7414},
{"sys/ttycom.h", "TIOCSETAW", 0x802c7415},
{"sys/ttycom.h", "TIOCSETAF", 0x802c7416},
{"machine/pcvt_ioctl.h", "VGASETSCREEN", 0x80305668},
{"sys/sockio.h", "SIOCADDRT", 0x8030720a},
{"sys/sockio.h", "SIOCDELRT", 0x8030720b},
{"cam/scsi/scsi_targetio.h", "TARGIOCSETISTATE", 0x80344305},
{"netatm/atm_ioctl.h", "AIOCADD", 0x803c4181},
{"machine/mouse.h", "MOUSE_SETVARS", 0x80404d07},
{"sys/sockio.h", "SIOCAIFADDR", 0x8040691a},
{"sys/sockio.h", "SIOCSIFPHYADDR", 0x80406946},
{"netinet6/in6_var.h", "SIOCSIFPREFIX_IN6", 0x80406964},
{"netinet6/in6_var.h", "SIOCDIFPREFIX_IN6", 0x80406966},
{"netatm/atm_ioctl.h", "AIOCSET", 0x80484184},
{"machine/pcvt_ioctl.h", "KBDSCKEY", 0x80484b11},
{"netinet6/in6_var.h", "SIOCAIFPREFIX_IN6", 0x80606967},
{"netinet6/in6_var.h", "SIOCCIFPREFIX_IN6", 0x80606968},
{"netinet6/in6_var.h", "SIOCSGIFPREFIX_IN6", 0x80606969},
{"sys/consio.h", "CONS_SETTERM", 0x80686371},
{"netinet/ip_nat.h", "SIOCADNAT", 0x80707250},
{"netinet/ip_nat.h", "SIOCRMNAT", 0x80707251},
{"netinet6/in6_var.h", "SIOCAIFADDR_IN6", 0x8078691a},
{"netinet6/in6_var.h", "SIOCSIFPHYADDR_IN6", 0x80786946},
{"machine/i4b_ioctl.h", "I4B_CONNECT_REQ", 0x80843401},
{"machine/cronyx.h", "CXIOCSETMODE", 0x80847802},
{"sys/xrpuio.h", "XRPU_IOC_TIMECOUNTING", 0x80a03601},
{"machine/ioctl_fd.h", "FD_FORM", 0x80a4463d},
{"netinet/ip_fil.h", "SIOCADAFR", 0x80c0723c},
{"netinet/ip_fil.h", "SIOCRMAFR", 0x80c0723d},
{"netinet/ip_fil.h", "SIOCADIFR", 0x80c07243},
{"netinet/ip_fil.h", "SIOCRMIFR", 0x80c07244},
{"netinet/ip_fil.h", "SIOCINAFR", 0x80c07246},
{"netinet/ip_fil.h", "SIOCINIFR", 0x80c07247},
{"sys/consio.h", "PIO_SCRNMAP", 0x81006b03},
{"machine/ioctl_ctx.h", "CTX_SET_LUT", 0x81007805},
{"sys/disklabel.h", "DIOCSDINFO", 0x81146466},
{"sys/disklabel.h", "DIOCWDINFO", 0x81146467},
{"sys/sockio.h", "SIOCALIFADDR", 0x8118691b},
{"sys/sockio.h", "SIOCDLIFADDR", 0x8118691d},
{"netinet6/in6_var.h", "SIOCSIFADDR_IN6", 0x8120690c},
{"netinet6/in6_var.h", "SIOCSIFDSTADDR_IN6", 0x8120690e},
{"netinet6/in6_var.h", "SIOCSIFNETMASK_IN6", 0x81206916},
{"netinet6/in6_var.h", "SIOCDIFADDR_IN6", 0x81206919},
{"sys/kbio.h", "PIO_DEADKEYMAP", 0x862a6b09},
{"machine/ioctl_bt848.h", "BT848SCLIP", 0x86407842},
{"sys/consio.h", "PIO_FONT8x8", 0x88006340},
{"sys/kbio.h", "PIO_KEYMAP", 0x8a026b07},
{"sys/consio.h", "PIO_FONT8x14", 0x8e006342},
{"sys/soundcard.h", "SNDCTL_COPR_SENDMSG", 0x8fa44308},
{"machine/soundcard.h", "SNDCTL_COPR_SENDMSG", 0x8fa44308},
{"sys/consio.h", "PIO_FONT8x16", 0x90006344},
{"pccard/cardinfo.h", "PIOCGREG", 0xc0025064},
{"machine/i4b_ioctl.h", "I4B_CDID_REQ", 0xc0043400},
{"machine/soundcard.h", "AIOGMIX", 0xc004410d},
{"sys/soundcard.h", "AIOGMIX", 0xc004410d},
{"machine/soundcard.h", "AIOSMIX", 0xc004410e},
{"sys/soundcard.h", "AIOSMIX", 0xc004410e},
{"machine/soundcard.h", "AIOSTOP", 0xc004410f},
{"sys/soundcard.h", "AIOSTOP", 0xc004410f},
{"net/bpf.h", "BIOCSBLEN", 0xc0044266},
{"sys/vnioctl.h", "VNIOCGSET", 0xc0044602},
{"sys/vnioctl.h", "VNIOCGCLEAR", 0xc0044603},
{"sys/vnioctl.h", "VNIOCUSET", 0xc0044604},
{"sys/vnioctl.h", "VNIOCUCLEAR", 0xc0044605},
{"machine/soundcard.h", "SNDCTL_DSP_SPEED", 0xc0045002},
{"sys/soundcard.h", "SNDCTL_DSP_SPEED", 0xc0045002},
{"sys/soundcard.h", "SNDCTL_DSP_STEREO", 0xc0045003},
{"machine/soundcard.h", "SNDCTL_DSP_STEREO", 0xc0045003},
{"machine/soundcard.h", "SNDCTL_DSP_SETFMT", 0xc0045005},
{"sys/soundcard.h", "SNDCTL_DSP_SETFMT", 0xc0045005},
{"machine/soundcard.h", "SOUND_PCM_WRITE_CHANNELS", 0xc0045006},
{"sys/soundcard.h", "SOUND_PCM_WRITE_CHANNELS", 0xc0045006},
{"machine/soundcard.h", "SOUND_PCM_WRITE_FILTER", 0xc0045007},
{"sys/soundcard.h", "SOUND_PCM_WRITE_FILTER", 0xc0045007},
{"pccard/cardinfo.h", "PIOCRWMEM", 0xc0045008},
{"sys/soundcard.h", "SNDCTL_DSP_SUBDIVIDE", 0xc0045009},
{"machine/soundcard.h", "SNDCTL_DSP_SUBDIVIDE", 0xc0045009},
{"machine/soundcard.h", "SNDCTL_DSP_SETFRAGMENT", 0xc004500a},
{"sys/soundcard.h", "SNDCTL_DSP_SETFRAGMENT", 0xc004500a},
{"machine/soundcard.h", "SNDCTL_SEQ_CTRLRATE", 0xc0045103},
{"sys/soundcard.h", "SNDCTL_SEQ_CTRLRATE", 0xc0045103},
{"sys/soundcard.h", "SNDCTL_SYNTH_MEMAVL", 0xc004510e},
{"machine/soundcard.h", "SNDCTL_SYNTH_MEMAVL", 0xc004510e},
{"machine/soundcard.h", "SNDCTL_TMR_TIMEBASE", 0xc0045401},
{"sys/soundcard.h", "SNDCTL_TMR_TIMEBASE", 0xc0045401},
{"machine/soundcard.h", "SNDCTL_TMR_TEMPO", 0xc0045405},
{"sys/soundcard.h", "SNDCTL_TMR_TEMPO", 0xc0045405},
{"sys/soundcard.h", "SNDCTL_TMR_SOURCE", 0xc0045406},
{"machine/soundcard.h", "SNDCTL_TMR_SOURCE", 0xc0045406},
{"net/if_atm.h", "SIOCRAWATM", 0xc004617a},
{"sys/soundcard.h", "SNDCTL_MIDI_PRETIME", 0xc0046d00},
{"machine/soundcard.h", "SNDCTL_MIDI_PRETIME", 0xc0046d00},
{"machine/soundcard.h", "SNDCTL_MIDI_MPUMODE", 0xc0046d01},
{"sys/soundcard.h", "SNDCTL_MIDI_MPUMODE", 0xc0046d01},
{"netinet/ip_fil.h", "SIOCIPFFL", 0xc0047241},
{"netinet/ip_nat.h", "SIOCFLNAT", 0xc0047256},
{"netinet/ip_nat.h", "SIOCCNATL", 0xc0047257},
{"machine/ioctl_bt848.h", "BT848_I2CWR", 0xc0047839},
{"machine/perfmon.h", "PMIOGET", 0xc0083507},
{"sys/soundcard.h", "AIOSSIZE", 0xc008410b},
{"machine/soundcard.h", "AIOSSIZE", 0xc008410b},
{"sys/soundcard.h", "AIOSYNC", 0xc008410f},
{"machine/soundcard.h", "AIOSYNC", 0xc008410f},
{"sys/vnioctl.h", "VNIOCATTACH", 0xc0084600},
{"sys/vnioctl.h", "VNIOCDETACH", 0xc0084601},
{"net/if_atm.h", "SIOCATMENA", 0xc008617b},
{"net/if_atm.h", "SIOCATMDIS", 0xc008617c},
{"sys/cdio.h", "CDIOREADTOCENTRYS", 0xc0086305},
{"sys/sockio.h", "OSIOCGIFCONF", 0xc0086914},
{"sys/sockio.h", "SIOCGIFCONF", 0xc0086924},
{"net/if_ppp.h", "PPPIOCGNPMODE", 0xc008744c},
{"machine/perfmon.h", "PMIOREAD", 0xc00c3504},
{"dev/usb/usb.h", "USB_GET_ALTINTERFACE", 0xc00c5566},
{"dev/usb/usb.h", "USB_SET_ALTINTERFACE", 0xc00c5567},
{"dev/usb/usb.h", "USB_GET_NO_ALT", 0xc00c5568},
{"dev/usb/usb.h", "USB_GET_FULL_DESC", 0xc00c556d},
{"sys/cdio.h", "CDIOCREADSUBCHANNEL", 0xc00c6303},
{"sys/cdio.h", "CDIOREADTOCENTRY", 0xc00c6306},
{"sys/kbio.h", "GIO_KEYMAPENT", 0xc00c6b0a},
{"sys/memrange.h", "MEMRANGE_GET", 0xc00c6d32},
{"cam/scsi/scsi_targetio.h", "TARGCTLIOALLOCUNIT", 0xc0104307},
{"pccard/cardinfo.h", "PIOCGIO", 0xc0105004},
{"dev/usb/usb.h", "USB_GET_CONFIG_DESC", 0xc010556a},
{"machine/pcvt_ioctl.h", "VGAREADPEL", 0xc010566e},
{"sys/cdio.h", "CDIOCREADAUDIO", 0xc010631f},
{"machine/soundcard.h", "AIOSFMT", 0xc010660c},
{"sys/soundcard.h", "AIOSFMT", 0xc010660c},
{"sys/pciio.h", "PCIOCREAD", 0xc0107002},
{"sys/pciio.h", "PCIOCWRITE", 0xc0107003},
{"sys/pciio.h", "PCIOCATTACHED", 0xc0107004},
{"machine/i4b_ioctl.h", "I4B_CTRL_INFO_REQ", 0xc0143404},
{"sys/soundcard.h", "SNDCTL_COPR_RDATA", 0xc0144302},
{"machine/soundcard.h", "SNDCTL_COPR_RDATA", 0xc0144302},
{"machine/soundcard.h", "SNDCTL_COPR_RCODE", 0xc0144303},
{"sys/soundcard.h", "SNDCTL_COPR_RCODE", 0xc0144303},
{"sys/soundcard.h", "SNDCTL_COPR_RUN", 0xc0144306},
{"machine/soundcard.h", "SNDCTL_COPR_RUN", 0xc0144306},
{"machine/soundcard.h", "SNDCTL_COPR_HALT", 0xc0144307},
{"sys/soundcard.h", "SNDCTL_COPR_HALT", 0xc0144307},
{"pccard/cardinfo.h", "PIOCGMEM", 0xc0145002},
{"machine/pcvt_ioctl.h", "VGAGETFONTATTR", 0xc0145667},
{"sys/wormio.h", "WORMIOCFIRSTWRITABLEADDR", 0xc0145721},
{"sys/consio.h", "CONS_MOUSECTL", 0xc014630a},
{"sys/consio.h", "CONS_GETINFO", 0xc0146349},
{"sys/kbio.h", "GETFKEY", 0xc0146b00},
{"sys/kbio.h", "SETFKEY", 0xc0146b01},
{"sys/sockio.h", "SIOCGETVIFCNT", 0xc014720f},
{"sys/sockio.h", "SIOCGETSGCNT", 0xc0147210},
{"machine/ioctl_bt848.h", "TVTUNER_GETCHNLSET", 0xc0147846},
{"sys/ccdvar.h", "CCDIOCSET", 0xc0184610},
{"machine/apm_bios.h", "APMIO_BIOS", 0xc018500a},
{"dev/usb/usb.h", "USB_REQUEST", 0xc0185501},
{"dev/usb/usb.h", "USB_GET_INTERFACE_DESC", 0xc018556b},
{"dev/usb/usb.h", "USB_GET_ENDPOINT_DESC", 0xc018556c},
{"dev/usb/usb.h", "USB_DO_REQUEST", 0xc018556f},
{"machine/pcvt_ioctl.h", "VGAPCVTID", 0xc0185671},
{"sys/consio.h", "CONS_GSAVER", 0xc0186306},
{"sys/dvdio.h", "DVDIOCREPORTKEY", 0xc01863c8},
{"sys/dvdio.h", "DVDIOCSENDKEY", 0xc01863c9},
{"netinet/ip_nat.h", "SIOCGNATL", 0xc0187253},
{"machine/soundcard.h", "AIOGCAP", 0xc01c410f},
{"sys/soundcard.h", "AIOGCAP", 0xc01c410f},
{"machine/ioctl_bt848.h", "METEORGSUPPIXFMT", 0xc01c7841},
{"netatm/atm_ioctl.h", "AIOCINFO", 0xc0204185},
{"machine/i4b_debug.h", "I4B_CTL_GET_HSCXSTAT", 0xc0204302},
{"sys/sockio.h", "OSIOCGIFADDR", 0xc020690d},
{"sys/sockio.h", "OSIOCGIFDSTADDR", 0xc020690f},
{"sys/sockio.h", "SIOCGIFFLAGS", 0xc0206911},
{"sys/sockio.h", "OSIOCGIFBRDADDR", 0xc0206912},
{"sys/sockio.h", "OSIOCGIFNETMASK", 0xc0206915},
{"sys/sockio.h", "SIOCGIFMETRIC", 0xc0206917},
{"sys/sockio.h", "SIOCGIFADDR", 0xc0206921},
{"sys/sockio.h", "SIOCGIFDSTADDR", 0xc0206922},
{"sys/sockio.h", "SIOCGIFBRDADDR", 0xc0206923},
{"sys/sockio.h", "SIOCGIFNETMASK", 0xc0206925},
{"sys/sockio.h", "SIOCGIFMTU", 0xc0206933},
{"sys/sockio.h", "SIOCGIFPHYS", 0xc0206935},
{"sys/sockio.h", "SIOCSIFMEDIA", 0xc0206937},
{"sys/sockio.h", "SIOCGIFGENERIC", 0xc020693a},
{"machine/if_wl_wavelan.h", "SIOCGWLCNWID", 0xc020693c},
{"machine/if_wl_wavelan.h", "SIOCSWLCNWID", 0xc020693d},
{"machine/if_wl_wavelan.h", "SIOCGWLPSA", 0xc020693e},
{"machine/if_wl_wavelan.h", "SIOCSWLPSA", 0xc020693f},
{"machine/if_wl_wavelan.h", "SIOCGWLEEPROM", 0xc0206942},
{"machine/if_wl_wavelan.h", "SIOCGWLCACHE", 0xc0206943},
{"machine/if_wl_wavelan.h", "SIOCGWLCITEM", 0xc0206944},
{"sys/sockio.h", "SIOCGIFPSRCADDR", 0xc0206947},
{"sys/sockio.h", "SIOCGIFPDSTADDR", 0xc0206948},
{"sys/soundcard.h", "SNDCTL_MIDI_MPUCMD", 0xc0216d02},
{"machine/soundcard.h", "SNDCTL_MIDI_MPUCMD", 0xc0216d02},
{"sys/pciio.h", "PCIOCGETCONF", 0xc0247001},
{"netinet6/in6_var.h", "SIOCGETMIFCNT_IN6", 0xc024756b},
{"machine/pcvt_ioctl.h", "VGAPCVTINFO", 0xc0285672},
{"sys/sockio.h", "SIOCGIFMEDIA", 0xc0286938},
{"machine/cronyx.h", "CXIOCGETSTAT", 0xc0287803},
{"sys/fbio.h", "FBIOGCURSOR", 0xc02c4619},
{"netinet6/in6_var.h", "SIOCGIFINFO_IN6", 0xc02c694c},
{"sys/timepps.h", "PPS_IOC_FETCH", 0xc0303106},
{"machine/pcvt_ioctl.h", "VGAGETSCREEN", 0xc0305669},
{"netinet6/in6_var.h", "SIOCGNBRINFO_IN6", 0xc030694e},
{"netinet/ip_fil.h", "SIOCATHST", 0xc030724e},
{"cam/scsi/scsi_targetio.h", "TARGIOCGETISTATE", 0xc0344306},
{"netinet/ip_fil.h", "SIOCAUTHW", 0xc038724c},
{"netinet/ip_fil.h", "SIOCAUTHR", 0xc038724d},
{"netinet6/in6_var.h", "SIOCGIFPREFIX_IN6", 0xc0406965},
{"machine/mouse.h", "MOUSE_READSTATE", 0xc0444d08},
{"machine/mouse.h", "MOUSE_READDATA", 0xc0444d09},
{"machine/pcvt_ioctl.h", "KBDGCKEY", 0xc0484b10},
{"machine/pcvt_ioctl.h", "KBDGOKEY", 0xc0484b12},
{"net/if_ppp.h", "SIOCGPPPCSTATS", 0xc048697a},
{"net/if_ppp.h", "SIOCGPPPSTATS", 0xc048697b},
{"netinet6/in6_var.h", "SIOCGETSGCNT_IN6", 0xc050756a},
{"sys/consio.h", "CONS_GETTERM", 0xc0686370},
{"machine/i4b_debug.h", "I4B_CTL_GET_LAPDSTAT", 0xc0704304},
{"machine/soundcard.h", "SNDCTL_MIDI_INFO", 0xc074510c},
{"sys/soundcard.h", "SNDCTL_MIDI_INFO", 0xc074510c},
{"machine/comstats.h", "COM_GETPORTSTATS", 0xc080631e},
{"machine/comstats.h", "COM_CLRPORTSTATS", 0xc080631f},
{"machine/pcaudioio.h", "AUDIO_SETINFO", 0xc0844102},
{"machine/cronyx.h", "CXIOCGETMODE", 0xc0847801},
{"machine/soundcard.h", "SNDCTL_SYNTH_INFO", 0xc08c5102},
{"sys/soundcard.h", "SNDCTL_SYNTH_INFO", 0xc08c5102},
{"sys/fbio.h", "FBIO_MODEINFO", 0xc09c4667},
{"sys/fbio.h", "FBIO_FINDMODE", 0xc09c4668},
{"sys/consio.h", "CONS_MODEINFO", 0xc09c6366},
{"sys/consio.h", "CONS_FINDMODE", 0xc09c6367},
{"sys/consio.h", "CONS_ADPINFO", 0xc0a46365},
{"machine/comstats.h", "COM_GETBRDSTATS", 0xc0a86320},
{"pccard/cardinfo.h", "PIOCSDRV", 0xc0ac5006},
{"netinet/ip_fil.h", "SIOCZRLST", 0xc0c0724b},
{"machine/ioctl_bt848.h", "BT848_WEEPROM", 0xc1047832},
{"machine/ioctl_bt848.h", "BT848_REEPROM", 0xc1047833},
{"machine/ioctl_bt848.h", "BT848_SIGNATURE", 0xc1047834},
{"dev/usb/usb.h", "USB_GET_STRING_DESC", 0xc108556e},
{"netinet/ip_fil.h", "SIOCFRZST", 0xc10c724a},
{"sys/sockio.h", "SIOCGLIFADDR", 0xc118691c},
{"netinet6/in6_var.h", "SIOCGIFADDR_IN6", 0xc1206921},
{"netinet6/in6_var.h", "SIOCGIFDSTADDR_IN6", 0xc1206922},
{"netinet6/in6_var.h", "SIOCGIFNETMASK_IN6", 0xc1206925},
{"netinet6/in6_var.h", "SIOCGIFPSRCADDR_IN6", 0xc1206947},
{"netinet6/in6_var.h", "SIOCGIFPDSTADDR_IN6", 0xc1206948},
{"netinet6/in6_var.h", "SIOCGIFAFLAG_IN6", 0xc1206949},
{"netinet6/in6_var.h", "SIOCSNDFLUSH_IN6", 0xc120694d},
{"netinet6/in6_var.h", "SIOCSPFXFLUSH_IN6", 0xc120694f},
{"netinet6/in6_var.h", "SIOCSRTRFLUSH_IN6", 0xc1206950},
{"netinet6/in6_var.h", "SIOCGIFALIFETIME_IN6", 0xc1206951},
{"netinet6/in6_var.h", "SIOCSIFALIFETIME_IN6", 0xc1206952},
{"netinet6/in6_var.h", "SIOCGIFSTAT_IN6", 0xc1206953},
{"netinet6/in6_var.h", "SIOCGIFSTAT_ICMP6", 0xc1206954},
{"netinet6/in6_var.h", "SIOCGDRLST_IN6", 0xc128694a},
{"dev/usb/usb.h", "USB_DEVICEINFO", 0xc1585504},
{"cam/scsi/scsi_pass.h", "CAMIOCOMMAND", 0xc2601402},
{"cam/scsi/scsi_pass.h", "CAMGETPASSTHRU", 0xc2601403},
{"cam/scsi/scsi_targetio.h", "TARGIOCCOMMAND", 0xc2604304},
{"sys/sockio.h", "SIOCGIFSTATUS", 0xc331693b},
{"dev/usb/usb.h", "USB_GET_REPORT", 0xc4045517},
{"netinet6/in6_var.h", "SIOCGPRLST_IN6", 0xc7b8694b},
{"sys/dvdio.h", "DVDIOCREADSTRUCTURE", 0xc80c63ca},
{"machine/soundcard.h", "SNDCTL_COPR_LOAD", 0xcfb04301},
{"sys/soundcard.h", "SNDCTL_COPR_LOAD", 0xcfb04301},
{"machine/soundcard.h", "SNDCTL_PMGR_IFACE", 0xcfb85001},
{"sys/soundcard.h", "SNDCTL_PMGR_IFACE", 0xcfb85001},
{"sys/soundcard.h", "SNDCTL_PMGR_ACCESS", 0xcfb85110},
{"machine/soundcard.h", "SNDCTL_PMGR_ACCESS", 0xcfb85110},
