	{"linux/fs.h",	"FIBMAP",	0x20000001},
	{"linux/fs.h",	"FIGETBSZ",	0x20000002},
	{"linux/fd.h",	"FDGETPRM",	0x20000204},
	{"linux/fd.h",	"FDGETMAXERRS",	0x2000020e},
	{"linux/fd.h",	"FDGETDRVTYP",	0x2000020f},
	{"linux/fd.h",	"FDGETDRVPRM",	0x20000211},
	{"linux/fd.h",	"FDGETDRVSTAT",	0x20000212},
	{"linux/fd.h",	"FDPOLLDRVSTAT",	0x20000213},
	{"linux/fd.h",	"FDGETFDCSTAT",	0x20000215},
	{"linux/fd.h",	"FDWERRORGET",	0x20000217},
	{"linux/fd.h",	"FDCLRPRM",	0x20000241},
	{"linux/fd.h",	"FDSETPRM",	0x20000242},
	{"linux/fd.h",	"FDDEFPRM",	0x20000243},
	{"linux/fd.h",	"FDMSGON",	0x20000245},
	{"linux/fd.h",	"FDMSGOFF",	0x20000246},
	{"linux/fd.h",	"FDFMTBEG",	0x20000247},
	{"linux/fd.h",	"FDFMTTRK",	0x20000248},
	{"linux/fd.h",	"FDFMTEND",	0x20000249},
	{"linux/fd.h",	"FDSETEMSGTRESH",	0x2000024a},
	{"linux/fd.h",	"FDFLUSH",	0x2000024b},
	{"linux/fd.h",	"FDSETMAXERRS",	0x2000024c},
	{"linux/fd.h",	"FDRESET",	0x20000254},
	{"linux/fd.h",	"FDWERRORCLR",	0x20000256},
	{"linux/fd.h",	"FDRAWCMD",	0x20000258},
	{"linux/fd.h",	"FDTWADDLE",	0x20000259},
	{"linux/fd.h",	"FDEJECT",	0x2000025a},
	{"linux/fd.h",	"FDSETDRVPRM",	0x20000290},
	{"linux/umsdos_fs.h",	"UMSDOS_READDIR_DOS",	0x200004d2},
	{"linux/umsdos_fs.h",	"UMSDOS_UNLINK_DOS",	0x200004d3},
	{"linux/umsdos_fs.h",	"UMSDOS_RMDIR_DOS",	0x200004d4},
	{"linux/umsdos_fs.h",	"UMSDOS_STAT_DOS",	0x200004d5},
	{"linux/umsdos_fs.h",	"UMSDOS_CREAT_EMD",	0x200004d6},
	{"linux/umsdos_fs.h",	"UMSDOS_UNLINK_EMD",	0x200004d7},
	{"linux/umsdos_fs.h",	"UMSDOS_READDIR_EMD",	0x200004d8},
	{"linux/umsdos_fs.h",	"UMSDOS_GETVERSION",	0x200004d9},
	{"linux/umsdos_fs.h",	"UMSDOS_INIT_EMD",	0x200004da},
	{"linux/umsdos_fs.h",	"UMSDOS_DOS_SETUP",	0x200004db},
	{"linux/umsdos_fs.h",	"UMSDOS_RENAME_DOS",	0x200004dc},
	{"linux/fs.h",	"BLKROSET",	0x2000125d},
	{"linux/fs.h",	"BLKROGET",	0x2000125e},
	{"linux/fs.h",	"BLKRRPART",	0x2000125f},
	{"linux/fs.h",	"BLKGETSIZE",	0x20001260},
	{"linux/fs.h",	"BLKFLSBUF",	0x20001261},
	{"linux/fs.h",	"BLKRASET",	0x20001262},
	{"linux/fs.h",	"BLKRAGET",	0x20001263},
	{"linux/fs.h",	"BLKFRASET",	0x20001264},
	{"linux/fs.h",	"BLKFRAGET",	0x20001265},
	{"linux/fs.h",	"BLKSECTSET",	0x20001266},
	{"linux/fs.h",	"BLKSECTGET",	0x20001267},
	{"linux/fs.h",	"BLKSSZGET",	0x20001268},
	{"linux/blkpg.h",	"BLKPG",	0x20001269},
	{"linux/fs.h",	"BLKPG",	0x20001269},
	{"linux/elevator.h",	"BLKELVGET",	0x2000126a},
	{"linux/fs.h",	"BLKELVGET",	0x2000126a},
	{"linux/elevator.h",	"BLKELVSET",	0x2000126b},
	{"linux/fs.h",	"BLKELVSET",	0x2000126b},
	{"linux/agpgart.h",	"AGPIOC_INFO",	0x20004100},
	{"linux/agpgart.h",	"AGPIOC_ACQUIRE",	0x20004101},
	{"linux/apm_bios.h",	"APM_IOC_STANDBY",	0x20004101},
	{"linux/agpgart.h",	"AGPIOC_RELEASE",	0x20004102},
	{"linux/apm_bios.h",	"APM_IOC_SUSPEND",	0x20004102},
	{"linux/agpgart.h",	"AGPIOC_SETUP",	0x20004103},
	{"linux/agpgart.h",	"AGPIOC_RESERVE",	0x20004104},
	{"linux/agpgart.h",	"AGPIOC_PROTECT",	0x20004105},
	{"linux/agpgart.h",	"AGPIOC_ALLOCATE",	0x20004106},
	{"linux/agpgart.h",	"AGPIOC_DEALLOCATE",	0x20004107},
	{"linux/agpgart.h",	"AGPIOC_BIND",	0x20004108},
	{"linux/agpgart.h",	"AGPIOC_UNBIND",	0x20004109},
	{"linux/pmu.h",	"PMU_IOC_SLEEP",	0x20004200},
	{"linux/cciss_ioctl.h",	"CCISS_GETPCIINFO",	0x20004201},
	{"linux/pmu.h",	"PMU_IOC_GET_BACKLIGHT",	0x20004201},
	{"linux/cciss_ioctl.h",	"CCISS_GETINTINFO",	0x20004202},
	{"linux/pmu.h",	"PMU_IOC_SET_BACKLIGHT",	0x20004202},
	{"linux/cciss_ioctl.h",	"CCISS_SETINTINFO",	0x20004203},
	{"linux/pmu.h",	"PMU_IOC_GET_MODEL",	0x20004203},
	{"linux/cciss_ioctl.h",	"CCISS_GETNODENAME",	0x20004204},
	{"linux/pmu.h",	"PMU_IOC_HAS_ADB",	0x20004204},
	{"linux/cciss_ioctl.h",	"CCISS_SETNODENAME",	0x20004205},
	{"linux/cciss_ioctl.h",	"CCISS_GETHEARTBEAT",	0x20004206},
	{"linux/cciss_ioctl.h",	"CCISS_GETBUSTYPES",	0x20004207},
	{"linux/cciss_ioctl.h",	"CCISS_GETFIRMVER",	0x20004208},
	{"linux/cciss_ioctl.h",	"CCISS_GETDRIVVER",	0x20004209},
	{"linux/cciss_ioctl.h",	"CCISS_REVALIDVOLS",	0x2000420a},
	{"linux/cciss_ioctl.h",	"CCISS_PASSTHRU",	0x2000420b},
	{"linux/capi.h",	"CAPI_REGISTER",	0x20004301},
	{"linux/capi.h",	"CAPI_GET_MANUFACTURER",	0x20004306},
	{"linux/capi.h",	"CAPI_GET_VERSION",	0x20004307},
	{"linux/capi.h",	"CAPI_GET_SERIAL",	0x20004308},
	{"linux/capi.h",	"CAPI_GET_PROFILE",	0x20004309},
	{"linux/capi.h",	"CAPI_MANUFACTURER_CMD",	0x20004320},
	{"linux/capi.h",	"CAPI_GET_ERRCODE",	0x20004321},
	{"linux/capi.h",	"CAPI_INSTALLED",	0x20004322},
	{"linux/capi.h",	"CAPI_GET_FLAGS",	0x20004323},
	{"linux/capi.h",	"CAPI_SET_FLAGS",	0x20004324},
	{"linux/capi.h",	"CAPI_CLR_FLAGS",	0x20004325},
	{"linux/capi.h",	"CAPI_NCCI_OPENCOUNT",	0x20004326},
	{"linux/capi.h",	"CAPI_NCCI_GETUNIT",	0x20004327},
	{"linux/input.h",	"EVIOCGVERSION",	0x20004501},
	{"linux/input.h",	"EVIOCGID",	0x20004502},
	{"linux/input.h",	"EVIOCGREP",	0x20004503},
	{"linux/input.h",	"EVIOCSREP",	0x20004503},
	{"linux/input.h",	"EVIOCGKEYCODE",	0x20004504},
	{"linux/input.h",	"EVIOCSKEYCODE",	0x20004504},
	{"linux/input.h",	"EVIOCGKEY",	0x20004505},
	{"linux/fb.h",	"FBIOGET_VBLANK",	0x20004612},
	{"linux/isdn.h",	"IIOCNETAIF",	0x20004901},
	{"linux/isdn.h",	"IIOCNETDIF",	0x20004902},
	{"linux/isdn.h",	"IIOCNETSCF",	0x20004903},
	{"linux/isdn.h",	"IIOCNETGCF",	0x20004904},
	{"linux/isdn.h",	"IIOCNETANM",	0x20004905},
	{"linux/isdn.h",	"IIOCNETDNM",	0x20004906},
	{"linux/isdn.h",	"IIOCNETGNM",	0x20004907},
	{"linux/isdn.h",	"IIOCGETSET",	0x20004908},
	{"linux/isdn.h",	"IIOCSETSET",	0x20004909},
	{"linux/isdn.h",	"IIOCSETVER",	0x2000490a},
	{"linux/isdn.h",	"IIOCNETHUP",	0x2000490b},
	{"linux/isdn.h",	"IIOCSETGST",	0x2000490c},
	{"linux/isdn.h",	"IIOCSETBRJ",	0x2000490d},
	{"linux/isdn.h",	"IIOCSIGPRF",	0x2000490e},
	{"linux/isdn.h",	"IIOCGETPRF",	0x2000490f},
	{"linux/isdn.h",	"IIOCSETPRF",	0x20004910},
	{"linux/isdn.h",	"IIOCGETMAP",	0x20004911},
	{"linux/isdn.h",	"IIOCSETMAP",	0x20004912},
	{"linux/isdn.h",	"IIOCNETASL",	0x20004913},
	{"linux/isdn.h",	"IIOCNETDIL",	0x20004914},
	{"linux/isdn.h",	"IIOCGETCPS",	0x20004915},
	{"linux/isdn.h",	"IIOCGETDVR",	0x20004916},
	{"linux/isdn.h",	"IIOCNETLCR",	0x20004917},
	{"linux/isdn.h",	"IIOCNETDWRSET",	0x20004918},
	{"linux/isdn.h",	"IIOCNETALN",	0x20004920},
	{"linux/isdn.h",	"IIOCNETDLN",	0x20004921},
	{"linux/isdn.h",	"IIOCNETGPN",	0x20004922},
	{"linux/isdn.h",	"IIOCDBGVAR",	0x2000497f},
	{"linux/isdn.h",	"IIOCDRVCTL",	0x20004980},
	{"linux/random.h",	"RNDGETENTCNT",	0x20005200},
	{"linux/random.h",	"RNDADDTOENTCNT",	0x20005201},
	{"linux/random.h",	"RNDGETPOOL",	0x20005202},
	{"linux/random.h",	"RNDADDENTROPY",	0x20005203},
	{"linux/random.h",	"RNDZAPENTCNT",	0x20005204},
	{"linux/random.h",	"RNDCLEARPOOL",	0x20005206},
	{"asm-alpha/ioctls.h",	"TIOCGPTN",	0x20005430},
	{"asm-alpha/ioctls.h",	"TIOCSPTLCK",	0x20005431},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CONTROL",	0x20005500},
	{"linux/usbdevice_fs.h",	"USBDEVFS_BULK",	0x20005502},
	{"linux/usbdevice_fs.h",	"USBDEVFS_RESETEP",	0x20005503},
	{"linux/usbdevice_fs.h",	"USBDEVFS_SETINTERFACE",	0x20005504},
	{"linux/usbdevice_fs.h",	"USBDEVFS_SETCONFIGURATION",	0x20005505},
	{"linux/usbdevice_fs.h",	"USBDEVFS_GETDRIVER",	0x20005508},
	{"linux/usbdevice_fs.h",	"USBDEVFS_SUBMITURB",	0x2000550a},
	{"linux/usbdevice_fs.h",	"USBDEVFS_DISCARDURB",	0x2000550b},
	{"linux/usbdevice_fs.h",	"USBDEVFS_REAPURB",	0x2000550c},
	{"linux/usbdevice_fs.h",	"USBDEVFS_REAPURBNDELAY",	0x2000550d},
	{"linux/usbdevice_fs.h",	"USBDEVFS_DISCSIGNAL",	0x2000550e},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CLAIMINTERFACE",	0x2000550f},
	{"linux/usbdevice_fs.h",	"USBDEVFS_RELEASEINTERFACE",	0x20005510},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CONNECTINFO",	0x20005511},
	{"linux/usbdevice_fs.h",	"USBDEVFS_IOCTL",	0x20005512},
	{"linux/usbdevice_fs.h",	"USBDEVFS_HUB_PORTINFO",	0x20005513},
	{"linux/usbdevice_fs.h",	"USBDEVFS_RESET",	0x20005514},
	{"linux/usbdevice_fs.h",	"USBDEVFS_CLEAR_HALT",	0x20005515},
	{"linux/watchdog.h",	"WDIOC_GETSUPPORT",	0x20005700},
	{"linux/watchdog.h",	"WDIOC_GETSTATUS",	0x20005701},
	{"linux/watchdog.h",	"WDIOC_GETBOOTSTATUS",	0x20005702},
	{"linux/watchdog.h",	"WDIOC_GETTEMP",	0x20005703},
	{"linux/watchdog.h",	"WDIOC_SETOPTIONS",	0x20005704},
	{"linux/watchdog.h",	"WDIOC_KEEPALIVE",	0x20005705},
	{"linux/sonet.h",	"SONET_GETSTAT",	0x20006110},
	{"linux/sonet.h",	"SONET_GETSTATZ",	0x20006111},
	{"linux/sonet.h",	"SONET_SETDIAG",	0x20006112},
	{"linux/sonet.h",	"SONET_CLRDIAG",	0x20006113},
	{"linux/sonet.h",	"SONET_GETDIAG",	0x20006114},
	{"linux/sonet.h",	"SONET_SETFRAMING",	0x20006115},
	{"linux/sonet.h",	"SONET_GETFRAMING",	0x20006116},
	{"linux/sonet.h",	"SONET_GETFRSENSE",	0x20006117},
	{"linux/atm_idt77105.h",	"IDT77105_GETSTAT",	0x20006132},
	{"linux/atm_idt77105.h",	"IDT77105_GETSTATZ",	0x20006133},
	{"linux/atmdev.h",	"ATM_GETSTAT",	0x20006150},
	{"linux/atmdev.h",	"ATM_GETSTATZ",	0x20006151},
	{"linux/atmdev.h",	"ATM_GETLOOP",	0x20006152},
	{"linux/atmdev.h",	"ATM_SETLOOP",	0x20006153},
	{"linux/atmdev.h",	"ATM_QUERYLOOP",	0x20006154},
	{"linux/atm_eni.h",	"ENI_MEMDUMP",	0x20006160},
	{"linux/atm_nicstar.h",	"NS_GETPSTAT",	0x20006161},
	{"linux/atm_zatm.h",	"ZATM_GETPOOL",	0x20006161},
	{"linux/atm_nicstar.h",	"NS_SETBUFLEV",	0x20006162},
	{"linux/atm_zatm.h",	"ZATM_GETPOOLZ",	0x20006162},
	{"linux/atm_nicstar.h",	"NS_ADJBUFLEV",	0x20006163},
	{"linux/atm_zatm.h",	"ZATM_SETPOOL",	0x20006163},
	{"linux/atm_zatm.h",	"ZATM_GETTHIST",	0x20006164},
	{"linux/atm_eni.h",	"ENI_SETMULT",	0x20006167},
	{"linux/atm_tcp.h",	"SIOCSIFATMTCP",	0x20006180},
	{"linux/atmdev.h",	"ATM_GETLINKRATE",	0x20006181},
	{"linux/atmdev.h",	"ATM_GETNAMES",	0x20006183},
	{"linux/atmdev.h",	"ATM_GETTYPE",	0x20006184},
	{"linux/atmdev.h",	"ATM_GETESI",	0x20006185},
	{"linux/atmdev.h",	"ATM_GETADDR",	0x20006186},
	{"linux/atmdev.h",	"ATM_RSTADDR",	0x20006187},
	{"linux/atmdev.h",	"ATM_ADDADDR",	0x20006188},
	{"linux/atmdev.h",	"ATM_DELADDR",	0x20006189},
	{"linux/atmdev.h",	"ATM_GETCIRANGE",	0x2000618a},
	{"linux/atmdev.h",	"ATM_SETCIRANGE",	0x2000618b},
	{"linux/atmdev.h",	"ATM_SETESI",	0x2000618c},
	{"linux/atmdev.h",	"ATM_SETESIF",	0x2000618d},
	{"linux/atm_tcp.h",	"ATMTCP_CREATE",	0x2000618e},
	{"linux/atm_tcp.h",	"ATMTCP_REMOVE",	0x2000618f},
	{"linux/atmlec.h",	"ATMLEC_CTRL",	0x200061d0},
	{"linux/atmlec.h",	"ATMLEC_DATA",	0x200061d1},
	{"linux/atmlec.h",	"ATMLEC_MCAST",	0x200061d2},
	{"linux/atmmpc.h",	"ATMMPC_CTRL",	0x200061d8},
	{"linux/atmmpc.h",	"ATMMPC_DATA",	0x200061d9},
	{"linux/atmclip.h",	"SIOCMKCLIP",	0x200061e0},
	{"linux/atmarp.h",	"ATMARPD_CTRL",	0x200061e1},
	{"linux/atmarp.h",	"ATMARP_MKIP",	0x200061e2},
	{"linux/atmarp.h",	"ATMARP_SETENTRY",	0x200061e3},
	{"linux/atmarp.h",	"ATMARP_ENCAP",	0x200061e5},
	{"linux/atmsvc.h",	"ATMSIGD_CTRL",	0x200061f0},
	{"linux/atmdev.h",	"ATM_SETSC",	0x200061f1},
	{"linux/coda.h",	"CIOC_KERNEL_VERSION",	0x2000630a},
	{"linux/comstats.h",	"COM_GETPORTSTATS",	0x2000631e},
	{"linux/comstats.h",	"COM_CLRPORTSTATS",	0x2000631f},
	{"linux/comstats.h",	"COM_GETBRDSTATS",	0x20006320},
	{"linux/comstats.h",	"COM_READPORT",	0x20006328},
	{"linux/comstats.h",	"COM_READBOARD",	0x20006329},
	{"linux/comstats.h",	"COM_READPANEL",	0x2000632a},
	{"linux/devfs_fs.h",	"DEVFSDIOC_GET_PROTO_REV",	0x20006400},
	{"linux/video_decoder.h",	"DECODER_GET_CAPABILITIES",	0x20006401},
	{"linux/devfs_fs.h",	"DEVFSDIOC_SET_EVENT_MASK",	0x20006402},
	{"linux/video_decoder.h",	"DECODER_GET_STATUS",	0x20006402},
	{"linux/devfs_fs.h",	"DEVFSDIOC_RELEASE_EVENT_QUEUE",	0x20006403},
	{"linux/video_decoder.h",	"DECODER_SET_NORM",	0x20006403},
	{"linux/devfs_fs.h",	"DEVFSDIOC_SET_DEBUG_MASK",	0x20006404},
	{"linux/video_decoder.h",	"DECODER_SET_INPUT",	0x20006404},
	{"linux/video_decoder.h",	"DECODER_SET_OUTPUT",	0x20006405},
	{"linux/video_decoder.h",	"DECODER_ENABLE_OUTPUT",	0x20006406},
	{"linux/video_decoder.h",	"DECODER_SET_PICTURE",	0x20006407},
	{"linux/video_decoder.h",	"DECODER_DUMP",	0x200064c0},
	{"linux/video_encoder.h",	"ENCODER_GET_CAPABILITIES",	0x20006501},
	{"linux/video_encoder.h",	"ENCODER_SET_NORM",	0x20006502},
	{"linux/video_encoder.h",	"ENCODER_SET_INPUT",	0x20006503},
	{"linux/video_encoder.h",	"ENCODER_SET_OUTPUT",	0x20006504},
	{"linux/video_encoder.h",	"ENCODER_ENABLE_OUTPUT",	0x20006505},
	{"linux/ext2_fs.h",	"EXT2_IOC_GETFLAGS",	0x20006601},
	{"asm-alpha/ioctls.h",	"FIOCLEX",	0x20006601},
	{"linux/ext2_fs.h",	"EXT2_IOC_SETFLAGS",	0x20006602},
	{"asm-alpha/ioctls.h",	"FIONCLEX",	0x20006602},
	{"asm-alpha/sockios.h",	"FIOGETOWN",	0x2000667b},
	{"asm-alpha/sockios.h",	"FIOSETOWN",	0x2000667c},
	{"asm-alpha/ioctls.h",	"FIOASYNC",	0x2000667d},
	{"asm-alpha/ioctls.h",	"FIONBIO",	0x2000667e},
	{"asm-alpha/ioctls.h",	"FIONREAD",	0x2000667f},
	{"linux/i2o-dev.h",	"I2OGETIOPS",	0x20006900},
	{"linux/i2o-dev.h",	"I2OHRTGET",	0x20006901},
	{"linux/i2o-dev.h",	"I2OLCTGET",	0x20006902},
	{"linux/i2o-dev.h",	"I2OPARMSET",	0x20006903},
	{"linux/i2o-dev.h",	"I2OPARMGET",	0x20006904},
	{"linux/i2o-dev.h",	"I2OSWDL",	0x20006905},
	{"linux/i2o-dev.h",	"I2OSWUL",	0x20006906},
	{"linux/i2o-dev.h",	"I2OSWDEL",	0x20006907},
	{"linux/i2o-dev.h",	"I2OVALIDATE",	0x20006908},
	{"linux/i2o-dev.h",	"I2OHTML",	0x20006909},
	{"linux/i2o-dev.h",	"I2OEVTREG",	0x2000690a},
	{"linux/i2o-dev.h",	"I2OEVTGET",	0x2000690b},
	{"linux/joystick.h",	"JSIOCGVERSION",	0x20006a01},
	{"linux/joystick.h",	"JSIOCGAXES",	0x20006a11},
	{"linux/joystick.h",	"JSIOCGBUTTONS",	0x20006a12},
	{"linux/joystick.h",	"JSIOCSCORR",	0x20006a21},
	{"linux/joystick.h",	"JSIOCGCORR",	0x20006a22},
	{"linux/udf_fs_i.h",	"UDF_GETEASIZE",	0x20006c40},
	{"linux/udf_fs_i.h",	"UDF_GETEABLOCK",	0x20006c41},
	{"linux/udf_fs_i.h",	"UDF_GETVOLIDENT",	0x20006c42},
	{"linux/synclink.h",	"MGSL_IOCSPARAMS",	0x20006d00},
	{"linux/mtio.h",	"MTIOCTOP",	0x20006d01},
	{"linux/synclink.h",	"MGSL_IOCGPARAMS",	0x20006d01},
	{"linux/mtio.h",	"MTIOCGET",	0x20006d02},
	{"linux/synclink.h",	"MGSL_IOCSTXIDLE",	0x20006d02},
	{"linux/mtio.h",	"MTIOCPOS",	0x20006d03},
	{"linux/synclink.h",	"MGSL_IOCGTXIDLE",	0x20006d03},
	{"linux/mtio.h",	"MTIOCGETCONFIG",	0x20006d04},
	{"linux/synclink.h",	"MGSL_IOCTXENABLE",	0x20006d04},
	{"linux/mtio.h",	"MTIOCSETCONFIG",	0x20006d05},
	{"linux/synclink.h",	"MGSL_IOCRXENABLE",	0x20006d05},
	{"linux/mtio.h",	"MTIOCRDFTSEG",	0x20006d06},
	{"linux/synclink.h",	"MGSL_IOCTXABORT",	0x20006d06},
	{"linux/mtio.h",	"MTIOCWRFTSEG",	0x20006d07},
	{"linux/synclink.h",	"MGSL_IOCGSTATS",	0x20006d07},
	{"linux/mtio.h",	"MTIOCVOLINFO",	0x20006d08},
	{"linux/synclink.h",	"MGSL_IOCWAITEVENT",	0x20006d08},
	{"linux/mtio.h",	"MTIOCGETSIZE",	0x20006d09},
	{"linux/synclink.h",	"MGSL_IOCLOOPTXDONE",	0x20006d09},
	{"linux/mtio.h",	"MTIOCFTFORMAT",	0x20006d0a},
	{"linux/mtio.h",	"MTIOCFTCMD",	0x20006d0b},
	{"linux/synclink.h",	"MGSL_IOCCLRMODCOUNT",	0x20006d0f},
	{"linux/zftape.h",	"MTIOC_ZFTAPE_GETBLKSZ",	0x20006d68},
	{"linux/ncp_fs.h",	"NCP_IOC_NCPREQUEST",	0x20006e01},
	{"linux/ncp_fs.h",	"NCP_IOC_GETMOUNTUID",	0x20006e02},
	{"linux/ncp_fs.h",	"NCP_IOC_GETMOUNTUID2",	0x20006e02},
	{"linux/ncp_fs.h",	"NCP_IOC_CONN_LOGGED_IN",	0x20006e03},
	{"linux/ncp_fs.h",	"NCP_IOC_GET_FS_INFO",	0x20006e04},
	{"linux/ncp_fs.h",	"NCP_IOC_GET_FS_INFO_V2",	0x20006e04},
	{"linux/ncp_fs.h",	"NCP_IOC_SIGN_INIT",	0x20006e05},
	{"linux/ncp_fs.h",	"NCP_IOC_SIGN_WANTED",	0x20006e06},
	{"linux/ncp_fs.h",	"NCP_IOC_SET_SIGN_WANTED",	0x20006e06},
	{"linux/ncp_fs.h",	"NCP_IOC_LOCKUNLOCK",	0x20006e07},
	{"linux/ncp_fs.h",	"NCP_IOC_GETROOT",	0x20006e08},
	{"linux/ncp_fs.h",	"NCP_IOC_SETROOT",	0x20006e08},
	{"linux/ncp_fs.h",	"NCP_IOC_GETOBJECTNAME",	0x20006e09},
	{"linux/ncp_fs.h",	"NCP_IOC_SETOBJECTNAME",	0x20006e09},
	{"linux/ncp_fs.h",	"NCP_IOC_GETPRIVATEDATA",	0x20006e0a},
	{"linux/ncp_fs.h",	"NCP_IOC_SETPRIVATEDATA",	0x20006e0a},
	{"linux/ncp_fs.h",	"NCP_IOC_GETCHARSETS",	0x20006e0b},
	{"linux/ncp_fs.h",	"NCP_IOC_SETCHARSETS",	0x20006e0b},
	{"linux/ncp_fs.h",	"NCP_IOC_GETDENTRYTTL",	0x20006e0c},
	{"linux/ncp_fs.h",	"NCP_IOC_SETDENTRYTTL",	0x20006e0c},
	{"linux/matroxfb.h",	"MATROXFB_SET_OUTPUT_CONNECTION",	0x20006ef8},
	{"linux/matroxfb.h",	"MATROXFB_GET_OUTPUT_CONNECTION",	0x20006ef8},
	{"linux/matroxfb.h",	"MATROXFB_GET_AVAILABLE_OUTPUTS",	0x20006ef9},
	{"linux/matroxfb.h",	"MATROXFB_SET_OUTPUT_MODE",	0x20006efa},
	{"linux/matroxfb.h",	"MATROXFB_GET_OUTPUT_MODE",	0x20006efa},
	{"linux/matroxfb.h",	"MATROXFB_GET_ALL_OUTPUTS",	0x20006efb},
	{"linux/rtc.h",	"RTC_AIE_ON",	0x20007001},
	{"linux/rtc.h",	"RTC_AIE_OFF",	0x20007002},
	{"linux/rtc.h",	"RTC_UIE_ON",	0x20007003},
	{"linux/rtc.h",	"RTC_UIE_OFF",	0x20007004},
	{"linux/rtc.h",	"RTC_PIE_ON",	0x20007005},
	{"linux/rtc.h",	"RTC_PIE_OFF",	0x20007006},
	{"linux/rtc.h",	"RTC_ALM_SET",	0x20007007},
	{"linux/rtc.h",	"RTC_ALM_READ",	0x20007008},
	{"linux/rtc.h",	"RTC_RD_TIME",	0x20007009},
	{"linux/rtc.h",	"RTC_SET_TIME",	0x2000700a},
	{"linux/rtc.h",	"RTC_IRQP_READ",	0x2000700b},
	{"linux/rtc.h",	"RTC_IRQP_SET",	0x2000700c},
	{"linux/rtc.h",	"RTC_EPOCH_READ",	0x2000700d},
	{"linux/rtc.h",	"RTC_EPOCH_SET",	0x2000700e},
	{"linux/rtc.h",	"RTC_WIE_ON",	0x2000700f},
	{"linux/rtc.h",	"RTC_WKALM_SET",	0x2000700f},
	{"linux/rtc.h",	"RTC_WIE_OFF",	0x20007010},
	{"linux/rtc.h",	"RTC_WKALM_RD",	0x20007010},
	{"linux/nvram.h",	"NVRAM_INIT",	0x20007040},
	{"linux/nvram.h",	"NVRAM_SETCKS",	0x20007041},
	{"linux/ppdev.h",	"PPSETMODE",	0x20007080},
	{"linux/ppdev.h",	"PPRSTATUS",	0x20007081},
	{"linux/ppdev.h",	"PPRCONTROL",	0x20007083},
	{"linux/ppdev.h",	"PPWCONTROL",	0x20007084},
	{"linux/ppdev.h",	"PPRDATA",	0x20007085},
	{"linux/ppdev.h",	"PPWDATA",	0x20007086},
	{"linux/ppdev.h",	"PPCLAIM",	0x2000708b},
	{"linux/ppdev.h",	"PPRELEASE",	0x2000708c},
	{"linux/ppdev.h",	"PPYIELD",	0x2000708d},
	{"linux/ppdev.h",	"PPFCONTROL",	0x2000708e},
	{"linux/ppdev.h",	"PPEXCL",	0x2000708f},
	{"linux/ppdev.h",	"PPDATADIR",	0x20007090},
	{"linux/ppdev.h",	"PPNEGOT",	0x20007091},
	{"linux/ppdev.h",	"PPWCTLONIRQ",	0x20007092},
	{"linux/ppdev.h",	"PPCLRIRQ",	0x20007093},
	{"linux/ppdev.h",	"PPSETPHASE",	0x20007094},
	{"linux/ppdev.h",	"PPGETTIME",	0x20007095},
	{"linux/ppdev.h",	"PPSETTIME",	0x20007096},
	{"linux/serio.h",	"SPIOCSTYPE",	0x20007101},
	{"linux/telephony.h",	"PHONE_CAPABILITIES",	0x20007180},
	{"linux/telephony.h",	"PHONE_CAPABILITIES_LIST",	0x20007181},
	{"linux/telephony.h",	"PHONE_CAPABILITIES_CHECK",	0x20007182},
	{"linux/telephony.h",	"PHONE_RING",	0x20007183},
	{"linux/telephony.h",	"PHONE_HOOKSTATE",	0x20007184},
	{"linux/telephony.h",	"PHONE_MAXRINGS",	0x20007185},
	{"linux/telephony.h",	"PHONE_RING_CADENCE",	0x20007186},
	{"linux/telephony.h",	"OLD_PHONE_RING_START",	0x20007187},
	{"linux/telephony.h",	"PHONE_RING_START",	0x20007187},
	{"linux/telephony.h",	"PHONE_RING_STOP",	0x20007188},
	{"linux/telephony.h",	"PHONE_REC_CODEC",	0x20007189},
	{"linux/telephony.h",	"PHONE_REC_START",	0x2000718a},
	{"linux/telephony.h",	"PHONE_REC_STOP",	0x2000718b},
	{"linux/telephony.h",	"PHONE_REC_DEPTH",	0x2000718c},
	{"linux/telephony.h",	"PHONE_FRAME",	0x2000718d},
	{"linux/telephony.h",	"PHONE_REC_VOLUME",	0x2000718e},
	{"linux/telephony.h",	"PHONE_REC_LEVEL",	0x2000718f},
	{"linux/telephony.h",	"PHONE_PLAY_CODEC",	0x20007190},
	{"linux/telephony.h",	"PHONE_PLAY_START",	0x20007191},
	{"linux/telephony.h",	"PHONE_PLAY_STOP",	0x20007192},
	{"linux/telephony.h",	"PHONE_PLAY_DEPTH",	0x20007193},
	{"linux/telephony.h",	"PHONE_PLAY_VOLUME",	0x20007194},
	{"linux/telephony.h",	"PHONE_PLAY_LEVEL",	0x20007195},
	{"linux/telephony.h",	"PHONE_DTMF_READY",	0x20007196},
	{"linux/telephony.h",	"PHONE_GET_DTMF",	0x20007197},
	{"linux/telephony.h",	"PHONE_GET_DTMF_ASCII",	0x20007198},
	{"linux/telephony.h",	"PHONE_DTMF_OOB",	0x20007199},
	{"linux/telephony.h",	"PHONE_EXCEPTION",	0x2000719a},
	{"linux/telephony.h",	"PHONE_PLAY_TONE",	0x2000719b},
	{"linux/telephony.h",	"PHONE_SET_TONE_ON_TIME",	0x2000719c},
	{"linux/telephony.h",	"PHONE_SET_TONE_OFF_TIME",	0x2000719d},
	{"linux/telephony.h",	"PHONE_GET_TONE_ON_TIME",	0x2000719e},
	{"linux/telephony.h",	"PHONE_GET_TONE_OFF_TIME",	0x2000719f},
	{"linux/telephony.h",	"PHONE_GET_TONE_STATE",	0x200071a0},
	{"linux/telephony.h",	"PHONE_BUSY",	0x200071a1},
	{"linux/telephony.h",	"PHONE_RINGBACK",	0x200071a2},
	{"linux/telephony.h",	"PHONE_DIALTONE",	0x200071a3},
	{"linux/telephony.h",	"PHONE_CPT_STOP",	0x200071a4},
	{"linux/telephony.h",	"PHONE_PSTN_SET_STATE",	0x200071a4},
	{"linux/telephony.h",	"PHONE_PSTN_GET_STATE",	0x200071a5},
	{"linux/telephony.h",	"PHONE_WINK_DURATION",	0x200071a6},
	{"linux/telephony.h",	"PHONE_QUERY_CODEC",	0x200071a7},
	{"linux/telephony.h",	"PHONE_PSTN_LINETEST",	0x200071a8},
	{"linux/telephony.h",	"PHONE_VAD",	0x200071a9},
	{"linux/ixjuser.h",	"IXJCTL_DSP_RESET",	0x200071c0},
	{"linux/ixjuser.h",	"IXJCTL_CARDTYPE",	0x200071c1},
	{"linux/ixjuser.h",	"IXJCTL_SERIAL",	0x200071c2},
	{"linux/ixjuser.h",	"IXJCTL_DSP_TYPE",	0x200071c3},
	{"linux/ixjuser.h",	"IXJCTL_DSP_VERSION",	0x200071c4},
	{"linux/ixjuser.h",	"IXJCTL_DSP_IDLE",	0x200071c5},
	{"linux/ixjuser.h",	"IXJCTL_TESTRAM",	0x200071c6},
	{"linux/ixjuser.h",	"IXJCTL_SET_FILTER",	0x200071c7},
	{"linux/ixjuser.h",	"IXJCTL_GET_FILTER_HIST",	0x200071c8},
	{"linux/ixjuser.h",	"IXJCTL_INIT_TONE",	0x200071c9},
	{"linux/ixjuser.h",	"IXJCTL_TONE_CADENCE",	0x200071ca},
	{"linux/ixjuser.h",	"IXJCTL_AEC_START",	0x200071cb},
	{"linux/ixjuser.h",	"IXJCTL_AEC_STOP",	0x200071cc},
	{"linux/ixjuser.h",	"IXJCTL_AEC_GET_LEVEL",	0x200071cd},
	{"linux/ixjuser.h",	"IXJCTL_SET_LED",	0x200071ce},
	{"linux/ixjuser.h",	"IXJCTL_MIXER",	0x200071cf},
	{"linux/ixjuser.h",	"IXJCTL_DAA_COEFF_SET",	0x200071d0},
	{"linux/ixjuser.h",	"IXJCTL_PORT",	0x200071d1},
	{"linux/ixjuser.h",	"IXJCTL_DAA_AGAIN",	0x200071d2},
	{"linux/ixjuser.h",	"IXJCTL_PSTN_LINETEST",	0x200071d3},
	{"linux/ixjuser.h",	"IXJCTL_CID",	0x200071d4},
	{"linux/ixjuser.h",	"IXJCTL_POTS_PSTN",	0x200071d5},
	{"linux/ixjuser.h",	"IXJCTL_FILTER_CADENCE",	0x200071d6},
	{"linux/ixjuser.h",	"IXJCTL_PLAY_CID",	0x200071d7},
	{"linux/ixjuser.h",	"IXJCTL_VMWI",	0x200071d8},
	{"linux/ixjuser.h",	"IXJCTL_CIDCW",	0x200071d9},
	{"linux/ixjuser.h",	"IXJCTL_VERSION",	0x200071da},
	{"linux/ixjuser.h",	"IXJCTL_HZ",	0x200071e0},
	{"linux/ixjuser.h",	"IXJCTL_RATE",	0x200071e1},
	{"linux/ixjuser.h",	"IXJCTL_FRAMES_READ",	0x200071e2},
	{"linux/ixjuser.h",	"IXJCTL_FRAMES_WRITTEN",	0x200071e3},
	{"linux/ixjuser.h",	"IXJCTL_READ_WAIT",	0x200071e4},
	{"linux/ixjuser.h",	"IXJCTL_WRITE_WAIT",	0x200071e5},
	{"linux/ixjuser.h",	"IXJCTL_DRYBUFFER_READ",	0x200071e6},
	{"linux/ixjuser.h",	"IXJCTL_DRYBUFFER_CLEAR",	0x200071e7},
	{"linux/ixjuser.h",	"IXJCTL_INTERCOM_START",	0x200071fd},
	{"linux/ixjuser.h",	"IXJCTL_INTERCOM_STOP",	0x200071fe},
	{"linux/msdos_fs.h",	"VFAT_IOCTL_READDIR_BOTH",	0x20007201},
	{"linux/msdos_fs.h",	"VFAT_IOCTL_READDIR_SHORT",	0x20007202},
	{"asm-alpha/sockios.h",	"SIOCATMARK",	0x20007307},
	{"asm-alpha/sockios.h",	"SIOCSPGRP",	0x20007308},
	{"asm-alpha/sockios.h",	"SIOCGPGRP",	0x20007309},
	{"linux/cdk.h",	"STL_BINTR",	0x20007314},
	{"linux/cdk.h",	"STL_BSTART",	0x20007315},
	{"linux/cdk.h",	"STL_BSTOP",	0x20007316},
	{"linux/cdk.h",	"STL_BRESET",	0x20007317},
	{"linux/cdk.h",	"STL_GETPFLAG",	0x20007350},
	{"linux/cdk.h",	"STL_SETPFLAG",	0x20007351},
	{"asm-alpha/ioctls.h",	"TIOCGETP",	0x20007408},
	{"asm-alpha/ioctls.h",	"TIOCSETP",	0x20007409},
	{"asm-alpha/ioctls.h",	"TIOCSETN",	0x2000740a},
	{"asm-alpha/ioctls.h",	"TIOCSETC",	0x20007411},
	{"asm-alpha/ioctls.h",	"TIOCGETC",	0x20007412},
	{"asm-alpha/ioctls.h",	"TCGETS",	0x20007413},
	{"asm-alpha/ioctls.h",	"TCSETS",	0x20007414},
	{"asm-alpha/ioctls.h",	"TCSETSW",	0x20007415},
	{"asm-alpha/ioctls.h",	"TCSETSF",	0x20007416},
	{"asm-alpha/ioctls.h",	"TCGETA",	0x20007417},
	{"asm-alpha/ioctls.h",	"TCSETA",	0x20007418},
	{"asm-alpha/ioctls.h",	"TCSETAW",	0x20007419},
	{"asm-alpha/ioctls.h",	"TCSETAF",	0x2000741c},
	{"asm-alpha/ioctls.h",	"TCSBRK",	0x2000741d},
	{"asm-alpha/ioctls.h",	"TCXONC",	0x2000741e},
	{"asm-alpha/ioctls.h",	"TCFLSH",	0x2000741f},
	{"linux/if_ppp.h",	"PPPIOCGCHAN",	0x20007437},
	{"linux/if_ppp.h",	"PPPIOCATTCHAN",	0x20007438},
	{"linux/if_ppp.h",	"PPPIOCDISCONN",	0x20007439},
	{"linux/if_ppp.h",	"PPPIOCCONNECT",	0x2000743a},
	{"linux/if_ppp.h",	"PPPIOCSMRRU",	0x2000743b},
	{"linux/if_ppp.h",	"PPPIOCDETACH",	0x2000743c},
	{"linux/if_ppp.h",	"PPPIOCATTACH",	0x2000743d},
	{"linux/if_ppp.h",	"PPPIOCNEWUNIT",	0x2000743e},
	{"linux/if_ppp.h",	"PPPIOCGIDLE",	0x2000743f},
	{"linux/if_ppp.h",	"PPPIOCSDEBUG",	0x20007440},
	{"linux/if_ppp.h",	"PPPIOCGDEBUG",	0x20007441},
	{"linux/if_ppp.h",	"PPPIOCSNPMODE",	0x2000744b},
	{"linux/if_ppp.h",	"PPPIOCGNPMODE",	0x2000744c},
	{"linux/if_ppp.h",	"PPPIOCSCOMPRESS",	0x2000744d},
	{"linux/if_ppp.h",	"PPPIOCXFERUNIT",	0x2000744e},
	{"linux/if_ppp.h",	"PPPIOCSXASYNCMAP",	0x2000744f},
	{"linux/if_ppp.h",	"PPPIOCGXASYNCMAP",	0x20007450},
	{"linux/if_ppp.h",	"PPPIOCSMAXCID",	0x20007451},
	{"linux/if_ppp.h",	"PPPIOCSMRU",	0x20007452},
	{"linux/if_ppp.h",	"PPPIOCGMRU",	0x20007453},
	{"linux/if_ppp.h",	"PPPIOCSRASYNCMAP",	0x20007454},
	{"linux/if_ppp.h",	"PPPIOCGRASYNCMAP",	0x20007455},
	{"linux/if_ppp.h",	"PPPIOCGUNIT",	0x20007456},
	{"linux/if_ppp.h",	"PPPIOCSASYNCMAP",	0x20007457},
	{"linux/if_ppp.h",	"PPPIOCGASYNCMAP",	0x20007458},
	{"linux/if_ppp.h",	"PPPIOCSFLAGS",	0x20007459},
	{"linux/if_ppp.h",	"PPPIOCGFLAGS",	0x2000745a},
	{"linux/jffs.h",	"JFFS_PRINT_HASH",	0x2000745a},
	{"linux/jffs.h",	"JFFS_PRINT_TREE",	0x2000745b},
	{"linux/jffs.h",	"JFFS_GET_STATUS",	0x2000745c},
	{"asm-alpha/ioctls.h",	"TIOCSWINSZ",	0x20007467},
	{"asm-alpha/ioctls.h",	"TIOCGWINSZ",	0x20007468},
	{"asm-alpha/ioctls.h",	"TIOCSTART",	0x2000746e},
	{"asm-alpha/ioctls.h",	"TIOCSTOP",	0x2000746f},
	{"asm-alpha/ioctls.h",	"TIOCOUTQ",	0x20007473},
	{"asm-alpha/ioctls.h",	"TIOCGLTC",	0x20007474},
	{"asm-alpha/ioctls.h",	"TIOCSLTC",	0x20007475},
	{"asm-alpha/ioctls.h",	"TIOCSPGRP",	0x20007476},
	{"asm-alpha/ioctls.h",	"TIOCGPGRP",	0x20007477},
	{"linux/isdn_ppp.h",	"PPPIOCGCALLINFO",	0x20007480},
	{"linux/isdn_ppp.h",	"PPPIOCBUNDLE",	0x20007481},
	{"linux/isdn_ppp.h",	"PPPIOCGMPFLAGS",	0x20007482},
	{"linux/isdn_ppp.h",	"PPPIOCSMPFLAGS",	0x20007483},
	{"linux/isdn_ppp.h",	"PPPIOCSMPMTU",	0x20007484},
	{"linux/isdn_ppp.h",	"PPPIOCSMPMRU",	0x20007485},
	{"linux/isdn_ppp.h",	"PPPIOCGCOMPRESSORS",	0x20007486},
	{"linux/isdn_ppp.h",	"PPPIOCSCOMPRESSOR",	0x20007487},
	{"linux/isdn_ppp.h",	"PPPIOCGIFNAME",	0x20007488},
	{"linux/toshiba.h",	"TOSH_SMM",	0x20007490},
	{"linux/smb_fs.h",	"SMB_IOC_GETMOUNTUID",	0x20007501},
	{"linux/smb_fs.h",	"SMB_IOC_NEWCONN",	0x20007502},
	{"linux/smb_fs.h",	"SMB_IOC_GETMOUNTUID32",	0x20007503},
	{"linux/ext2_fs.h",	"EXT2_IOC_GETVERSION",	0x20007601},
	{"linux/videodev.h",	"VIDIOCGCAP",	0x20007601},
	{"linux/ext2_fs.h",	"EXT2_IOC_SETVERSION",	0x20007602},
	{"linux/videodev.h",	"VIDIOCGCHAN",	0x20007602},
	{"linux/videodev.h",	"VIDIOCSCHAN",	0x20007603},
	{"linux/videodev.h",	"VIDIOCGTUNER",	0x20007604},
	{"linux/videodev.h",	"VIDIOCSTUNER",	0x20007605},
	{"linux/videodev.h",	"VIDIOCGPICT",	0x20007606},
	{"linux/videodev.h",	"VIDIOCSPICT",	0x20007607},
	{"linux/videodev.h",	"VIDIOCCAPTURE",	0x20007608},
	{"linux/videodev.h",	"VIDIOCGWIN",	0x20007609},
	{"linux/videodev.h",	"VIDIOCSWIN",	0x2000760a},
	{"linux/videodev.h",	"VIDIOCGFBUF",	0x2000760b},
	{"linux/videodev.h",	"VIDIOCSFBUF",	0x2000760c},
	{"linux/videodev.h",	"VIDIOCKEY",	0x2000760d},
	{"linux/videodev.h",	"VIDIOCGFREQ",	0x2000760e},
	{"linux/videodev.h",	"VIDIOCSFREQ",	0x2000760f},
	{"linux/videodev.h",	"VIDIOCGAUDIO",	0x20007610},
	{"linux/videodev.h",	"VIDIOCSAUDIO",	0x20007611},
	{"linux/videodev.h",	"VIDIOCSYNC",	0x20007612},
	{"linux/videodev.h",	"VIDIOCMCAPTURE",	0x20007613},
	{"linux/videodev.h",	"VIDIOCGMBUF",	0x20007614},
	{"linux/videodev.h",	"VIDIOCGUNIT",	0x20007615},
	{"linux/videodev.h",	"VIDIOCGCAPTURE",	0x20007616},
	{"linux/videodev.h",	"VIDIOCSCAPTURE",	0x20007617},
	{"linux/videodev.h",	"VIDIOCSPLAYMODE",	0x20007618},
	{"linux/videodev.h",	"VIDIOCSWRITEMODE",	0x20007619},
	{"linux/videodev.h",	"VIDIOCGPLAYINFO",	0x2000761a},
	{"linux/videodev.h",	"VIDIOCSMICROCODE",	0x2000761b},
	{"linux/videodev.h",	"VIDIOCGVBIFMT",	0x2000761c},
	{"linux/videodev.h",	"VIDIOCSVBIFMT",	0x2000761d},
	{"linux/dn.h",	"SIOCSNETADDR",	0x200089e0},
	{"linux/dn.h",	"OSIOCSNETADDR",	0x200089e0},
	{"linux/dn.h",	"SIOCGNETADDR",	0x200089e1},
	{"linux/dn.h",	"OSIOCGNETADDR",	0x200089e1},
	{"linux/auto_fs.h",	"AUTOFS_IOC_READY",	0x20009360},
	{"linux/auto_fs.h",	"AUTOFS_IOC_FAIL",	0x20009361},
	{"linux/auto_fs.h",	"AUTOFS_IOC_CATATONIC",	0x20009362},
	{"linux/auto_fs.h",	"AUTOFS_IOC_PROTOVER",	0x20009363},
	{"linux/auto_fs.h",	"AUTOFS_IOC_SETTIMEOUT",	0x20009364},
	{"linux/auto_fs.h",	"AUTOFS_IOC_EXPIRE",	0x20009365},
	{"linux/auto_fs4.h",	"AUTOFS_IOC_EXPIRE_MULTI",	0x20009366},
	{"linux/nbd.h",	"NBD_SET_SOCK",	0x2000ab00},
	{"linux/nbd.h",	"NBD_SET_BLKSIZE",	0x2000ab01},
	{"linux/nbd.h",	"NBD_SET_SIZE",	0x2000ab02},
	{"linux/nbd.h",	"NBD_DO_IT",	0x2000ab03},
	{"linux/nbd.h",	"NBD_CLEAR_SOCK",	0x2000ab04},
	{"linux/nbd.h",	"NBD_CLEAR_QUE",	0x2000ab05},
	{"linux/nbd.h",	"NBD_PRINT_DEBUG",	0x2000ab06},
	{"linux/nbd.h",	"NBD_SET_SIZE_BLOCKS",	0x2000ab07},
	{"linux/nbd.h",	"NBD_DISCONNECT",	0x2000ab08},
	{"linux/raw.h",	"RAW_SETBIND",	0x2000ac00},
	{"linux/raw.h",	"RAW_GETBIND",	0x2000ac01},
	{"linux/if_pppox.h",	"PPPOEIOCSFWD",	0x2000b100},
	{"linux/if_pppox.h",	"PPPOEIOCDFWD",	0x2000b101},
	{"linux/reiserfs_fs.h",	"REISERFS_IOC_UNPACK",	0x2000cd01},
	{"linux/lvm.h",	"VG_CREATE",	0x2000fe00},
	{"linux/lvm.h",	"VG_REMOVE",	0x2000fe01},
	{"linux/lvm.h",	"VG_EXTEND",	0x2000fe03},
	{"linux/lvm.h",	"VG_REDUCE",	0x2000fe04},
	{"linux/lvm.h",	"VG_STATUS",	0x2000fe05},
	{"linux/lvm.h",	"VG_STATUS_GET_COUNT",	0x2000fe06},
	{"linux/lvm.h",	"VG_STATUS_GET_NAMELIST",	0x2000fe07},
	{"linux/lvm.h",	"VG_SET_EXTENDABLE",	0x2000fe08},
	{"linux/lvm.h",	"VG_RENAME",	0x2000fe09},
	{"linux/lvm.h",	"LV_CREATE",	0x2000fe20},
	{"linux/lvm.h",	"LV_REMOVE",	0x2000fe21},
	{"linux/lvm.h",	"LV_ACTIVATE",	0x2000fe22},
	{"linux/lvm.h",	"LV_DEACTIVATE",	0x2000fe23},
	{"linux/lvm.h",	"LV_EXTEND",	0x2000fe24},
	{"linux/lvm.h",	"LV_REDUCE",	0x2000fe25},
	{"linux/lvm.h",	"LV_STATUS_BYNAME",	0x2000fe26},
	{"linux/lvm.h",	"LV_STATUS_BYINDEX",	0x2000fe27},
	{"linux/lvm.h",	"LV_SET_ACCESS",	0x2000fe28},
	{"linux/lvm.h",	"LV_SET_ALLOCATION",	0x2000fe29},
	{"linux/lvm.h",	"LV_SET_STATUS",	0x2000fe2a},
	{"linux/lvm.h",	"LE_REMAP",	0x2000fe2b},
	{"linux/lvm.h",	"LV_SNAPSHOT_USE_RATE",	0x2000fe2c},
	{"linux/lvm.h",	"LV_STATUS_BYDEV",	0x2000fe2e},
	{"linux/lvm.h",	"LV_RENAME",	0x2000fe2f},
	{"linux/lvm.h",	"LV_BMAP",	0x2000fe30},
	{"linux/lvm.h",	"PV_STATUS",	0x2000fe40},
	{"linux/lvm.h",	"PV_CHANGE",	0x2000fe41},
	{"linux/lvm.h",	"PV_FLUSH",	0x2000fe42},
	{"linux/lvm.h",	"PE_LOCK_UNLOCK",	0x2000fe50},
	{"linux/lvm.h",	"LVM_GET_IOP_VERSION",	0x2000fe98},
	{"linux/lvm.h",	"LVM_RESET",	0x2000fe99},
	{"linux/lvm.h",	"LVM_LOCK_LVM",	0x2000ff00},
